from enum import Enum


class Airport(Enum):
    EUROAIRPORT_BASEL_MULHOUSE_FREIBURG_AIRPORT = "EAP"
    LIANYUNGANG_AIRPORT = "LYG"
    ALDERNEY_AIRPORT = "ACI"
    FALEOLO_AIRPORT = "APW"
    LINYI_AIRPORT = "LYI"
    JOSE_MARIA_CORDOVA_INTERNATIONAL_AIRPORT = "MDE"
    ANTÔNIO_RIBEIRO_NOGUEIRA_JR_STATE_AIRPORT = "JTN"
    MADIVARU_AIRPORT = "LMV"
    LAZARO_CARDENAS_AIRPORT = "LZC"
    RODRIGUEZ_BALLON_INTERNATIONAL_AIRPORT = "AQP"
    TAIYUAN_YAOCHENG_AIRPORT = "TYC"
    LIUZHOU_AIRPORT = "LZH"
    MANTA_AIRPORT = "MEC"
    DAZHOU_JINYA_AIRPORT = "DZH"
    BERENICE_INTERNATIONAL_AIRPORT = "EES"
    KUKËS_INTERNATIONAL_AIRPORT = "KFZ"
    PEDRO_TEIXEIRA_CASTELO_AIRPORT = "JTA"
    UYYALAWADA_NARASIMHA_REDDY_AIRPORT = "KJB"
    EZHOU_HUAHU_AIRPORT = "EHU"
    FUZULI_INTERNATIONAL_AIRPORT = "FZL"
    SANGIA_NIBANDERA_AIRPORT = "KXB"
    ANGRA_DOS_REIS_AIRPORT = "GDR"
    BEIDAHUANG_GENERAL_AIRPORT = "HLJ"
    CHENGDU_HUAIZHOU_AIRPORT = "HZU"
    LORENZO_AIRPORT = "MXQ"
    AMPARA_KONDAVATTAVAN_TANK_AIRPORT = "AFK"
    SÃO_PAULO_CATARINA_EXECUTIVE_AIRPORT = "JHF"
    BILLUND_AIRPORT = "BLL"
    WALFRIDO_SALMITO_DE_ALMEIDA_AIRPORT = "JSB"
    ELEFTHERIOS_VENIZELOS_INTERNATIONAL_AIRPORT = "ATH"
    ALEKSANDROVSK_SAKHALINSKIY_AIRPORT = "UHS"
    MEHAMN_AIRPORT = "MEH"
    TULLAMARINE_AIRPORT = "MEL"
    MEMPHIS_INTERNATIONAL_AIRPORT = "MEM"
    MBS_INTERNATIONAL_AIRPORT = "MBS"
    WILKES_BARRE_SCRANTON_INTERNATIONAL_AIRPORT = "AVP"
    DOHA_INTERNATIONAL_AIRPORT = "DIA"
    GANJA_INTERNATIONAL_AIRPORT = "GNJ"
    SUIFENHE_DONGNING_AIRPORT = "HSF"
    AL_BARDAWIL_INTERNATIONAL_AIRPORT = "RDL"
    NEW_VACARIA_AIRPORT = "VCC"
    MALACCA_INTERNATIONAL_AIRPORT = "MKZ"
    GONDIA_AIRPORT = "GDB"
    MALE_INTERNATIONAL_AIRPORT = "MLE"
    ANQING_TIANZHUSHAN_AIRPORT = "AQG"
    ST_HUBERT_AIRPORT = "YHU"
    ISLAND_LAKE_AIRPORT = "YIV"
    AEROPORTO_DE_CRATEUS_AIRPORT = "JCS"
    QAISUMAH_AIRPORT = "AQI"
    KUUJJUARAPIK_AIRPORT = "YGW"
    KING_HUSSEIN_INTERNATIONAL_AIRPORT = "AQJ"
    ABDUL_RACHMAN_SALEH_AIRPORT = "MLG"
    LIVINGSTONE_AIRPORT = "LVI"
    CATOCA_AIRPORT = "CTV"
    MUDANJIANG_AIRPORT = "MDG"
    BRIGADEIRO_FIRMINO_AYRES_AIRPORT = "JPO"
    NAGIB_DEMACHKI_AIRPORT = "JPE"
    PARATY_AIRPORT = "JPY"
    NIAGARA_DISTRICT_AIRPORT = "YCM"
    DIGBY_ISLAND_AIRPORT = "YPR"
    YELLOWSTONE_REGIONAL_AIRPORT = "COD"
    HUSEIN_SASTRANEGARA_AIRPORT = "BDO"
    DARA_SAKOR_INTERNATIONAL_AIRPORT = "DSY"
    VADODARA_AIRPORT = "BDQ"
    NEWARK_LIBERTY_INTERNATIONAL_AIRPORT = "EWR"
    SANIKILUAQ_AIRPORT = "YSK"
    PEMBROKE_AND_AREA_AIRPORT = "YTA"
    TASIUJUAQ_AIRPORT = "YTQ"
    DHAALU_AIRPORT = "DDD"
    YUTIAN_WANFANG_AIRPORT = "YTW"
    COCHIN_INTERNATIONAL_AIRPORT = "COK"
    JIANDE_QIANDAOHU_AIRPORT = "JDE"
    MATSU_BEIGAN_AIRPORT = "MFK"
    DARBHANGA_AIRPORT = "DBR"
    DODGE_CITY_MUNICIPAL_AIRPORT = "DDC"
    ROGUE_VALLEY_INTERNATIONAL_MEDFORD_AIRPORT = "MFR"
    EL_ALTO_INTERNATIONAL_AIRPORT = "LPB"
    KAPUSKASING_AIRPORT = "YYU"
    MOULAY_ALI_CHERIF_AIRPORT = "ERH"
    ERIE_INTERNATIONAL_AIRPORT = "ERI"
    EREN_HOT_AIRPORT = "ERL"
    EXETER_INTERNATIONAL_AIRPORT = "EXT"
    TERNEY_AIRPORT = "NEI"
    LIUPANSHUI_YUEZHAO_AIRPORT = "LPF"
    ELIWANA_AIRPORT = "WHB"
    LAMPANG_AIRPORT = "LPT"
    GODS_RIVER_AIRPORT = "ZGI"
    SANDSPIT_AIRPORT = "YZP"
    PORT_HARDY_AIRPORT = "YZT"
    SACHIGO_LAKE_AIRPORT = "ZPB"
    MOI_INTERNATIONAL_AIRPORT = "MBA"
    MYEIK_AIRPORT = "MGZ"
    MASHHAD_INTERNATIONAL_AIRPORT = "MHD"
    ULAWA_AIRPORT = "RNA"
    EL_YOPAL_AIRPORT = "EYP"
    KEY_WEST_INTERNATIONAL_AIRPORT = "EYW"
    MINISTRO_PISTARINI_AIRPORT = "EZE"
    CHENZHOU_BEIHU_AIRPORT = "HCZ"
    DUMAGUETE_AIRPORT = "DGT"
    LUNGI_INTERNATIONAL_AIRPORT = "FNA"
    SAWYER_INTERNATIONAL_AIRPORT = "MQT"
    MANNHEIM_AIRPORT = "MHG"
    MARSH_HARBOUR_INTERNATIONAL_AIRPORT = "MHH"
    MANHATTAN_MUNICIPAL_AIRPORT = "MHK"
    MARIEHAMN_AIRPORT = "MHQ"
    LORD_HOWE_ISLAND_AIRPORT = "LDH"
    GRAN_CANARIA_AIRPORT = "LPA"
    LINKOPING_CITY_AIRPORT = "LPI"
    MADEIRA_AIRPORT = "FNC"
    FUNADHOO_AIRPORT = "FND"
    ADDIS_ABABA_BOLE_INTERNATIONAL_AIRPORT = "ADD"
    EASTERN_WV_REGIONAL_AIRPORT_SHEPHERD_FIELD = "MRB"
    MISSOULA_INTERNATIONAL_AIRPORT = "MSO"
    MINNEAPOLIS_ST_PAUL_INTERNATIONAL_AIRPORT = "MSP"
    MINSK_NATIONAL_AIRPORT = "MSQ"
    LIPETSK_AIRPORT = "LPK"
    NORWAY_HOUSE_AIRPORT = "YNE"
    LIEPAYA_AIRPORT = "LPX"
    LOUDES_AIRPORT = "LPY"
    COCA_AIRPORT = "OCC"
    GLENEGEDALE_AIRPORT = "ILY"
    MAKU_INTERNATIONAL_AIRPORT = "IMQ"
    FELIX_HOUPHOUET_BOIGNY_AIRPORT = "ABJ"
    LILABARI_AIRPORT = "IXI"
    LANN_BIHOUE_AIRPORT = "LRT"
    SATWARI_AIRPORT = "IXJ"
    KING_FAHD_INTERNATIONAL_AIRPORT = "DMM"
    HILO_INTERNATIONAL_AIRPORT = "ITO"
    AGARTALA_AIRPORT = "IXA"
    BAGDOGRA_AIRPORT = "IXB"
    CHANDIGARH_AIRPORT = "IXC"
    BAMRAULI_AIRPORT = "IXD"
    MANGALORE_AIRPORT = "IXE"
    MALIKUS_SALEH_AIRPORT = "LSW"
    MADURAI_AIRPORT = "IXM"
    ALTAY_AIRPORT = "AAT"
    ASABA_INTERNATIONAL_AIRPORT = "ABB"
    LOSINJ_AIRPORT = "LSZ"
    LA_FLORIDA_AIRPORT = "LSC"
    BIRSA_MUNDA_AIRPORT = "IXR"
    CHIKKALTHANA_AIRPORT = "IXU"
    LA_CROSSE_REGIONAL_AIRPORT = "LSE"
    JOSEFA_CAMEJO_AIRPORT = "LSP"
    DRESDEN_INTERNATIONAL_AIRPORT = "DRS"
    PORT_BLAIR_AIRPORT = "IXZ"
    GOVARDHANPUR_AIRPORT = "JGA"
    JIAGEDAQI_AIRPORT = "JGD"
    LAUNCESTON_AIRPORT = "LST"
    LISMORE_AIRPORT = "LSY"
    BUBUNG_AIRPORT = "LUW"
    SITIA_AIRPORT = "JSH"
    SKIATHOS_AIRPORT = "JSI"
    WESTMORELAND_COUNTY_AIRPORT = "LBE"
    JAMESTOWN_AIRPORT = "JHW"
    CHIOS_AIRPORT = "JKH"
    KALYMNOS_ISLAND_NATIONAL_AIRPORT = "JKL"
    JANAKPUR_AIRPORT = "JKR"
    CITY_OF_DERRY_AIRPORT = "LDY"
    BAURU_AIRPORT = "BAU"
    LEIPZIG_HALLE_AIRPORT = "LEJ"
    LAFAYETTE_REGIONAL_AIRPORT = "LFT"
    AGATTI_ISLAND_AIRPORT = "AGX"
    LUANG_NAMTHA_AIRPORT = "LXG"
    DONETSK_INTERNATIONAL_AIRPORT = "DOK"
    DUSSELDORF_INTERNATIONAL_AIRPORT = "DUS"
    NOTTINGHAM_AIRPORT = "NQT"
    MOHE_AIRPORT = "OHE"
    NOVOSTROYKA_AIRPORT = "OHH"
    LUXOR_INTERNATIONAL_AIRPORT = "LXR"
    LIMNOS_AIRPORT = "LXS"
    LOME_AIRPORT = "LFW"
    LAGUARDIA_AIRPORT = "LGA"
    LONG_BEACH_AIRPORT = "LGB"
    LIEGE_AIRPORT = "LGG"
    DEADMANS_CAY_AIRPORT = "LGI"
    LANGKAWI_INTERNATIONAL_AIRPORT = "LGK"
    SILAMPARI_AIRPORT = "LLJ"
    BUA_AIRPORT = "LLO"
    ASPEN_AIRPORT = "ASE"
    SILVIO_PETTIROSSI_INTERNATIONAL_AIRPORT = "ASU"
    ATMAUTLUAK_AIRPORT = "ATT"
    HELSINKI_VANTAA_AIRPORT = "HEL"
    NORTH_BAY_AIRPORT = "BRR"
    LILONGWE_INTERNATIONAL_AIRPORT = "LLW"
    PENSACOLA_INTERNATIONAL_AIRPORT = "PNS"
    LIVERPOOL_JOHN_LENNON_AIRPORT = "LPL"
    AVIGNON_CAUMONT_AIRPORT = "AVN"
    LUANG_PRABANG_INTERNATIONAL_AIRPORT = "LPQ"
    SANAA_INTERNATIONAL_AIRPORT = "SAH"
    EL_SALVADOR_INTERNATIONAL_AIRPORT = "SAL"
    SAN_DIEGO_INTERNATIONAL_AIRPORT = "SAN"
    ITAUBA_AIRPORT = "AUB"
    MARECHAL_CUNHA_MACHADO_INTERNATIONAL_AIRPORT = "SLZ"
    SACRAMENTO_INTERNATIONAL_AIRPORT = "SMF"
    LAREDO_INTERNATIONAL_AIRPORT = "LRD"
    AVALON_AIRPORT = "AVV"
    AHWAZ_AIRPORT = "AWZ"
    HELSINGE_AIRPORT = "SOO"
    LAMBERT_ST_LOUIS_INTERNATIONAL_AIRPORT = "STL"
    ST_PAUL_DOWNTOWN_AIRPORT = "STP"
    CYRIL_E_KING_AIRPORT = "STT"
    SURAT_GUJARAT_AIRPORT = "STV"
    HENRY_E_ROHLSEN_AIRPORT = "STX"
    JUANDA_INTERNATIONAL_AIRPORT = "SUB"
    LAMEZIA_TERME_INTERNATIONAL_AIRPORT = "SUF"
    SURIGAO_AIRPORT = "SUG"
    LANGTOU_AIRPORT = "DDG"
    FAISALABAD_AIRPORT = "LYP"
    SAMSUN_CARSAMBA_AIRPORT = "SZF"
    SHENZHEN_BAOAN_INTERNATIONAL_AIRPORT = "SZX"
    LYON_SAINT_EXUPERY_INTERNATIONAL_AIRPORT = "LYS"
    DEMOKRITOS_AIRPORT = "AXD"
    ANDIZHAN_AIRPORT = "AZN"
    KALAMAZOO_BATTLE_CREEK_INTERNATIONAL_AIRPORT = "AZO"
    PUER_SIMAO_AIRPORT = "SYM"
    GOLOVIN_AIRPORT = "GLV"
    LUZHOU_LANTIAN_AIRPORT = "LZO"
    GUSTAVUS_AIRPORT = "GST"
    NYINGCHI_MAINLING_AIRPORT = "LZY"
    SANGSTER_INTERNATIONAL_AIRPORT = "MBJ"
    BLACKER_AIRPORT = "MBL"
    E_CORTISSOZ_AIRPORT = "BAQ"
    AIRPORT_CHAFEI_AMSEI = "BAT"
    BACOLOD_SILAY_INTERNATIONAL_AIRPORT = "BCD"
    LITTLE_CAYMAN_AIRPORT = "LYB"
    LYCKSELE_AIRPORT = "LYC"
    CHENNAI_AIRPORT = "MAA"
    KOYUK_AIRPORT = "KKA"
    HOLY_CROSS_AIRPORT = "HCR"
    KETCHIKAN_INTERNATIONAL_AIRPORT = "KTN"
    KALTAG_AIRPORT = "KAL"
    HOMER_AIRPORT = "HOM"
    HOOPER_BAY_AIRPORT = "HPB"
    HUSLIA_AIRPORT = "HSL"
    KING_SALMON_AIRPORT = "AKN"
    BRADLEY_INTERNATIONAL_AIRPORT = "BDL"
    BHADRAPUR_AIRPORT = "BDP"
    BELGRAD_NIKOLA_TESLA_AIRPORT = "BEG"
    MEADOWS_FIELD_AIRPORT = "BFL"
    BRAM_FISCHER_INTERNATIONAL_AIRPORT = "BFN"
    BELFAST_INTERNATIONAL_AIRPORT = "BFS"
    BOB_BAKER_MEMORIAL_AIRPORT = "IAN"
    SHAGELUK_AIRPORT = "SHX"
    NOME_AIRPORT = "OME"
    TOKSOOK_BAY_AIRPORT = "OOK"
    ST_MICHAEL_AIRPORT = "SMK"
    PLATINUM_AIRPORT = "PTU"
    MCALLEN_INTERNATIONAL_AIRPORT = "MFE"
    SVALBARD_AIRPORT = "LYR"
    RALPH_WIEN_MEMORIAL_AIRPORT = "OTZ"
    AARHUS_AIRPORT = "AAR"
    ACAPULCO_INTERNATIONAL_AIRPORT = "ACA"
    ALTENRHEIN_AIRPORT = "ACH"
    XINGYI_AIRPORT = "ACX"
    BURI_RAM_AIRPORT = "BFV"
    PALONEGRO_INTERNATIONAL_AIRPORT = "BGA"
    SUMBURGH_AIRPORT = "LSI"
    RUBY_AIRPORT = "RBY"
    ABERDEEN_INTERNATIONAL_AIRPORT = "ABZ"
    SAINT_MARYS_AIRPORT = "KSM"
    FORT_YUKON_AIRPORT = "FYU"
    GWINNETT_COUNTY_AIRPORT = "LZU"
    MASBATE_AIRPORT = "MBT"
    MARIBOR_INTERNATIONAL_AIRPORT = "MBX"
    ZABOL_AIRPORT = "ACZ"
    SOCHI_INTERNATIONAL_AIRPORT = "AER"
    VIGRA_ALESUND_AIRPORT = "AES"
    ALGHERO_FERTILIA_AIRPORT = "AHO"
    AIZAWL_AIRPORT = "AJL"
    HABIB_BOURGUIBA_INTERNATIONAL_AIRPORT = "MIR"
    PRUDHOE_BAY_DEADHORSE_AIRPORT = "SCC"
    ELMIRA_CORNING_REGIONAL_AIRPORT = "ELM"
    KAMUSI_AIRPORT = "KUY"
    ASAHIKAWA_AIRPORT = "AKJ"
    HAMILTON_ISLAND_AIRPORT = "HTI"
    AUCKLAND_AIRPORT = "AKL"
    MANCHESTER_BOSTON_REGIONAL_AIRPORT = "MHT"
    KJAERSTAD_AIRPORT = "MJF"
    GREATER_BINGHAMTON_AIRPORT = "BGM"
    BELAYA_GORA_AIRPORT = "BGN"
    BERGEN_AIRPORT = "BGO"
    MITIGA_TRIPOLI_AIRPORT = "MJI"
    POND_INLET_AIRPORT = "YIO"
    MIAMI_INTERNATIONAL_AIRPORT = "MIA"
    GUERNSEY_AIRPORT = "GCI"
    TRIESTE_FRIULI_VENEZIA_GIULIA_AIRPORT = "TRS"
    LIBREVILLE_AIRPORT = "LBV"
    TRIVANDRUM_INTERNATIONAL_AIRPORT = "TRV"
    TIRUCHIRAPALLI_INTERNATIONAL_AIRPORT = "TRZ"
    TAIPEI_SONGSHAN_AIRPORT = "TSA"
    ASTANA_NURSULTAN_INTERNATIONAL_AIRPORT = "TSE"
    TABUBIL_AIRPORT = "TBG"
    ALTA_AIRPORT = "ALF"
    ALBANY_AIRPORT = "ALH"
    BEIRA_AIRPORT = "BEW"
    BAGHDAD_INTERNATIONAL_AIRPORT = "BGW"
    MOUNT_ISA_AIRPORT = "ISA"
    LONGREACH_AIRPORT = "LRE"
    BAMAKO_SENOU_INTERNATIONAL_AIRPORT = "BKO"
    MANUEL_CRESCENCIO_REJON_INTERNATIONAL_AIRPORT = "MID"
    KAYSERI_AIRPORT = "ASR"
    ANYANG_AIRPORT = "AYN"
    WOODBOURNE_AIRPORT = "BHE"
    RUDRA_MATA_AIRPORT = "BHJ"
    BIRMINGHAM_SHUTTLESWORTH_INTERNATIONAL_AIRPORT = "BHM"
    BROKEN_HILL_AIRPORT = "BHQ"
    BHAVNAGAR_AIRPORT = "BHU"
    MCKELLAR_AIRPORT = "MKL"
    BASTIA_PORETTA_AIRPORT = "BIA"
    SCHEFFERVILLE_AIRPORT = "YKL"
    RENDANI_AIRPORT = "MKW"
    KANGIRSUK_AIRPORT = "YKG"
    MACKAY_AIRPORT = "MKY"
    GJOA_HAVEN_AIRPORT = "YHK"
    BATSFJORD_AIRPORT = "BJF"
    BEMIDJI_AIRPORT = "BJI"
    QUAD_CITY_INTERNATIONAL_AIRPORT = "MLI"
    MELILLA_AIRPORT = "MLN"
    MILOS_AIRPORT = "MLO"
    NINOY_AQUINO_INTERNATIONAL_AIRPORT = "MNL"
    BAHRAIN_INTERNATIONAL_AIRPORT = "BAH"
    BAOTOU_AIRPORT = "BAV"
    BARNAUL_GHERMAN_TITOV_INTERNATIONAL_AIRPORT = "BAX"
    YUNDUM_INTERNATIONAL_AIRPORT = "BJL"
    BAHJA_AIRPORT = "BJQ"
    MILAS_BODRUM_AIRPORT = "BJV"
    STURDEE_VALLEY_AIRPORT = "YTC"
    MAASTRICHT_AACHEN_AIRPORT = "MST"
    GATINEAU_AIRPORT = "YND"
    INEDBIRENNE_AIRPORT = "DJG"
    AALBORG_AIRPORT = "AAL"
    NATUASHISH_AIRPORT = "YNP"
    LOUIS_ARMSTRONG_NEW_ORLEANS_INTERNATIONAL_AIRPORT = "MSY"
    WHITEHORSE_AIRPORT = "YXY"
    FLORIDA_KEYS_MARATHON_AIRPORT = "MTH"
    MONTROSE_REGIONAL_AIRPORT = "MTJ"
    PHUNG_DUC_AIRPORT = "BMV"
    NASHVILLE_INTERNATIONAL_AIRPORT = "BNA"
    BANDAR_ABBAS_INTERNATIONAL_AIRPORT = "BND"
    JOMO_KENYATTA_INTERNATIONAL_AIRPORT = "NBO"
    MAAFARU_INTERNATIONAL_AIRPORT = "NMF"
    CHANGBAISHAN_AIRPORT = "NBS"
    COTE_DAZUR_AIRPORT = "NCE"
    KIRKWALL_AIRPORT = "KOI"
    BRINDISI_SALENTO_AIRPORT = "BDS"
    BARDUFOSS_AIRPORT = "BDU"
    BENBECULA_AIRPORT = "BEB"
    RAFAEL_HERNANDEZ_AIRPORT = "BQN"
    BEAUVAIS_TILLE_AIRPORT = "BVA"
    BOA_VISTA_AIRPORT = "BVB"
    LAROCHE_AIRPORT = "BVE"
    RANKIN_INLET_AIRPORT = "YRT"
    BANGOR_INTERNATIONAL_AIRPORT = "BGR"
    BHAIRAWA_AIRPORT = "BWA"
    LAS_BRUJAS_AIRPORT = "BWW"
    MERIMBULA_AIRPORT = "MIM"
    NOTO_AIRPORT = "NTQ"
    BAIKONUR_KRAYNIY_AIRPORT = "BXY"
    ALBERT_BRAY_AIRPORT = "BYF"
    BELTSY_AIRPORT = "BZY"
    KASANE_AIRPORT = "BBK"
    KOTA_KINABALU_INTERNATIONAL_AIRPORT = "BKI"
    BURKE_LAKEFRONT_AIRPORT = "BKL"
    GUANAJUATO_INTERNATIONAL_AIRPORT = "BJX"
    BALKANABAT_AIRPORT = "BKN"
    CENTRAL_ILLINOIS_REGIONAL_AIRPORT = "BMI"
    CABINDA_AIRPORT = "CAB"
    MORELIA_AIRPORT = "MLM"
    CASCAVEL_AIRPORT = "CAC"
    BARTOLOMEU_LISANDRO_AIRPORT = "CAW"
    J_WILSTERMAN_AIRPORT = "CBB"
    CAMBRIDGE_AIRPORT = "CBG"
    JARDINES_DEL_REY_AIRPORT = "CCC"
    CARCASSONNE_AIRPORT = "CCF"
    COCOS_ISLANDS_AIRPORT = "CCK"
    DAWSON_CITY_AIRPORT = "YDA"
    ZWEIBRUECKEN_AIRPORT = "ZQW"
    TOKUA_AIRPORT = "RAB"
    ROROS_AIRPORT = "RRS"
    BALLINA_BYRON_AIRPORT = "BNK"
    BRONNOYSUND_AIRPORT_BRONNOY = "BNN"
    BRAMBLE_AIRPORT = "MNI"
    MONROE_REGIONAL_AIRPORT = "MLU"
    DURHAM_TEES_VALLEY_AIRPORT = "MME"
    SAINT_HELENA_AIRPORT = "ASI"
    BENIN_CITY_AIRPORT = "BNI"
    PORTO_SEGURO_AIRPORT = "BPS"
    BANGDA_AIRPORT = "BPX"
    MAMMOTH_LAKES_AIRPORT = "MMH"
    MURMANSK_AIRPORT = "MMK"
    MORRISTOWN_MUNICIPAL_AIRPORT = "MMU"
    MALMO_AIRPORT = "MMX"
    PENANG_INTERNATIONAL_AIRPORT = "PEN"
    BISKRA_AIRPORT = "BSK"
    MACEIO_ZUMBI_DOS_PALMARES_INTERNATIONAL_AIRPORT = "MCZ"
    NETAJI_SUBHAS_CHANDRA_BOSE_AIRPORT = "CCU"
    ADRAR_AIRPORT = "AZR"
    BLAGOVESCHENSK_AIRPORT = "BQS"
    BREST_AIRPORT = "BQT"
    BARREIRAS_AIRPORT = "BRA"
    BRASILIA_INTERNATIONAL_AIRPORT = "BSB"
    KIRAKIRA_AIRPORT = "IRA"
    BACHA_KHAN_INTERNATIONAL_AIRPORT = "PEW"
    PENZA_AIRPORT = "PEZ"
    PHILADELPHIA_INTERNATIONAL_AIRPORT = "PHL"
    PARKES_AIRPORT = "PKE"
    PAKSE_AIRPORT = "PKZ"
    AIN_EL_BEY_AIRPORT = "CZL"
    RESOLUTE_BAY_AIRPORT = "YRB"
    BELLA_COOLA_AIRPORT = "QBC"
    LANZAROTE_AIRPORT = "ACE"
    CHEREPOVETS_AIRPORT = "CEE"
    HAWARDEN_AIRPORT = "CEG"
    PRINCE_MOHAMMAD_BIN_ABDULAZIZ_INTERNATIONAL_AIRPORT = "MED"
    SULTAN_MAHMUD_BADARUDDIN_II_AIRPORT = "PLM"
    EMMET_COUNTY_AIRPORT = "PLN"
    PORT_LINCOLN_AIRPORT = "PLO"
    PROVIDENCIALES_INTERNATIONAL_AIRPORT = "PLS"
    MUTIARA_AIRPORT = "PLW"
    PORT_ELIZABETH_INTERNATIONAL_AIRPORT = "PLZ"
    EL_TEPUAL_AIRPORT = "PMC"
    PALMA_DE_MALLORCA_AIRPORT = "PMI"
    PHNOM_PENH_INTERNATIONAL_AIRPORT = "PNH"
    POHNPEI_AIRPORT = "PNI"
    BISBEE_MUNICIPAL_AIRPORT = "BSQ"
    KEISAH_AIRPORT = "KEA"
    ANGLING_LAKE_AIRPORT = "YAX"
    BASCO_AIRPORT = "BSO"
    CRESTON_VALLEY_AIRPORT = "CFQ"
    CARPIQUET_AIRPORT = "CFR"
    BENITO_JUAREZ_INTERNATIONAL_AIRPORT = "MEX"
    SALGADO_FILHO_INTERNATIONAL_AIRPORT = "POA"
    TAHITI_FAAA_AIRPORT = "PPT"
    WONDERBOOM_AIRPORT = "PRY"
    PISA_INTERNATIONAL_AIRPORT = "PSA"
    TRI_CITIES_AIRPORT = "PSC"
    IQALUIT_AIRPORT = "YFB"
    PRINCE_SAID_IBRAHIM_INTERNATONAL_AIRPORT = "HAH"
    THEODORE_FRANCIS_GREEN_MEMORIAL_STATE_AIRPORT = "PVD"
    SHANGHAI_PUDONG_INTERNATIONAL_AIRPORT = "PVG"
    PORTO_VELHO_INTERNATIONAL_AIRPORT = "PVH"
    BERENS_RIVER_AIRPORT = "YBV"
    MOBILE_REGIONAL_AIRPORT = "MOB"
    LES_SALINES_AIRPORT = "AAE"
    ARAXA_AIRPORT = "AAX"
    ABAKAN_AIRPORT = "ABA"
    SULTAN_ISKANDAR_MUDA_INTERNATIONAL_AIRPORT = "BTJ"
    BATON_ROUGE_METROPOLITAN_AIRPORT = "BTR"
    BURLINGTON_INTERNATIONAL_AIRPORT = "BTV"
    MARECHAL_RONDON_INTERNATIONAL_AIRPORT = "CGB"
    MONTES_CLAROS_AIRPORT = "MOC"
    KINGSTON_NORMAN_ROGERS_AIRPORT = "YGK"
    MOLDE_AIRPORT_ARO = "MOL"
    DRYDEN_REGIONAL_AIRPORT = "YHD"
    EAST_FORK_AIRPORT = "EFO"
    MORONDAVA_AIRPORT = "MOQ"
    MINOT_INTERNATIONAL_AIRPORT = "MOT"
    MORANBAH_AIRPORT = "MOV"
    BORACAY_AIRPORT = "MPH"
    ADANA_AIRPORT = "ADA"
    ADIYAMAN_AIRPORT = "ADF"
    GUSTAVO_ROJAS_PINILLA_AIRPORT = "ADZ"
    BRUNEI_INTERNATIONAL_AIRPORT = "BWN"
    SAO_PAULO_CONGONHAS_AIRPORT = "CGH"
    MONTPELLIER_MEDITERRANEE_AIRPORT = "MPL"
    BURNIE_WYNYARD_AIRPORT = "BWT"
    PLEIKU_AIRPORT = "PXU"
    WILLIAMS_LAKE_AIRPORT = "YWL"
    AKWA_IBOM_AIRPORT = "QUO"
    FOOTNER_LAKE_AIRPORT = "YOJ"
    CAGLIARI_ELMAS_AIRPORT = "CAG"
    MAKALE_AIRPORT = "MQX"
    MISURATA_AIRPORT = "MRA"
    CANBERRA_AIRPORT = "CBR"
    CATUMBELA_AIRPORT = "CBT"
    CHANGCHUN_LONGJIA_INTERNATIONAL_AIRPORT = "CGQ"
    CAMPO_GRANDE_INTERNATIONAL_AIRPORT = "CGR"
    JORGE_NEWBERY_AIRPORT = "AEP"
    SAN_RAFAEL_AIRPORT = "AFA"
    AUGSBURG_AIRPORT = "AGB"
    LA_GARENNE_AIRPORT = "AGF"
    ALEJO_GARCIA_AIRPORT = "AGT"
    AGUASCALIENTS_INTERNATIONAL_AIRPORT = "AGU"
    LAGUINDINGAN_INTERNATIONAL_AIRPORT = "CGY"
    THUNDER_BAY_INTERNATIONAL_AIRPORT = "YQT"
    CABLE_AIRPORT = "CCB"
    GORNO_ALTAYSK_AIRPORT = "RGK"
    CRANE_COUNTY_AIRPORT = "CCG"
    CALICUT_INTERNATIONAL_AIRPORT = "CCJ"
    MORO_AIRPORT = "MXH"
    MACTAN_CEBU_INTERNATIONAL_AIRPORT = "CEB"
    DEL_NORTE_COUNTY_REGIONAL_AIRPORT = "CEC"
    CHIANG_RAI_INTERNATIONAL_AIRPORT = "CEI"
    AJACCIO_NAPOLEON_BONAPARTE_AIRPORT = "AJA"
    JOUF_AIRPORT = "AJF"
    AGRI_AIRPORT = "AJI"
    IN_AMENAS_AIRPORT = "IAM"
    MUS_AIRPORT = "MSR"
    YANGON_INTERNATIONAL_AIRPORT = "RGN"
    ANGELHOLM_HELSINGBORG_AIRPORT = "AGH"
    MOSHOESHOE_INTERNATIONAL_AIRPORT = "MSU"
    CAPE_GIRARDEAU_AIRPORT = "CGI"
    SOEKARNO_HATTA_INTERNATIONAL_AIRPORT = "CGK"
    SHAH_AMANAT_INTERNATIONAL_AIRPORT = "CGP"
    CHATTANOOGA_AIRPORT = "CHA"
    CHARLESTON_INTERNATIONAL_AIRPORT = "CHS"
    CIAMPINO_G_B_PASTINE_INTERNATIONAL_AIRPORT = "CIA"
    THE_EASTERN_IOWA_AIRPORT = "CID"
    E_BELTRAM_AIRPORT = "CIJ"
    AKSU_AIRPORT = "AKU"
    AKTYUBINSK_AIRPORT = "AKX"
    ALMATY_AIRPORT = "ALA"
    AHMEDABAD_AIRPORT = "AMD"
    AMSTERDAM_AIRPORT_SCHIPHOL = "AMS"
    ILULISSAT_AIRPORT = "JAV"
    YURI_GAGARIN_AIRPORT = "MSZ"
    DAHL_CREEK_AIRPORT = "DCK"
    CHRISTCHURCH_INTERNATIONAL_AIRPORT = "CHC"
    EGILSSTADIR_AIRPORT = "EGS"
    CHAOYANG_AIRPORT = "CHG"
    V_C_BIRD_INTERNATIONAL_AIRPORT = "ANU"
    ANSHAN_TENGAO_AIRPORT = "AOG"
    SHYMKENT_AIRPORT = "CIT"
    CORNEL_RUIZ_AIRPORT = "CIX"
    CAJAMARCA_AIRPORT = "CJA"
    CHEDDI_JAGAN_INTERNATIONAL_AIRPORT = "GEO"
    BAYANNUR_TIANJITAI_AIRPORT = "RLK"
    SANTA_ANA_AIRPORT = "NNB"
    COIMBATORE_INTERNATIONAL_AIRPORT = "CJB"
    EL_LOA_AIRPORT = "CJC"
    CHEONGJU_AIRPORT = "CJJ"
    BENEDUM_AIRPORT = "CKB"
    CHONGQING_JIANGBEI_INTERNATIONAL_AIRPORT = "CKG"
    CHOKURDAH_AIRPORT = "CKH"
    APARTADO_AIRPORT = "APO"
    QUICHE_AIRPORT = "AQB"
    TOREMBI_AIRPORT = "TCJ"
    NAMPULA_AIRPORT = "APL"
    CONAKRY_AIRPORT = "CKY"
    MAPUTO_INTERNATIONAL_AIRPORT = "MPM"
    CANAKKALE_AIRPORT = "CKZ"
    MCCLELLAN_PALOMAR_AIRPORT = "CLD"
    ALFONSO_B_ARAGON_AIRPORT = "CLO"
    ALOR_ISLAND_AIRPORT = "ARD"
    WATERTOWN_AIRPORT = "ART"
    ASTRAKHAN_AIRPORT = "ASF"
    COLIMA_AIRPORT = "CLQ"
    SANDAKAN_AIRPORT = "SDK"
    SAINTE_CATHERINE_AIRPORT = "CLY"
    CIUDAD_DEL_CARMEN_AIRPORT = "CME"
    JOHN_GLENN_COLUMBUS_INTERNATIONAL_AIRPORT = "CMH"
    ALTAMIRA_AIRPORT = "ATM"
    NOUMERATE_AIRPORT = "GHA"
    MONTAUK_AIRPORT = "MTP"
    JOAO_SUASSUNA_AIRPORT = "CPV"
    YEAGER_AIRPORT = "CRW"
    LOS_GARZONES_AIRPORT = "MTR"
    JOSE_TADEO_MONAGAS_INTERNATIONAL_AIRPORT = "MUN"
    GWADAR_AIRPORT = "GWD"
    AUGUSTA_AIRPORT = "AUG"
    AURILLAC_AIRPORT = "AUR"
    ARAGUAINA_AIRPORT = "AUX"
    AN_SHUN_HUANG_GUO_SHU_AIRPORT = "AVA"
    MOHAMED_V_INTERNATIONAL_AIRPORT = "CMN"
    IGN_AGRAMONTE_INTERNATIONAL_AIRPORT = "CMW"
    KOGALNICEANU_AIRPORT = "CND"
    GWALIOR_AIRPORT = "GWL"
    GAZIPASA_AIRPORT = "GZP"
    GAZIANTEP_AIRPORT = "GZT"
    HANIMAADHOO_AIRPORT = "HAQ"
    GOTEBORG_LANDVETTER_AIRPORT = "GOT"
    YAMPA_VALLEY_AIRPORT = "HDN"
    HAT_YAI_INTERNATIONAL_AIRPORT = "HDY"
    WABUSH_AIRPORT = "YWK"
    HERAT_INTERNATIONAL_AIRPORT = "HEA"
    HERAKLION_AIRPORT = "HER"
    MULTAN_AIRPORT = "MUX"
    MUSOMA_AIRPORT = "MUZ"
    EL_EDEN_AIRPORT = "AXM"
    SPRINGPOINT_AIRPORT = "AXP"
    YANAMILLA_AIRPORT = "AYP"
    BATA_AIRPORT = "BSG"
    CARRASCO_INTERNATIONAL_AIRPORT = "MVD"
    SATU_MARE_INTERNATIONAL_AIRPORT = "SUJ"
    DOUALA_AIRPORT = "DLA"
    SAULT_STE_MARIE_AIRPORT = "SSM"
    MAKHACHKALA_AIRPORT = "MCX"
    SUNSHINE_COAST_AIRPORT = "MCY"
    SAM_RATULANGI_INTERNATIONAL_AIRPORT = "MDC"
    MPANDA_AIRPORT = "MOW"
    SHIJIAZHUANG_LUANCHENG_AIRPORT = "LCT"
    WILLIAMSON_COUNTY_AIRPORT = "MWA"
    CAMBA_PUNTA_AIRPORT = "CNQ"
    TSTC_WACO_AIRPORT = "CNW"
    YAZD_AIRPORT = "AZD"
    BATMAN_AIRPORT = "BAL"
    DARU_AIRPORT = "DAU"
    FLIN_FLON_AIRPORT = "YFO"
    GOLENIOW_AIRPORT = "SZZ"
    QUANZHOU_JINJIANG_INTERNATIONAL_AIRPORT = "JJN"
    JACKSONVILLE_INTERNATIONAL_AIRPORT = "JAX"
    LA_ISABELA_INTERNATIONAL_AIRPORT = "JBQ"
    JERSEY_AIRPORT = "JER"
    JOHN_F_KENNEDY_INTERNATIONAL_AIRPORT = "JFK"
    KENNETH_KAUNDA_INTERNATIONAL_AIRPORT = "LUN"
    AXAMO_AIRPORT = "JKG"
    HARRISBURG_INTERNATIONAL_AIRPORT = "MDT"
    CHICAGO_MIDWAY_INTERNATIONAL_AIRPORT = "MDW"
    EL_PLUMERILLO_INTERNATIONAL_AIRPORT = "MDZ"
    EL_TARI_AIRPORT = "KOE"
    KAGOSHIMA_AIRPORT = "KOJ"
    KRUUNUPYY_AIRPORT = "KOK"
    LAKE_CHARLES_REGIONAL_AIRPORT = "LCH"
    ESSENDON_AIRPORT = "MEB"
    BENSON_MUNICIPAL_AIRPORT = "BBB"
    INGENIERO_AERONAUTICO_AMBROSIO_L_V_TARAVELLA_INTERNATIONAL_AIRPORT = "COR"
    COLORADO_SPRINGS_AIRPORT = "COS"
    COLUMBIA_REGIONAL_AIRPORT = "COU"
    A_N_R_ROBINSON_INTERNATIONAL_AIRPORT = "TAB"
    DAEGU_INTERNATIONAL_AIRPORT = "TAE"
    TANNA_AIRPORT = "TAH"
    TAKAMATSU_AIRPORT = "TAK"
    TAMPICO_INTERNATIONAL_AIRPORT = "TAM"
    STATESBORO_BULLOCH_COUNTY_AIRPORT = "TBR"
    TBILISI_INTERNATIONAL_AIRPORT = "TBS"
    TABRIZ_AIRPORT = "TBZ"
    RICKENBACKER_INTERNATIONAL_AIRPORT = "LCK"
    LIANCHENG_AIRPORT = "LCX"
    CHAPELCO_AIRPORT = "CPC"
    CAMPECHE_INTERNATIONAL_AIRPORT = "CPE"
    COPENHAGEN_AIRPORT = "CPH"
    CHAMONATE_AIRPORT = "CPO"
    BACAU_AIRPORT = "BCM"
    CASPER_NATRONA_COUNTY_INTERNATIONAL_AIRPORT = "CPR"
    ST_LOUIS_DOWNTOWN_AIRPORT = "CPS"
    CAPE_TOWN_INTERNATIONAL_AIRPORT = "CPT"
    ABADAN_AIRPORT = "ABD"
    GODS_LAKE_NARROWS_AIRPORT = "YGO"
    AL_AQIQ_AIRPORT = "ABT"
    NNAMDI_AZIKIWE_INTERNATIONAL_AIRPORT = "ABV"
    ALBURY_AIRPORT = "ABX"
    RICK_HUSBAND_AMARILLO_INTERNATIONAL_AIRPORT = "AMA"
    TONGREN_AIRPORT = "TEN"
    BENJAMIN_RIVERA_NORIEGA_AIRPORT = "CPX"
    HOSEA_KUTAKO_INTERNATIONAL_AIRPORT = "WDH"
    GENERAL_E_MOSCONI_INTERNATIONAL_AIRPORT = "CRD"
    BRADFORD_AIRPORT = "BFD"
    MAUN_AIRPORT = "MUB"
    ADELAIDE_AIRPORT = "ADL"
    ARDABIL_AIRPORT = "ADU"
    BOEING_FIELD_INTERNATIONAL_AIRPORT = "BFI"
    TONGLIAO_AIRPORT = "TGO"
    PODKAMENNAYA_TUNGUSKA_AIRPORT = "TGP"
    TANGA_AIRPORT = "TGT"
    TONCONTIN_AIRPORT = "TGU"
    TERESINA_AIRPORT = "THE"
    SUKHOTHAI_AIRPORT = "THS"
    TIMIKA_AIRPORT = "TIM"
    BIJIE_AIRPORT = "BFJ"
    MBEYA_AIRPORT = "MBI"
    MACAPA_INTERNATIONAL_AIRPORT = "MCP"
    MINERAL_WELLS_AIRPORT = "MWL"
    MUAN_INTERNATIONAL_AIRPORT = "MWX"
    MWANZA_AIRPORT = "MWZ"
    MEXICALI_AIRPORT = "MXL"
    MILANO_MALPENSA_AIRPORT = "MXP"
    BUFFALO_MUNICIPAL_AIRPORT = "BFK"
    BRAGANCA_AIRPORT = "BGC"
    BANGUI_AIRPORT = "BGF"
    MOGADISHU_INTERNATIONAL_AIRPORT = "MGQ"
    TRIPOLI_INTERNATIONAL_AIRPORT = "TIP"
    TIRUPATI_AIRPORT = "TIR"
    TIMARU_AIRPORT = "TIU"
    TIVAT_AIRPORT = "TIV"
    ROSHCHINO_INTERNATIONAL_AIRPORT = "TJM"
    MERZIFON_AIRPORT = "MZH"
    SIERRA_MAESTRA_AIRPORT = "MZO"
    MORUYA_AIRPORT = "MYA"
    MALINDI_AIRPORT = "MYD"
    MAZAR_I_SHARIF_AIRPORT = "MZR"
    BAR_HARBOR_AIRPORT = "BHB"
    BISHA_AIRPORT = "BHH"
    COMANDANTE_AIRPORT = "BHI"
    BUKHARA_AIRPORT = "BHK"
    RAJA_BHOJ_AIRPORT = "BHO"
    RAGLAN_AIRPORT = "BHS"
    BAHAWALPUR_AIRPORT = "BHV"
    CHEBOKSARY_AIRPORT = "CSY"
    ARVIDSJAUR_AIRPORT = "AJR"
    ARACAJU_AIRPORT = "AJU"
    CATAMARCA_AIRPORT = "CTC"
    TAMWORTH_AIRPORT = "TMW"
    JINAN_YAOQIANG_INTERNATIONAL_AIRPORT = "TNA"
    TANGIER_IBN_BATTOUTA_AIRPORT = "TNG"
    TAINAN_AIRPORT = "TNN"
    COATEPEQUE_AIRPORT = "CTF"
    CHETUMAL_AIRPORT = "CTM"
    COOKTOWN_AIRPORT = "CTN"
    CHENGDU_SHUANGLIU_INTERNATIONAL_AIRPORT = "CTU"
    BIARRITZ_ANGLET_BAYONNE_AIRPORT = "BIQ"
    BIRATNAGAR_AIRPORT = "BIR"
    MARISCAL_LAMAR_INTERNATIONAL_AIRPORT = "CUE"
    PANAMA_PACIFICO_AIRPORT = "BLB"
    BAJAWA_SOA_AIRPORT = "BJW"
    BADAJOZ_AIRPORT = "BJZ"
    MARANGGO_AIRPORT = "TQQ"
    FRANCISCO_SARABIA_INTERNATIONAL_AIRPORT = "TRC"
    TRONDHEIM_AIRPORT_VAERNES = "TRD"
    TRI_CITIES_REGIONAL_AIRPORT = "TRI"
    TURIN_AIRPORT = "TRN"
    TAREE_AIRPORT = "TRO"
    MONMOUTH_EXECUTIVE_AIRPORT = "BLM"
    QUEEN_ALIA_INTERNATIONAL_AIRPORT = "AMM"
    PATTIMURA_AIRPORT = "AMQ"
    ADAM_AIRPORT = "AOM"
    CLOVIS_MUNICIPAL_AIRPORT = "CVN"
    MATSUYAMA_AIRPORT = "MYJ"
    MYRTLE_BEACH_INTERNATIONAL_AIRPORT = "MYR"
    MTWARA_AIRPORT = "MYW"
    MIRI_AIRPORT = "MYY"
    LA_NUBIA_AIRPORT = "MZL"
    CERRO_MORENO_INTERNATIONAL_AIRPORT = "ANF"
    GUGLIELMO_MARCONI_AIRPORT = "BLQ"
    SKUKUZA_AIRPORT = "SZK"
    SAO_GONCALO_DO_AMARANTE_GOVERNADOR_ALUIZIO_ALVES_INTL_AIRPORT = "NAT"
    ANDENES_AIRPORT = "ANX"
    ANCONA_FALCONARA_AIRPORT = "AOI"
    MAZATLAN_INTERNATIONAL_AIRPORT = "MZT"
    SULTAN_MUHAMMAD_SALAHUDDIN_AIRPORT = "BMU"
    DR_BABASAHEB_AMBEDKAR_INTERNATIONAL_AIRPORT = "NAG"
    NAKHICHEVAN_AIRPORT = "NAJ"
    NAPLES_INTERNATIONAL_AIRPORT = "NAP"
    CHURCHILL_AIRPORT = "YYQ"
    TREVISO_AIRPORT = "TSF"
    TSUSHIMA_AIRPORT = "TSJ"
    TIMISOARA_TRAIAN_VUIA_INTERNATIONAL_AIRPORT = "TSR"
    TRANG_AIRPORT = "TST"
    NAPLES_MUNICIPAL_AIRPORT = "APF"
    ALPENA_COUNTY_REGIONAL_AIRPORT = "APN"
    BRISBANE_AIRPORT = "BNE"
    BORDEAUX_AIRPORT = "BOD"
    NARATHIWAT_AIRPORT = "NAW"
    BOURGAS_AIRPORT = "BOJ"
    FLAMINGO_INTERNATIONAL_AIRPORT = "BON"
    ALTOONA_AIRPORT = "AOO"
    ALFEREZ_FAP_ALFREDO_VLADIMIR_SARA_BAUER_AIRPORT = "AOP"
    SULTAN_ABDUL_HALIM_AIRPORT = "AOR"
    CARNARVON_AIRPORT = "CVQ"
    COVENTRY_AIRPORT = "CVT"
    GOROKA_AIRPORT = "GKA"
    BEIJING_NANYUAN_AIRPORT = "NAY"
    BEGISHEVO_AIRPORT = "NBC"
    ENFIDHA_HAMMAMET_INTERNATIONAL_AIRPORT = "NBE"
    NERYUNGRI_AIRPORT = "NER"
    NEWCASTLE_AIRPORT = "NEV"
    TALAGI_AIRPORT = "ARH"
    ARMIDALE_AIRPORT = "ARM"
    STOCKHOLM_ARLANDA_AIRPORT = "ARN"
    ARACATUBA_AIRPORT = "ARU"
    ASHGABAT_AIRPORT = "ASB"
    TOWNSVILLE_AIRPORT = "TSV"
    BOLE_AIRPORT = "BPL"
    SULTAN_AJI_MUHAMAD_SULAIMAN_AIRPORT = "BPN"
    JEFFERSON_COUNTY_AIRPORT = "BPT"
    NEWCASTLE_INTERNATIONAL_AIRPORT = "NCL"
    NUKUS_AIRPORT = "NCU"
    NDJAMENA_AIRPORT = "NDJ"
    NADOR_INTERNATIONAL_AIRPORT = "NDR"
    SRI_GURU_RAM_DASS_JEE_INTERNATIONAL_AIRPORT = "ATQ"
    OUTAGAMIE_COUNTY_REGIONAL_AIRPORT = "ATW"
    ARAUCA_AIRPORT = "AUC"
    AUSTIN_BERGSTROM_INTERNATIONAL_AIRPORT = "AUS"
    CHILEKA_AIRPORT = "BLZ"
    SAN_CARLOS_DE_BARILOCHE_INTERNATIONAL_AIRPORT = "BRC"
    ASHEVILLE_REGIONAL_AIRPORT = "AVL"
    PALESE_AIRPORT = "BRI"
    BURLINGTON_AIRPORT = "BRL"
    SOUTH_PADRE_ISLAND_INTERNATIONAL_AIRPORT = "BRO"
    SAO_JOSE_DO_RIO_PRETO_AIRPORT = "SJP"
    LUIS_MUNOZ_MARIN_INTERNATIONAL_AIRPORT = "SJU"
    SAN_LUIS_POTOSI_AIRPORT = "SLP"
    AKITA_AIRPORT = "AXT"
    ANTALYA_AIRPORT = "AYT"
    MENDI_AIRPORT = "MDU"
    PHOENIX_MESA_GATEWAY_AIRPORT = "AZA"
    TETERBORO_AIRPORT = "TEB"
    TAITUNG_AIRPORT = "TTT"
    TUGUEGARAO_AIRPORT = "TUG"
    TURAIF_AIRPORT = "TUI"
    TULSA_INTERNATIONAL_AIRPORT = "TUL"
    BASRA_INTERNATIONAL_AIRPORT = "BSR"
    BRIGADEIRO_EDUARDO_GOMES_AIRPORT = "NVM"
    BRATSK_AIRPORT = "BTK"
    BUTTE_AIRPORT = "BTM"
    BINTULU_AIRPORT = "BTU"
    CAMOPI_AIRPORT = "OYC"
    ZAPOROZHYE_AIRPORT = "OZH"
    AIN_BEIDA_AIRPORT = "OGX"
    BIJU_PATNAIK_INTERNATIONAL_AIRPORT = "BBI"
    BARCELONA_EL_PRAT_AIRPORT = "BCN"
    BUNDABERG_AIRPORT = "BDB"
    SYAMSUDIN_NOOR_INTERNATIONAL_AIRPORT = "BDJ"
    TUNIS_CARTHAGE_INTERNATIONAL_AIRPORT = "TUN"
    TAUPO_AIRPORT = "TUO"
    TUPELO_REGIONAL_AIRPORT = "TUP"
    TUCSON_INTERNATIONAL_AIRPORT = "TUS"
    CHERRY_CAPITAL_AIRPORT = "TVC"
    THIEF_RIVER_FALLS_REGIONAL_AIRPORT = "TVF"
    THOMASVILLE_MUNICIPAL_AIRPORT = "TVI"
    TANGSHAN_SANNUHE_AIRPORT = "TVS"
    VLADIKAVKAZ_AIRPORT = "OGZ"
    BHATINDA_AIRPORT = "BUP"
    MUARA_BUNGO_AIRPORT = "BUU"
    BEJAIA_AIRPORT = "BJA"
    OHRID_AIRPORT = "OHD"
    ONTARIO_INTERNATIONAL_AIRPORT = "ONT"
    GOLD_COAST_AIRPORT = "OOL"
    OPA_LOCKA_EXECUTIVE_AIRPORT = "OPF"
    ARE_OSTERSUND_AIRPORT = "OSD"
    POINTE_NOIRE_AIRPORT = "PNR"
    NIGHTMUTE_AIRPORT = "NME"
    POINT_HOPE_AIRPORT = "PHO"
    AKUREYRI_AIRPORT = "AEY"
    AGADIR_AL_MASSIRA_AIRPORT = "AGA"
    VAL_DE_CANS_INTERNATIONAL_AIRPORT = "BEL"
    BREST_BRETAGNE_AIRPORT = "BES"
    BEIRUT_RAFIC_HARIRI_INTERNATIONAL_AIRPORT = "BEY"
    WESTERN_NEBRASKA_REGIONAL_AIRPORT = "BFF"
    BINGOL_AIRPORT = "BGG"
    TORSBY_AIRPORT = "TYF"
    TAIYUAN_WUSU_INTERNATIONAL_AIRPORT = "TYN"
    TYLER_POUNDS_REGIONAL_AIRPORT = "TYR"
    MCGHEE_TYSON_AIRPORT = "TYS"
    TRABZON_AIRPORT = "TZX"
    MAHARANA_PRATAP_AIRPORT = "UDR"
    BEVERLY_MUNICIPAL_AIRPORT = "BVY"
    BALTIMORE_WASH_INTERNATIONAL_THURGOOD_MARSHALL_AIRPORT = "BWI"
    NUIQSUT_AIRPORT = "NUI"
    NANTONG_XINGDONG_AIRPORT = "NTG"
    NYAGAN_AIRPORT = "NYA"
    NADYM_AIRPORT = "NYM"
    BATNA_AIRPORT = "BLJ"
    AIRPORT_CMDT_GUSTAVO_KRAEMER = "BGX"
    ORIO_AL_SERIO_INTERNATIONAL_AIRPORT = "BGY"
    KAVIENG_AIRPORT = "KVG"
    STOCKHOLM_SKAVSTA_AIRPORT = "NYO"
    NYURBA_AIRPORT = "NYR"
    GEORGE_BEST_BELFAST_CITY_AIRPORT = "BHD"
    NAY_PYI_TAW_AIRPORT = "NYT"
    QUETTA_AIRPORT = "UET"
    OBAN_AIRPORT = "OBN"
    TOKACHI_OBIHIRO_AIRPORT = "OBO"
    UFA_INTERNATIONAL_AIRPORT = "UFA"
    CORISCO_INTERNATIONAL_AIRPORT = "OCS"
    URGENCH_AIRPORT = "UGC"
    EL_CARANO_AIRPORT = "UIB"
    UST_KAMENOGORSK_AIRPORT = "UKK"
    KAHULUI_AIRPORT = "OGG"
    OGLE_AIRPORT = "OGL"
    OGDENSBURG_AIRPORT = "OGS"
    OSLO_AIRPORT_GARDERMOEN = "OSL"
    MOSNOV_AIRPORT = "OSR"
    OSH_AIRPORT = "OSS"
    OSTEND_BRUGES_INTERNATIONAL_AIRPORT = "OST"
    HOUARI_BOUMEDIENE_AIRPORT = "ALG"
    ANTWERP_INTERNATIONAL_AIRPORT = "ANR"
    MOKMER_AIRPORT = "BIK"
    BILLINGS_LOGAN_INTERNATIONAL_AIRPORT = "BIL"
    BILBAO_AIRPORT = "BIO"
    BISMARCK_AIRPORT = "BIS"
    UST_KUT_AIRPORT = "UKX"
    LENSK_AIRPORT = "ULK"
    BONITO_AIRPORT = "BYO"
    UMEA_AIRPORT = "UME"
    URAJ_AIRPORT = "URJ"
    OUAGADOUGOU_INTERNATIONAL_AIRPORT = "OUA"
    BRYANSK_INTERNATIONAL_AIRPORT = "BZK"
    BEZIERS_VIAS_AIRPORT = "BZR"
    SURAT_THANI_AIRPORT = "URT"
    ASTURIAS_AIRPORT = "OVD"
    PADERBORN_LIPPSTADT_AIRPORT = "PAD"
    SKIVE_AIRPORT = "SQW"
    PAGADIAN_AIRPORT = "PAG"
    FATMAWATI_SOEKARNO_AIRPORT = "BKS"
    BARKLEY_REGIONAL_AIRPORT = "PAH"
    TOUSSAINT_LOUVERTURE_INTERNATIONAL_AIRPORT = "PAP"
    MATECANA_INTERNATIONAL_AIRPORT = "PEI"
    BECKLEY_AIRPORT = "BKW"
    NSIMALEN_AIRPORT = "NSI"
    PANTELLERIA_AIRPORT = "PNL"
    PUNE_AIRPORT = "PNQ"
    MERCEDITA_AIRPORT = "PSE"
    GENERAL_JOSE_ANTONIO_ANZOATEGUI_INTERNATIONAL_AIRPORT = "BLA"
    GURAYAT_AIRPORT = "URY"
    PALM_SPRINGS_INTERNATIONAL_AIRPORT = "PSP"
    ABRUZZO_AIRPORT = "PSR"
    POSADAS_AIRPORT = "PSS"
    PUTUSSIBAU_AIRPORT = "PSU"
    BELLINGHAM_INTERNATIONAL_AIRPORT = "BLI"
    BLACKPOOL_AIRPORT = "BLK"
    KEMPEGOWDA_INTERNATIONAL_AIRPORT = "BLR"
    BROMMA_AIRPORT = "BMA"
    NIZHNEVARTOVSK_AIRPORT = "NJC"
    AL_NAJAF_INTERNATIONAL_AIRPORT = "NJF"
    NORWICH_INTERNATIONAL_AIRPORT = "NWI"
    XOXOCOTLAN_AIRPORT = "OAX"
    VAN_FERIT_MELEN_AIRPORT = "VAN"
    VARNA_AIRPORT = "VAR"
    ORANJEMUND_AIRPORT = "OMD"
    BANJA_LUKA_AIRPORT = "BNX"
    NOGLIKI_AIRPORT = "NGK"
    EL_DORADO_INTERNATIONAL_AIRPORT = "BOG"
    CHHATRAPATI_SHIVAJI_INTERNATIONAL_AIRPORT = "BOM"
    BODO_AIRPORT = "BOO"
    NIAMEY_AIRPORT = "NIM"
    TURANY_AIRPORT = "BRQ"
    PAPA_WESTRAY_AIRPORT = "PPW"
    NENJIAN_MELGEN_AIRPORT = "NJJ"
    VENICE_MARCO_POLO_AIRPORT = "VCE"
    NANJING_LUKOU_INTERNATIONAL_AIRPORT = "NKG"
    NAGOYA_AIRPORT = "NKM"
    NAKHON_PHANOM_AIRPORT = "NKP"
    QUETZALCOATL_INTERNATIONAL_AIRPORT = "NLD"
    BRISTOL_AIRPORT = "BRS"
    NINGLANG_LUGUHU_AIRPORT = "NLH"
    CHARIF_AL_IDRISSI_AIRPORT = "AHU"
    CROW_WING_COUNTY_AIRPORT = "BRD"
    BREMEN_AIRPORT = "BRE"
    BARQUISIMETO_AIRPORT = "BRM"
    NORFOLK_ISLAND_AIRPORT = "NLK"
    BERN_AIRPORT = "BRN"
    BRUSSELS_AIRPORT = "BRU"
    BAOSHAN_AIRPORT = "BSD"
    NELSPRUIT_AIRPORT = "NLP"
    NALATI_AIRPORT = "NLT"
    IRELAND_WEST_AIRPORT_KNOCK = "NOC"
    FASCENE_AIRPORT = "NOS"
    TONTOUTA_AIRPORT = "NOU"
    DALA_AIRPORT = "BLE"
    NEW_PLYMOUTH_AIRPORT = "NPL"
    NEWQUAY_CORNWALL_AIRPORT = "NQY"
    NOW_SHAHR_AIRPORT = "NSH"
    NELSON_AIRPORT = "NSN"
    BUDAPEST_FERENC_LISZT_INTERNATIONAL_AIRPORT = "BUD"
    BUFFALO_NIAGARA_INTERNATIONAL_AIRPORT = "BUF"
    NOTODDEN_AIRPORT = "NTB"
    BULAWAYO_AIRPORT = "BUQ"
    BOB_HOPE_AIRPORT = "BUR"
    BATUMI_AIRPORT = "BUS"
    BATHPALATHANG_AIRPORT = "BUT"
    BERLEVAG_AIRPORT = "BVG"
    KUNGSANGEN_AIRPORT = "NRK"
    BYDGOSZCZ_AIRPORT = "BZG"
    WEEZE_AIRPORT = "NRN"
    NARITA_INTERNATIONAL_AIRPORT = "NRT"
    AEROPUERTO_DEL_NORTE_INTERNATIONAL_AIRPORT = "NTR"
    PILANESBERG_INTERNATIONAL_AIRPORT = "NTY"
    NAKHON_SI_THAMMARAT_AIRPORT = "NST"
    NANTES_ATLANTIQUE_AIRPORT = "NTE"
    NORSUP_AIRPORT = "NUS"
    NAVEGANTES_AIRPORT = "NVT"
    BARISAL_AIRPORT = "BZL"
    BENI_MELLAL_AIRPORT = "BEM"
    BOURNEMOUTH_AIRPORT = "BOH"
    BUTUAN_AIRPORT = "BXU"
    BOZEMAN_YELLOWSTONE_INTERNATIONAL_AIRPORT = "BZN"
    AWANG_AIRPORT = "CBO"
    VILNIUS_INTERNATIONAL_AIRPORT = "VNO"
    CALABAR_AIRPORT = "CBQ"
    LAL_BAHADUR_SHASTRI_INTERNATIONAL_AIRPORT = "VNS"
    MONYWAR_AIRPORT = "NYW"
    AKRON_CANTON_AIRPORT = "CAK"
    MACHRIHANISH_AIRPORT = "CAL"
    CAP_HAITIEN_AIRPORT = "CAP"
    FELIX_EBOUE_AIRPORT = "CAY"
    COLOGNE_BONN_AIRPORT = "CGN"
    ORDU_GIRESUN_AIRPORT = "OGU"
    DESTIN_FORT_WALTON_BEACH_AIRPORT = "VPS"
    CARRIEL_SUR_AIRPORT = "CCP"
    CEDAR_CITY_AIRPORT = "CDC"
    WOLF_POINT_INTERNATIONAL_AIRPORT = "OLF"
    OLARE_AIRPORT = "OLG"
    SOHAR_AIRPORT = "OHS"
    OITA_AIRPORT = "OIT"
    CHADRON_AIRPORT = "CDR"
    NAHA_AIRPORT = "OKA"
    SIMON_BOLIVAR_INTERNATIONAL_AIRPORT = "CCS"
    OKADAMA_AIRPORT = "OKD"
    OKAYAMA_AIRPORT = "OKJ"
    OLBIA_COSTA_SMERALDA_AIRPORT = "OLB"
    SNOWY_MOUNTAINS_AIRPORT = "OOM"
    CABO_FRIO_INTERNATIONAL_AIRPORT = "CFB"
    URMIA_AIRPORT = "OMH"
    MOSTAR_AIRPORT = "OMO"
    ORADEA_AIRPORT = "OMR"
    OMSK_AIRPORT = "OMS"
    ONDANGWA_AIRPORT = "OND"
    ODATE_NOSHIRO_AIRPORT = "ONJ"
    OLENYOK_AIRPORT = "ONK"
    CHELYABINSK_INTERNATIONAL_AIRPORT = "CEK"
    ONTARIO_MUNICIPAL_AIRPORT = "ONO"
    CIUDAD_OBREGON_AIRPORT = "CEN"
    ONSLOW_AIRPORT = "ONS"
    OSTAFYEVO_INTERNATIONAL_BUSINESS_AIRPORT = "OSF"
    OSIJEK_AIRPORT = "OSI"
    OL_SEKI_AIRPORT = "OSJ"
    MONTEZUMA_COUNTY_AIRPORT = "CEZ"
    CARLOS_ROVIROSA_PEREZ_INTERNATIONAL_AIRPORT = "VSA"
    LES_ANGADES_AIRPORT = "OUD"
    OULU_AIRPORT = "OUL"
    DONEGAL_AIRPORT = "CFN"
    NOVOSIBIRSK_TOLMACHEVO_AIRPORT = "OVB"
    SOVETSKY_AIRPORT = "OVS"
    DAVIESS_COUNTY_AIRPORT = "OWB"
    LABO_AIRPORT = "OZC"
    ZAGORA_AIRPORT = "OZG"
    CLERMONT_FERRAND_AUVERGNE_AIRPORT = "CFE"
    COFFS_HARBOUR_AIRPORT = "CFS"
    MARCOS_A_GELABERT_INTERNATIONAL_AIRPORT = "PAC"
    JAIME_GONZALEZ_AIRPORT = "CFG"
    OUARZAZATE_AIRPORT = "OZZ"
    PAULO_AFONSO_AIRPORT = "PAV"
    CHLEF_INTERNATIONAL_AIRPORT = "CFK"
    IOANNIS_KAPODISTRIAS_AIRPORT = "CFU"
    CHANGDE_AIRPORT = "CGD"
    NOUADHIBOU_AIRPORT = "NDB"
    ES_SENIA_AIRPORT = "ORN"
    CHICO_MUNICIPAL_AIRPORT = "CIC"
    PAROS_AIRPORT = "PAS"
    JAY_PRAKASH_NARAYAN_INTERNATIONAL_AIRPORT = "PAT"
    ALEXANDER_BAY_AIRPORT = "ALJ"
    CAPITAN_ROLDEN_AIRPORT = "PCL"
    PALM_BEACH_INTERNATIONAL_AIRPORT = "PBI"
    ZANDERIJ_INTERNATIONAL_AIRPORT = "PBM"
    PLETTENBERG_BAY_AIRPORT = "PBZ"
    CHARLOTTESVILLE_ALBEMARLE_AIRPORT = "CHO"
    PRAIRIE_DU_CHIEN_MUNICIPAL_AIRPORT = "PCD"
    PERTH_AIRPORT = "PER"
    CHANIA_INTERNATIONAL_AIRPORT = "CHQ"
    PETROZAVODSK_AIRPORT = "PES"
    CHANGZHI_AIRPORT = "CIH"
    COMISO_AIRPORT = "CIY"
    FEDERAL_AIRPORT = "PET"
    WICK_AIRPORT = "WIC"
    MINANGKABAU_INTERNATIONAL_AIRPORT = "PDG"
    JOAO_PAULO_II_AIRPORT = "PDL"
    CHUMPHON_AIRPORT = "CJM"
    ABRAHAM_GONZALEZ_INTERNATIONAL_AIRPORT = "CJS"
    EASTERN_OREGON_REGIONAL_AIRPORT = "PDT"
    PORTLAND_INTERNATIONAL_AIRPORT = "PDX"
    PECHORA_AIRPORT = "PEX"
    ALAMARVDASHT_AIRPORT = "PGU"
    PERIGUEUX_AIRPORT = "PGX"
    COMTE_ANTONIO_AMILTON_BERALDO_AIRPORT = "PGZ"
    CLEVELAND_HOPKINS_INTERNATIONAL_AIRPORT = "CLE"
    PASSO_FUNDO_AIRPORT = "PFB"
    PAPHOS_INTERNATIONAL_AIRPORT = "PFO"
    AVRAM_IANCU_CLUJ_INTERNATIONAL_AIRPORT = "CLJ"
    EASTERWOOD_AIRPORT = "CLL"
    PANTNAGAR_AIRPORT = "PGH"
    DEPATI_AMIR_AIRPORT = "PGK"
    BULI_AIRPORT = "PGQ"
    HOUGHTON_COUNTY_AIRPORT = "CMX"
    TANCREDO_NEVES_INTERNATIONAL_AIRPORT = "CNF"
    PITT_GREENVILLE_AIRPORT = "PGV"
    PORT_HARCOURT_INTERNATIONAL_AIRPORT = "PHC"
    NEWPORT_NEWS_WILLIAMSBURG_INTERNATIONAL_AIRPORT = "PHF"
    PHITSANULOK_AIRPORT = "PHS"
    WOOD_COUNTY_AIRPORT = "PKB"
    PETROPAVLOVSK_KAMCHATSKY_AIRPORT = "PKC"
    KANNUR_INTERNATIONAL_AIRPORT = "CNN"
    PHALABORWA_AIRPORT = "PHW"
    PHOENIX_SKY_HARBOR_INTERNATIONAL_AIRPORT = "PHX"
    PEORIA_INTERNATIONAL_AIRPORT = "PIA"
    MAYA_MAYA_AIRPORT = "BZV"
    WILLARD_UNIVERSITY_AIRPORT = "CMI"
    CAIRNS_AIRPORT = "CNS"
    CHIANG_MAI_INTERNATIONAL_AIRPORT = "CNX"
    SEGE_AIRPORT = "EGM"
    HATTIESBURG_LAUREL_REGIONAL_AIRPORT = "PIB"
    ST_PETERSBURG_CLEARWATER_INTERNATIONAL_AIRPORT = "PIE"
    POCATELLO_REGIONAL_AIRPORT = "PIH"
    PIERRE_REGIONAL_AIRPORT = "PIR"
    BELO_HORIZONTE_AIRPORT = "PLU"
    CHARLEROI_BRUSSELS_SOUTH_AIRPORT = "CRL"
    RABIL_AIRPORT = "BVC"
    CRAIOVA_AIRPORT = "CRA"
    WAWI_AIRPORT = "PMA"
    GRAND_STRAND_AIRPORT = "CRE"
    LA_PALMDALE_REGIONAL_AIRPORT = "PMD"
    NORTHERN_ROCKIES_REGIONAL_AIRPORT = "YYE"
    PENTICTON_AIRPORT = "YYF"
    CHARLOTTETOWN_AIRPORT = "YYG"
    VICTORIA_INTERNATIONAL_AIRPORT = "YYJ"
    SUPADIO_INTERNATIONAL_AIRPORT = "PNK"
    JACKSONS_INTERNATIONAL_AIRPORT = "POM"
    ARBA_MINTCH_AIRPORT = "AMH"
    MAWELLA_LAGOON_AIRPORT = "DIW"
    PETROLINA_INTERNATIONAL_AIRPORT = "PNZ"
    CATANIA_FONTANAROSSA_AIRPORT = "CTA"
    ZHANGYE_GANZHOU_AIRPORT = "YZY"
    ZADAR_AIRPORT = "ZAD"
    ZAGREB_INTERNATIONAL_AIRPORT = "ZAG"
    ZAMBOANGA_INTERNATIONAL_AIRPORT = "ZAM"
    ALZINTAN_AIRPORT = "ZIS"
    RAFAEL_NUNEZ_INTERNATIONAL_AIRPORT = "CTG"
    KANGIQSUALUJJUAQ_AIRPORT = "XGR"
    CULIACAN_INTERNATIONAL_AIRPORT = "CUL"
    CANCUN_INTERNATIONAL_AIRPORT = "CUN"
    PORI_AIRPORT = "POR"
    PHU_QUOC_AIRPORT = "PQC"
    CURACAO_INTERNATIONAL_AIRPORT = "CUR"
    GEN_FIERRO_VILLALOBOS_AIRPORT = "CUU"
    PRESQUE_ISLE_MUNICIPAL_AIRPORT = "PQI"
    PIARCO_INTERNATIONAL_AIRPORT = "POS"
    POZNAN_AIRPORT = "POZ"
    ALEJANDRO_VELASCO_ASTETE_INTERNATIONAL_AIRPORT = "CUZ"
    CINCINNATI_NORTHERN_KENTUCKY_AIRPORT = "CVG"
    PETROPAVLOVSK_AIRPORT = "PPK"
    GUILLERMO_LEON_VALENCIA_AIRPORT = "PPN"
    PARAPARAUMU_AIRPORT = "PPQ"
    PUERTO_PRINCESA_INTERNATIONAL_AIRPORT = "PPS"
    GENERAL_MARIANO_MATAMOROS_AIRPORT = "CVJ"
    CIUDAD_VICTORIA_AIRPORT = "CVM"
    PALESTINE_MUNICIPALCIPAL_AIRPORT = "PSN"
    CANO_AIRPORT = "PSO"
    CHRISTMAS_ISLAND_AIRPORT = "CXI"
    HUGO_CANTERGIANI_REGIONAL_AIRPORT = "CXJ"
    CAM_RANH_INTERNATIONAL_AIRPORT = "CXR"
    AXUM_AIRPORT = "AXU"
    CENTRAL_WISCONSIN_AIRPORT = "CWA"
    AFONSO_PENA_INTERNATIONAL_AIRPORT = "CWB"
    CHERNIVTSI_INTERNATIONAL_AIRPORT = "CWC"
    CANGYUAN_WASHAN_AIRPORT = "CWJ"
    CARDIFF_AIRPORT = "CWL"
    COCHISE_COUNTY_AIRPORT = "CWX"
    COXS_BAZAR_AIRPORT = "CXB"
    CHITINA_AIRPORT = "CXC"
    CHOISEUL_BAY_AIRPORT = "CHY"
    PILOT_STATION_AIRPORT = "PQS"
    KUGLUKTUK_AIRPORT = "YCO"
    CHIAYI_AIRPORT = "CYI"
    TOBOLSK_REMEZOV_AIRPORT = "RMZ"
    COMTE_ROLIM_ADOLFO_AMARO_STATE_AIRPORT = "QDV"
    KEYSTONE_AIRPORT = "QKS"
    SINDHUDURG_AIRPORT = "SDW"
    CAYO_LARGO_DEL_SUR_AIRPORT = "CYO"
    CALBAYOG_AIRPORT = "CYP"
    RAMON_VILLEDA_MORALES_INTERNATIONAL_AIRPORT = "SAP"
    CHERSKIY_AIRPORT = "CYX"
    ORLANDO_SANFORD_INTERNATIONAL_AIRPORT = "SFB"
    CAUAYAN_AIRPORT = "CYZ"
    TRI_TOWNSHIP_AIRPORT = "SFY"
    SURGUT_AIRPORT = "SGC"
    SPRINGFIELD_BRANSON_NATIONAL_AIRPORT = "SGF"
    TAN_SON_NHAT_INTERNATIONAL_AIRPORT = "SGN"
    THESSALONIKI_INTERNATIONAL_AIRPORT = "SKG"
    STOKMARKNES_SKAGEN_AIRPORT = "SKN"
    GEORGE_F_L_CHARLES_AIRPORT = "SLU"
    SALEKHARD_AIRPORT = "SLY"
    SOFIA_AIRPORT = "SOF"
    SOGNDAL_AIRPORT = "SOG"
    SORKJOSEN_AIRPORT = "SOJ"
    CHUATHBALUK_AIRPORT = "CHU"
    COZUMEL_AIRPORT = "CZM"
    CAMPO_INTERNACIONAL_AIRPORT = "CZS"
    COROZAL_AIRPORT = "CZU"
    AKTION_AIRPORT = "PVK"
    PIKE_COUNTY_AIRPORT = "PVL"
    CHANGZHOU_AIRPORT = "CZX"
    INUVIK_MIKE_ZUBKO_AIRPORT = "YEV"
    PROVO_AIRPORT = "PVU"
    PEVEK_AIRPORT = "PWE"
    DAYTONA_BEACH_INTERNATIONAL_AIRPORT = "DAB"
    CHICAGO_EXECUTIVE_AIRPORT = "PWK"
    HAZRAT_SHAHJALAL_INTERNATIONAL_AIRPORT = "DAC"
    PAVLODAR_AIRPORT = "PWQ"
    DA_NANG_INTERNATIONAL_AIRPORT = "DAD"
    MAZAMET_AIRPORT = "DCM"
    DAOCHENG_YADING_AIRPORT = "DCY"
    PORTO_SANTO_AIRPORT = "PXO"
    SHACHE_AIRPORT = "QSZ"
    BIG_BEAR_CITY_AIRPORT = "RBF"
    COTONOU_AIRPORT = "COO"
    AUPALUK_AIRPORT = "YPJ"
    RAIATEA_AIRPORT = "RFP"
    ONEIDA_COUNTY_AIRPORT = "RHI"
    RHODES_AIRPORT = "RHO"
    DAMASCUS_INTERNATIONAL_AIRPORT = "DAM"
    KALLINGE_AIRPORT = "RNB"
    RIJEKA_AIRPORT = "RJK"
    DATONG_AIRPORT = "DAT"
    ENRIQUE_MALEK_AIRPORT = "DAV"
    DAZHOU_HESHI_AIRPORT = "DAX"
    JAMES_M_COX_DAYTON_INTERNATIONAL_AIRPORT = "DAY"
    DEBRECEN_AIRPORT = "DEB"
    DEZFUL_AIRPORT = "DEF"
    AGONCILLO_AIRPORT = "RJL"
    MARINDA_AIRPORT = "RJM"
    WASKAGANISH_AIRPORT = "YKQ"
    DUBBO_CITY_REGIONAL_AIRPORT = "DBO"
    DUBUQUE_MUNICIPAL_AIRPORT = "DBQ"
    DUBROVNIK_AIRPORT = "DBV"
    POSTVILLE_AIRPORT = "YSO"
    KNOX_COUNTY_REGIONAL_AIRPORT = "RKD"
    ROSKILDE_AIRPORT = "RKE"
    ROCK_SPRINGS_SWEETWATER_COUNTY_AIRPORT = "RKS"
    RAS_AL_KHAIMAH_INTERNATIONAL_AIRPORT = "RKT"
    LAAGE_AIRPORT = "RLG"
    RENNES_AIRPORT = "RNS"
    ROBERTS_INTERNATIONAL_AIRPORT = "ROB"
    ROI_ET_AIRPORT = "ROI"
    ROCKHAMPTON_AIRPORT = "ROK"
    MAAVAARULAA_AIRPORT = "RUL"
    REUNION_ROLAND_GARROS_AIRPORT = "RUN"
    ROVANIEMI_AIRPORT = "RVN"
    RZESZOW_INTERNATIONAL_AIRPORT = "RZE"
    DECATUR_AIRPORT = "DEC"
    DEHRA_DUN_AIRPORT = "DED"
    MENDELEYEVO_AIRPORT = "DEE"
    INDIRA_GANDHI_INTERNATIONAL_AIRPORT = "DEL"
    FORT_CHIPEWYAN_AIRPORT = "YPY"
    DENVER_INTERNATIONAL_AIRPORT = "DEN"
    DALLAS_FORT_WORTH_INTERNATIONAL_AIRPORT = "DFW"
    GUADALUPE_VICTORIA_AIRPORT = "DGO"
    SAN_ANTONIO_INTERNATIONAL_AIRPORT = "SAT"
    SABIHA_GOKCEN_INTERNATIONAL_AIRPORT = "SAW"
    SANTA_BARBARA_MUNICIPAL_AIRPORT = "SBA"
    SCOTTSDALE_AIRPORT = "SCF"
    ENSHEIM_AIRPORT = "SCN"
    SANTIAGO_DE_COMPOSTELA_AIRPORT = "SCQ"
    SCANDINAVIAN_MOUNTAINS_AIRPORT = "SCR"
    ANTONIO_MACEO_AIRPORT = "SCU"
    SUCEAVA_AIRPORT = "SCV"
    NORTHWEST_REGIONAL_AIRPORT = "YXT"
    GAGGAL_AIRPORT = "DHM"
    SUNDSVALL_TIMRA_AIRPORT = "SDL"
    DOTHAN_REGIONAL_AIRPORT = "DHN"
    LAS_AMERICAS_INTERNATIONAL_AIRPORT = "SDQ"
    DIBRUGARH_AIRPORT = "DIB"
    NORTH_PEACE_REGIONAL_AIRPORT = "YXJ"
    DIQING_SHANGRI_LA_AIRPORT = "DIG"
    DICKINSON_REGIONAL_AIRPORT = "DIK"
    COMORO_AIRPORT = "DIL"
    DIEN_BIEN_AIRPORT = "DIN"
    DIU_AIRPORT = "DIU"
    DIYARBAKIR_AIRPORT = "DIY"
    SULTAN_THAHA_AIRPORT = "DJB"
    JAMBYL_AIRPORT = "DMB"
    MOSCOW_DOMODEDOVO_AIRPORT = "DME"
    DON_MUEANG_INTERNATIONAL_AIRPORT = "DMK"
    FOND_DU_LAC_AIRPORT = "ZFD"
    BELLA_BELLA_AIRPORT = "ZEL"
    SANTANDER_AIRPORT = "SDR"
    SANTOS_DUMONT_AIRPORT = "SDU"
    SEATTLE_TACOMA_INTERNATIONAL_AIRPORT = "SEA"
    SREDNEKOLYMSK_AIRPORT = "SEK"
    LONDON_SOUTHEND_AIRPORT = "SEN"
    ROBERT_L_BRADSHAW_INTERNATIONAL_AIRPORT = "SKB"
    SAMARKAND_AIRPORT = "SKD"
    QAARSUT_AIRPORT = "JQA"
    SENTANI_AIRPORT = "DJJ"
    LEOPOLD_SEDAR_SENGHOR_INTERNATIONAL_AIRPORT = "DKR"
    SANTO_PEKOA_INTERNATIONAL_AIRPORT = "SON"
    MIRAMARE_AIRPORT = "RMI"
    TAICHUNG_INTERNATIONAL_AIRPORT = "RMQ"
    DOLE_JURA_AIRPORT = "DLE"
    DULUTH_INTERNATIONAL_AIRPORT = "DLH"
    BORNHOLM_AIRPORT = "RNN"
    RENO_TAHOE_INTERNATIONAL_AIRPORT = "RNO"
    LIEN_KHUONG_AIRPORT = "DLI"
    UNIVERSITY_PARK_AIRPORT = "SCE"
    DALAMAN_AIRPORT = "DLM"
    DALNERECHENSK_AIRPORT = "DLR"
    COLUMBIA_GORGE_REGIONAL_THE_DALLES_MUNICIPAL_AIRPORT = "DLS"
    DALI_AIRPORT = "DLU"
    SEYCHELLES_INTERNATIONAL_AIRPORT = "SEZ"
    THE_PAU_PYRENEES_INTERNATIONAL_AIRPORT = "PUF"
    POINTE_A_PITRE_INTERNATIONAL_AIRPORT = "PTP"
    ATKINSON_MUNICIPAL_AIRPORT = "PTS"
    TOCUMEN_INTERNATIONAL_AIRPORT = "PTY"
    PUEBLO_MEMORIAL_AIRPORT = "PUB"
    PUNTA_CANA_INTERNATIONAL_AIRPORT = "PUJ"
    GIMHAE_INTERNATIONAL_AIRPORT = "PUS"
    DIMAPUR_AIRPORT = "DMU"
    DALLAS_NORTH_AIRPORT = "DNE"
    DNEPROPETROVSK_INTERNATIONAL_AIRPORT = "DNK"
    ATUNG_BUNGSU_AIRPORT = "PXA"
    BAHAR_DAR_AIRPORT = "BJR"
    PLEURTUIT_AIRPORT = "DNR"
    SAMOS_AIRPORT = "SMI"
    PUERTO_ESCONDIDO_AIRPORT = "PXM"
    GANGTOK_PAKYONG_AIRPORT = "PYG"
    ABA_TENNA_D_YILMA_AIRPORT = "DIR"
    MELITA_AIRPORT = "DJE"
    CARDAK_AIRPORT = "DNZ"
    HAMAD_INTERNATIONAL_AIRPORT = "DOH"
    SAINT_GATIEN_AIRPORT = "DOL"
    PORT_SUDAN_AIRPORT = "PZU"
    LAQUILA_PRETURO_AIRPORT = "QAQ"
    DOURADOS_AIRPORT = "DOU"
    DONGYING_AIRPORT = "DOY"
    DUPAGE_AIRPORT = "DPA"
    IGLOOLIK_AIRPORT = "YGT"
    ASOSA_AIRPORT = "ASO"
    DUNDEE_AIRPORT = "DND"
    DIPOLOG_AIRPORT = "DPL"
    NGURAH_RAI_INTERNATIONAL_AIRPORT = "DPS"
    DAQING_SHI_AIRPORT = "DQA"
    DURANGO_LA_PLATA_COUNTY_AIRPORT = "DRO"
    DEL_RIO_INTERNATIONAL_AIRPORT = "DRT"
    DHARAVANDHOO_AIRPORT = "DRV"
    DARWIN_INTERNATIONAL_AIRPORT = "DRW"
    DONCASTER_SHEFFIELD_AIRPORT = "DSA"
    DES_MOINES_INTERNATIONAL_AIRPORT = "DSM"
    ORDOS_EJIN_HORO_AIRPORT = "DSN"
    BLAISE_DIAGNE_INTERNATIONAL_AIRPORT = "DSS"
    PAI_AIRPORT = "PYY"
    PIETERMARITZBURG_AIRPORT = "PZB"
    MANUEL_CARLOS_PIAR_GUAYANA_AIRPORT = "PZO"
    BUJUMBURA_INTERNATIONAL_AIRPORT = "BJM"
    SISINGAMANGARAJA_XII_INTERNATIONAL_AIRPORT = "DTB"
    DORTMUND_AIRPORT = "DTM"
    WUDALIANCHI_DEDU_AIRPORT = "DTU"
    KING_SHAKA_INTERNATIONAL_AIRPORT = "DUR"
    DEVILS_LAKE_AIRPORT = "DVL"
    FRANCISCO_BANGOY_INTL_AIRPORT = "DVO"
    SALE_AIRPORT = "RBA"
    ARAR_AIRPORT = "RAE"
    ROSEBURG_MUNICIPAL_AIRPORT = "RBG"
    NELSON_MANDELA_INTERNATIONAL_AIRPORT = "RAI"
    MENARA_AIRPORT = "RAK"
    RAPID_CITY_REGIONAL_AIRPORT = "RAP"
    RAROTONGA_AIRPORT = "RAR"
    RASHT_AIRPORT = "RAS"
    EL_ARISH_INTERNATIONAL_AIRPORT = "AAC"
    NEERLERIT_INAAT_AIRPORT = "CNP"
    RADOM_AIRPORT = "RDO"
    MARCILLAC_AIRPORT = "RDZ"
    DETROIT_METROPOLITAN_WAYNE_COUNTY_AIRPORT = "DTW"
    DUBLIN_AIRPORT = "DUB"
    DUNEDIN_INTERNATIONAL_AIRPORT = "DUD"
    RICHARDS_BAY_AIRPORT = "RCB"
    RIOHACHA_AIRPORT = "RCH"
    REDDING_MUNICIPAL_AIRPORT = "RDD"
    ROBERTS_FIELD_REDMOND_MUNICIPAL_AIRPORT = "RDM"
    KAZI_NAZRUL_ISLAM_AIRPORT = "RDP"
    PHOENIX_DEER_VALLEY_AIRPORT = "DVT"
    DAWADMI_AIRPORT = "DWD"
    RALEIGH_DURHAM_INTERNATIONAL_AIRPORT = "RDU"
    GUARARAPES_GILBERTO_FREYRE_INTERNATIONAL_AIRPORT = "REC"
    CHICAGO_ROCKFORD_INTERNATIONAL_AIRPORT = "RFD"
    RIO_GRANDE_AIRPORT = "RGA"
    RIO_HONDO_AIRPORT = "RHD"
    ASSIUT_AIRPORT = "ATZ"
    CAIRO_INTERNATIONAL_AIRPORT = "CAI"
    DANBURY_MUNICIPAL_AIRPORT = "DXR"
    ANADYR_AIRPORT = "DYR"
    DUSHANBE_AIRPORT = "DYU"
    DZAOUDZI_AIRPORT = "DZA"
    ZHEZHAZGAN_AIRPORT = "DZN"
    KEARNEY_REGIONAL_AIRPORT = "EAR"
    SAN_SEBASTIAN_AIRPORT = "EAS"
    EAU_CLAIRE_AIRPORT = "EAU"
    MARINA_DI_CAMPO_AIRPORT = "EBA"
    GIRUA_AIRPORT = "PNP"
    SANTA_MARIA_AIRPORT = "RIA"
    GEN_BUECH_AIRPORT = "RIB"
    RAJAHMUNDRY_AIRPORT = "RJA"
    RAJSHAHI_AIRPORT = "RJH"
    ASWAN_AIRPORT = "ASW"
    ESBJERG_AIRPORT = "EBJ"
    ERBIL_INTERNATIONAL_AIRPORT = "EBL"
    REYKJAVIK_INTERNATIONAL_AIRPORT = "RKV"
    ROCKWOOD_MUNICIPAL_AIRPORT = "RKW"
    BOUTHEON_AIRPORT = "EBU"
    COSTA_ESMERALDA_AIRPORT = "ECI"
    ERCAN_AIRPORT = "ECN"
    NORTH_RONALDSAY_AIRPORT = "NRL"
    RODRIGUES_ISLAND_AIRPORT = "RRG"
    ROTA_AIRPORT = "ROP"
    AIRAI_AIRPORT = "ROR"
    PLATOV_INTERNATIONAL_AIRPORT = "ROV"
    ASMARA_INTERNATIONAL_AIRPORT = "ASM"
    JACAREPAGUÁ_AIRPORT = "RRJ"
    SWAMI_VIVEKANANDA_AIRPORT = "RPR"
    RUOQIANG_LOULAN_AIRPORT = "RQA"
    SOUTH_ELEUTHERA_AIRPORT = "RSD"
    KING_KHALED_INTERNATIONAL_AIRPORT = "RUH"
    SARATOV_TSENTRALNY_AIRPORT = "RTW"
    EDINBURGH_AIRPORT = "EDI"
    ELDORET_AIRPORT = "EDL"
    BALIKESIR_KOCA_SEYIT_AIRPORT = "EDO"
    LODWAR_AIRPORT = "LOK"
    RUTLAND_AIRPORT = "RUT"
    RIO_VERDE_AIRPORT = "RVD"
    ROSTOV_AIRPORT = "RVI"
    BOUNDARY_BAY_AIRPORT = "YDT"
    RYUMSJOEN_AIRPORT = "RVK"
    EDAY_AIRPORT = "EOI"
    KEFALLINIA_AIRPORT = "EFL"
    J_YRAUSQUIN_AIRPORT = "SAB"
    SACRAMENTO_EXECUTIVE_AIRPORT = "SAC"
    ROUMANIERES_AIRPORT = "EGC"
    SAVANNAH_HILTON_HEAD_AIRPORT = "SAV"
    EAGLE_COUNTY_AIRPORT = "EGE"
    BELGOROD_AIRPORT = "EGO"
    EINDHOVEN_AIRPORT = "EIN"
    VARIGUIES_AIRPORT = "EJA"
    WEDJH_AIRPORT = "EJH"
    MADANG_AIRPORT = "MAG"
    PINE_ISLAND_AIRPORT = "DUF"
    STOCKTON_AIRPORT = "SCK"
    SYKTYVKAR_AIRPORT = "SCW"
    AKTAU_INTERNATIONAL_AIRPORT = "SCO"
    SAN_CRISTOBAL_AIRPORT = "SCY"
    DOV_HOZ_AIRPORT = "SDV"
    RICHLAND_MUNICIPAL_AIRPORT = "SDY"
    EJIN_BANNER_TAOLAI_AIRPORT = "EJN"
    SEBRING_REGIONAL_AIRPORT = "SEF"
    ELKO_AIRPORT = "EKO"
    SHAKHTYORSK_AIRPORT = "EKS"
    ELCHO_ISLAND_AIRPORT = "ELC"
    SOUTH_ARKANSAS_REGIONAL_AIRPORT = "ELD"
    EL_GOLEA_AIRPORT = "ELG"
    EL_PASO_INTERNATIONAL_AIRPORT = "ELP"
    PRINCE_NAYEF_BIN_ABDULAZIZ_REGIONAL_AIRPORT = "ELQ"
    EAST_LONDON_AIRPORT = "ELS"
    SFAX_EL_MAOU_AIRPORT = "SFA"
    SONDERBORG_AIRPORT = "SGD"
    SIEGERLAND_AIRPORT = "SGE"
    SARGODHA_AIRPORT = "SGI"
    GUEMAR_AIRPORT = "ELU"
    EAST_MIDLANDS_AIRPORT = "EMA"
    EMERALD_AIRPORT = "EMD"
    KENAI_MUNICIPAL_AIRPORT = "ENA"
    H_HASAN_AROEBOESMAN_AIRPORT = "ENE"
    ENSHI_AIRPORT = "ENH"
    ENUGU_AIRPORT = "ENU"
    ERSHILIPU_AIRPORT = "ENY"
    SAINT_GEORGE_MUNICIPAL_AIRPORT = "SGU"
    SINOP_AIRPORT = "SIC"
    LA_GRANDE_AIRPORT = "YGL"
    KENOSHA_REGIONAL_AIRPORT = "ENW"
    ENRIQUE_OLAYA_HERRERA_AIRPORT = "EOH"
    ESPERANCE_AIRPORT = "EPR"
    ESQUEL_AIRPORT = "EQS"
    ERZINCAN_AIRPORT = "ERC"
    ERFURT_AIRPORT = "ERF"
    ERBOGACHEN_AIRPORT = "ERG"
    EROS_AIRPORT = "ERS"
    FES_SAISS_AIRPORT = "FEZ"
    NDJILI_AIRPORT = "FIH"
    GURNEY_AIRPORT = "GUR"
    CHANGI_INTERNATIONAL_AIRPORT = "SIN"
    SHANGHAI_HONGQIAO_INTERNATIONAL_AIRPORT = "SHA"
    SISHEN_AIRPORT = "SIS"
    NAKASHIBETSU_AIRPORT = "SHB"
    SHIHEZI_HUAYUAN_AIRPORT = "SHF"
    SHUNGNAK_AIRPORT = "SHG"
    SHIRAHAMA_AIRPORT = "SHM"
    ERZURUM_AIRPORT = "ERZ"
    ESENBOGA_INTERNATIONAL_AIRPORT = "ESB"
    SHREVEPORT_REGIONAL_AIRPORT = "SHV"
    DELTA_COUNTY_AIRPORT = "ESC"
    SHARURAH_AIRPORT = "SHW"
    AMILCAR_CABRAL_INTERNATIONAL_AIRPORT = "SID"
    ELISTA_AIRPORT = "ESL"
    ESMERALDAS_AIRPORT = "ESM"
    ESSAOUIRA_AIRPORT = "ESU"
    EUGENE_AIRPORT = "EUG"
    FRANKFURT_AIRPORT = "FRA"
    FERA_ISLAND_AIRPORT = "FRE"
    PITUFFIK_AIRPORT = "THU"
    SAO_JORGE_ISLAND_AIRPORT = "SJZ"
    SKOPJE_ALEXANDER_THE_GREAT_AIRPORT = "SKP"
    SVETLAYA_AIRPORT = "ETL"
    CORONEL_ARTILLERIA_VICTOR_LARREA_AIRPORT = "ETR"
    METZ_NANCY_LORRAINE_AIRPORT = "ETZ"
    SIALKOT_AIRPORT = "SKT"
    SKIROS_AIRPORT = "SKU"
    SARANSK_AIRPORT = "SKX"
    TAKORADI_AIRPORT = "TKD"
    HASSAN_I_AIRPORT = "EUN"
    F_D_ROOSEVELT_AIRPORT = "EUX"
    HARSTAD_NARVIK_AIRPORT_EVENES = "EVE"
    SVEG_AIRPORT = "EVG"
    PLAN_DE_GUADALUPE_INTERNATIONAL_AIRPORT = "SLW"
    VILA_DO_PORTO_AIRPORT = "SMA"
    H_ASAN_AIRPORT = "SMQ"
    SAKON_NAKHON_AIRPORT = "SNO"
    ZVARTNOTS_INTERNATIONAL_AIRPORT = "EVN"
    EVANSVILLE_REGIONAL_AIRPORT = "EVV"
    NEW_BEDFORD_AIRPORT = "EWB"
    COASTAL_CAROLINA_REGIONAL_AIRPORT = "EWN"
    BELOYARSKY_AIRPORT = "EYK"
    FLORA_AIRPORT = "FRO"
    SAINT_PIERRE_AIRPORT = "FSP"
    FORT_LAUDERDALE_EXECUTIVE_AIRPORT = "FXE"
    LOKPRIYA_GOPINATH_BORDOLOI_INTERNATIONAL_AIRPORT = "GAU"
    GORGON_AIRPORT = "GBT"
    EBON_AIRPORT = "EBO"
    THANDWE_AIRPORT = "SNW"
    KOTOKA_INTERNATIONAL_AIRPORT = "ACC"
    MONTOIR_AIRPORT = "SNR"
    SANTA_CLARA_AIRPORT = "SNU"
    ADI_SUMARMO_INTERNATIONAL_AIRPORT = "SOC"
    ELAZIG_AIRPORT = "EZS"
    RED_LAKE_AIRPORT = "YRL"
    VAGAR_AIRPORT = "FAE"
    SAIPAN_INTERNATIONAL_AIRPORT = "SPN"
    HECTOR_INTERNATIONAL_AIRPORT = "FAR"
    FRESNO_YOSEMITE_INTERNATIONAL_AIRPORT = "FAT"
    FAYETTEVILLE_REGIONAL_AIRPORT = "FAY"
    FAIZABAD_AIRPORT = "FBD"
    LUBUMBASHI_INTERNATIONAL_AIRPORT = "FBM"
    QAANAAQ_AIRPORT = "NAQ"
    SPLIT_AIRPORT = "SPU"
    SHANGRAO_SANQINGSHAN_AIRPORT = "SQD"
    SANMING_SHAXIAN_AIRPORT = "SQJ"
    STANSTED_AIRPORT = "STN"
    SAIDPUR_AIRPORT = "SPD"
    HOUSTON_GULF_AIRPORT = "SPX"
    GLACIER_PARK_INTERNATIONAL_AIRPORT = "FCA"
    LEONARDO_DA_VINCI_FIUMICINO_AIRPORT = "FCO"
    BRINGELAND_AIRPORT = "FDE"
    MARTINIQUE_AIME_CESAIRE_INTERNATIONAL_AIRPORT = "FDF"
    FRIEDRICHSHAFEN_AIRPORT = "FDH"
    CAMPBELL_COUNTY_AIRPORT = "GCC"
    GENERAL_SANTOS_INTERNATIONAL_AIRPORT = "GES"
    SORONG_AIRPORT = "SQG"
    KANGIQSUJUAQ_AIRPORT = "YWB"
    FERGANA_AIRPORT = "FEG"
    SIAULIAI_INTERNATIONAL_AIRPORT = "SQQ"
    FERNANDO_DE_NORONHA_AIRPORT = "FEN"
    ACHMAD_YANI_INTERNATIONAL_AIRPORT = "SRG"
    STORD_AIRPORT = "SRP"
    DASHTE_NAZ_AIRPORT = "SRY"
    TEMINDUNG_AIRPORT = "SRI"
    FAGALI_I_AIRPORT = "FGI"
    MALABO_AIRPORT = "SSG"
    SEQUIM_VALLEY_AIRPORT = "SQV"
    MAKKOVIK_AIRPORT = "YMN"
    SARASOTA_BRADENTON_INTERNATIONAL_AIRPORT = "SRQ"
    DEPUTADO_LUIS_EDUARDO_MAGALHAES_INTERNATIONAL_AIRPORT = "SSA"
    SHARM_EL_SHEIKH_AIRPORT = "SSH"
    STOKKA_AIRPORT = "SSJ"
    SANTAREM_MAESTRO_WILSON_FONSECA_AIRPORT = "STM"
    BANGOKA_INTERNATIONAL_AIRPORT = "FKI"
    VENANGO_REGIONAL_AIRPORT = "FKL"
    FAK_FAK_AIRPORT = "FKQ"
    FUKUSHIMA_AIRPORT = "FKS"
    CAPITOLIO_AIRPORT = "FLA"
    FLAGSTAFF_PULLIAM_AIRPORT = "FLG"
    HERCILIO_LUZ_INTERNATIONAL_AIRPORT = "FLN"
    FLORENCE_AIRPORT = "FLO"
    FIRENZE_PERETOLA_AIRPORT = "FLR"
    GERALDTON_AIRPORT = "GET"
    GALLIVARE_AIRPORT = "GEV"
    SONOMA_COUNTY_AIRPORT = "STS"
    STUTTGART_AIRPORT = "STR"
    STAVROPOL_AIRPORT = "STW"
    HELLE_AIRPORT = "SVJ"
    FLINDERS_ISLAND_AIRPORT = "FLS"
    FERDINAND_LUMBAN_TOBING_AIRPORT = "FLZ"
    EL_PUCU_AIRPORT = "FMA"
    KOLTSOVO_INTERNATIONAL_AIRPORT = "SVX"
    KALEMIE_AIRPORT = "FMI"
    MEMMINGEN_ALLGAU_AIRPORT = "FMM"
    FOUR_CORNERS_REGIONAL_AIRPORT = "FMN"
    MUNSTER_OSNABRUCK_INTERNATIONAL_AIRPORT = "FMO"
    GARONS_AIRPORT = "FNI"
    PYONGYANG_SUNAN_INTERNATIONAL_AIRPORT = "FNJ"
    GRIFFITH_AIRPORT = "GFF"
    GRAND_FORKS_INTERNATIONAL_AIRPORT = "GFK"
    GRAFTON_AIRPORT = "GFN"
    FRIEDMAN_MEMORIAL_AIRPORT = "SUN"
    NAUSORI_AIRPORT = "SUV"
    RICHARD_I_BONG_AIRPORT = "SUW"
    SIOUX_GATEWAY_AIRPORT = "SUX"
    SAVOONGA_AIRPORT = "SVA"
    GRANT_COUNTY_AIRPORT = "SVC"
    STAVANGER_AIRPORT_SOLA = "SVG"
    BISHOP_INTERNATIONAL_AIRPORT = "FNT"
    SAVONLINNA_AIRPORT = "SVL"
    SHEREMETYEVO_INTERNATIONAL_AIRPORT = "SVO"
    FORT_DODGE_AIRPORT = "FOD"
    SCHONEFELD_AIRPORT = "SXF"
    SAUMLAKI_OLILIT_AIRPORT = "SXK"
    SRINAGAR_INTERNATIONAL_AIRPORT = "SXR"
    FORTUNA_AIRPORT = "FON"
    PINTO_MARTINS_AIRPORT = "FOR"
    GRAND_BAHAMA_INTERNATIONAL_AIRPORT = "FPO"
    STRONSAY_AIRPORT = "SOY"
    EL_FASHER_AIRPORT = "ELF"
    SANTA_ELENA_AIRPORT = "FRS"
    MANAS_INTERNATIONAL_AIRPORT = "FRU"
    FRANCISTOWN_AIRPORT = "FRW"
    SUD_CORSE_AIRPORT = "FSC"
    SIOUX_FALLS_REGIONAL_AIRPORT_JOE_FOSS_FIELD = "FSD"
    FORT_SMITH_REGIONAL_AIRPORT = "FSM"
    TOFINO_AIRPORT = "YAZ"
    CAMPBELL_RIVER_AIRPORT = "YBL"
    OUVEA_AIRPORT = "UVE"
    HEWANORRA_AIRPORT = "UVF"
    VILLA_INTERNATIONAL_AIRPORT_MAAMIGILI = "VAM"
    SIVAS_AIRPORT = "VAS"
    LUPEPAUU_AIRPORT = "VAV"
    MANDALAY_CHANMYATHAZI_AIRPORT = "VBC"
    BOKPYIN_AIRPORT = "VBP"
    MONTICHIARI_AIRPORT = "VBS"
    VISBY_AIRPORT = "VBY"
    GENEINA_AIRPORT = "EGN"
    SHIZUOKA_AIRPORT = "FSZ"
    MARILLAC_AIRPORT = "FTU"
    FUERTEVENTURA_AIRPORT = "FUE"
    FUYANG_AIRPORT = "FUG"
    FUKUE_AIRPORT = "FUJ"
    FUKUOKA_AIRPORT = "FUK"
    VIRACOPOS_AIRPORT = "VCP"
    DONG_HOI_AIRPORT = "VDH"
    VADSO_AIRPORT = "VDS"
    FUNAFUTI_ATOL_INTERNATIONAL_AIRPORT = "FUN"
    FUOSHAN_AIRPORT = "FUO"
    FORT_WAYNE_INTERNATIONAL_AIRPORT = "FWA"
    VIJAYAWADA_AIRPORT = "VGA"
    VOLOGDA_AIRPORT = "VGD"
    VIGO_AIRPORT = "VGO"
    VIRGIN_GORDA_AIRPORT = "VIJ"
    DAKHLA_AIRPORT = "VIL"
    VALDOSTA_REGIONAL_AIRPORT = "VLD"
    VALLADOLID_AIRPORT = "VLL"
    ARTURO_MICHELENA_INTERNATIONAL_AIRPORT = "VLN"
    ANGLESEY_AIRPORT = "VLY"
    FUYUN_KOKTOKAY_AIRPORT = "FYN"
    JUNMACHI_AIRPORT = "GAJ"
    GAMBELL_AIRPORT = "GAM"
    GAN_SEENU_AIRPORT = "GAN"
    GAYA_AIRPORT = "GAY"
    GABALA_INTERNATIONAL_AIRPORT = "GBB"
    SIR_SERETSE_KHAMA_INTERNATIONAL_AIRPORT = "GBE"
    GREGG_COUNTY_AIRPORT = "GGG"
    VAN_NUYS_AIRPORT = "VNY"
    VOLGOGRAD_INTERNATIONAL_AIRPORT = "VOG"
    VORONEZH_AIRPORT = "VOZ"
    VERO_BEACH_MUNICIPAL_AIRPORT = "VRB"
    VIRAC_AIRPORT = "VRC"
    WATTAY_INTERNATIONAL_AIRPORT = "VTE"
    VALLEDUPAR_AIRPORT = "VUP"
    VIRU_VIRU_INTERNATIONAL_AIRPORT = "VVI"
    LICHINGA_AIRPORT = "VXC"
    CESARIA_EVORA_INTERNATIONAL_AIRPORT = "VXE"
    VAXJO_AIRPORT = "VXO"
    WUHU_XUANZHOU_AIRPORT = "WHA"
    WHAKATANE_AIRPORT = "WHK"
    WALTER_J_KOLADZA_AIRPORT = "GBR"
    GARDEN_CITY_MUNICIPAL_AIRPORT = "GCK"
    ZUNYI_MAOTAI_AIRPORT = "WMT"
    OWEN_ROBERTS_INTERNATIONAL_AIRPORT = "GCM"
    MATAHORA_AIRPORT = "WNI"
    GODE_IDDIDOLE_AIRPORT = "GDE"
    DON_MIGUEL_HIDAL_Y_COSTILLA_INTERNATIONAL_AIRPORT = "GDL"
    GDANSK_LECH_WALESA_AIRPORT = "GDN"
    KAKAMEGA_AIRPORT = "GGM"
    WAPENAMANDA_AIRPORT = "WBM"
    WUHAI_AIRPORT = "WUA"
    MURRIN_MURRIN_AIRPORT = "WUI"
    XINZHOU_WUTAISHAN_AIRPORT = "WUT"
    SUNAN_SHUOFANG_INTERNATIONAL_AIRPORT = "WUX"
    GONDAR_AIRPORT = "GDQ"
    DAWSON_COMMUNITY_AIRPORT = "GDV"
    BORAM_AIRPORT = "WWK"
    NEW_CHITOSE_AIRPORT = "CTS"
    CAMILO_DAZA_INTERNATIONAL_AIRPORT = "CUC"
    LEVALDIGI_AIRPORT = "CUF"
    WANXIAN_AIRPORT = "WXN"
    MAGADAN_AIRPORT = "GDX"
    WHYALLA_AIRPORT = "WYA"
    WUNNUMMIN_LAKE_AIRPORT = "WNN"
    GELENDZIK_AIRPORT = "GDZ"
    NOUMEA_MAGENTA_AIRPORT = "GEA"
    SPOKANE_INTERNATIONAL_AIRPORT = "GEG"
    EXUMA_INTERNATIONAL_AIRPORT = "GGT"
    GLASGOW_INTERNATIONAL_AIRPORT = "GGW"
    SAGUENAY_BAGOTVILLE_AIRPORT = "YBG"
    OVDA_AIRPORT = "VDA"
    HIERRO_AIRPORT = "VDE"
    VANIMO_AIRPORT = "VAI"
    VITORIA_DA_CONQUISTA_AIRPORT = "VDC"
    VILHELMINA_AIRPORT = "VHM"
    VINH_AIRPORT = "VII"
    HAVRYSHIVKA_VINNYTSIA_INTERNATIONAL_AIRPORT = "VIN"
    VITORIA_AIRPORT = "VIT"
    VIENNA_INTERNATIONAL_AIRPORT = "VIE"
    VNUKOVO_AIRPORT = "VKO"
    VORKUTA_AIRPORT = "VKT"
    VILANCULOS_AIRPORT = "VNX"
    OSLO_GARDERMOEN_AIRPORT = "GEN"
    CAMBRIDGE_BAY_AIRPORT = "YCB"
    VASTERAS_HASSLO_AIRPORT = "VST"
    VISHAKHAPATNAM_AIRPORT = "VTZ"
    LA_VANGUARDIA_AIRPORT = "VVC"
    ILLIZI_AIRPORT = "VVZ"
    VERONA_VILLAFRANCA_AIRPORT = "VRN"
    VELIKIJ_USTYUG_AIRPORT = "VUS"
    VLADIVOSTOK_INTERNATIONAL_AIRPORT = "VVO"
    DEER_LAKE_REGIONAL_AIRPORT = "YDF"
    CAROSUE_DAM_AIRPORT = "WCD"
    NADZAB_AIRPORT = "LAE"
    WAINGAPU_AIRPORT = "WGP"
    WEIHAI_INTERNATIONAL_AIRPORT = "WEH"
    WEIPA_AIRPORT = "WEI"
    WAGGA_WAGGA_AIRPORT = "WGA"
    LONDOLOZI_AIRPORT = "LDZ"
    ARUSHA_AIRPORT = "ARK"
    KILWA_MASOKO_AIRPORT = "KIY"
    WILSON_AIRPORT = "WIL"
    WINTON_AIRPORT = "WIN"
    QUEENSTOWN_AIRPORT = "ZQN"
    BUKOBA_AIRPORT = "BKZ"
    ZHANGJIAKOU_NINGYUAN_AIRPORT = "ZQZ"
    JULIUS_NYERERE_INTERNATIONAL_AIRPORT = "DAR"
    WELLINGTON_INTERNATIONAL_AIRPORT = "WLG"
    WEST_ANGELAS_AIRPORT = "WLP"
    WALLIS_ISLAND_AIRPORT = "WLS"
    DODOMA_AIRPORT = "DOD"
    LAESO_AIRPORT = "BYR"
    DE_KOOY_DEN_HELDER_AIRPORT = "DHR"
    NANAIMO_AIRPORT = "YCD"
    WARSAW_MODLIN_AIRPORT = "WMI"
    WHITE_MOUNTAIN_AIRPORT = "WMO"
    LONDON_CITY_AIRPORT = "LCY"
    WENSHAN_PUZHEHEI_AIRPORT = "WNH"
    WAMENA_AIRPORT = "WMX"
    CHONGQING_WUSHAN_AIRPORT = "WSK"
    PIEDMONT_TRIAD_INTERNATIONAL_AIRPORT = "GSO"
    GREENVILLE_SPARTANBURG_INTERNATIONAL_AIRPORT = "GSP"
    WROCLAW_AIRPORT = "WRO"
    SARATOV_GAGARIN_AIRPORT = "GSV"
    BIRJAND_AIRPORT = "XBJ"
    TACHILEK_AIRPORT = "THL"
    MEHRABAD_INTERNATIONAL_AIRPORT = "THR"
    XILINHOT_AIRPORT = "XIL"
    XIANYANG_INTERNATIONAL_AIRPORT = "XIY"
    ENTEBBE_INTERNATIONAL_AIRPORT = "EBB"
    NORTH_FRONT_AIRPORT = "GIB"
    GALEAO_ANTONIO_CARLOS_JOBIM_INTERNATIONAL_AIRPORT = "GIG"
    GILGIT_AIRPORT = "GIL"
    GISBORNE_AIRPORT = "GIS"
    GOLDEN_TRIANGLE_REGIONAL_AIRPORT = "GTR"
    LA_AURORA_INTERNATIONAL_AIRPORT = "GUA"
    GUNNISON_AIRPORT = "GUC"
    HARUN_THOHIR_AIRPORT = "BXW"
    BEMOLANGA_AIRPORT = "BZM"
    JAZAN_REGIONAL_AIRPORT = "GIZ"
    JIJEL_FERHAT_ABBAS_AIRPORT = "GJL"
    XIAMEN_GAOQI_INTERNATIONAL_AIRPORT = "XMN"
    GRAND_JUNCTION_REGIONAL_AIRPORT = "GJT"
    XINING_CAOJIABAO_AIRPORT = "XNN"
    WESTERLAND_SYLT_AIRPORT = "GWT"
    KLANTEN_AIRPORT = "GLL"
    GOULIMIME_AIRPORT = "GLN"
    GELEPHU_AIRPORT = "GLU"
    GANNAN_XIAHE_AIRPORT = "GXH"
    GAMBELA_AIRPORT = "GMB"
    GOMEL_AIRPORT = "GME"
    GOMBE_LAWANTI_INTERNATIONAL_AIRPORT = "GMO"
    GIMPO_INTERNATIONAL_AIRPORT = "GMP"
    GOLOG_MAQIN_AIRPORT = "GMQ"
    LA_GOMERA_AIRPORT = "GMZ"
    GRODNO_AIRPORT = "GNA"
    GRENOBLE_ISERE_AIRPORT = "GNB"
    MAURICE_BISHOP_INTERNATIONAL_AIRPORT = "GND"
    HALMSTAD_AIRPORT = "HAD"
    KUUJJUAQ_AIRPORT = "YVP"
    HECHI_JINCHENGJIANG_AIRPORT = "HCJ"
    GABÈS_MATMATA_INTERNATIONAL_AIRPORT = "GAE"
    GAINESVILLE_REGIONAL_AIRPORT = "GNV"
    GENOA_CRISTOFORO_COLOMBO_AIRPORT = "GOA"
    NUUK_AIRPORT = "GOH"
    DABOLIM_AIRPORT = "GOI"
    NIZHNY_NOVGOROD_INTERNATIONAL_AIRPORT = "GOJ"
    GOMA_AIRPORT = "GOM"
    GORAKHPUR_AIRPORT = "GOP"
    GOLMUD_AIRPORT = "GOQ"
    GAROUA_AIRPORT = "GOU"
    ARAXOS_AIRPORT = "GPA"
    BALTRA_AIRPORT = "GPS"
    GULFPORT_BILOXI_INTERNATIONAL_AIRPORT = "GPT"
    FRANKFURT_HAHN_AIRPORT = "HHN"
    AUSTIN_STRAUBEL_INTERNATIONAL_AIRPORT = "GRB"
    GRAND_ISLAND_AIRPORT = "GRI"
    GEORGE_AIRPORT = "GRJ"
    GIRONA_COSTA_BRAVA_AIRPORT = "GRO"
    EELDE_AIRPORT = "GRQ"
    GERALD_R_FORD_INTERNATIONAL_AIRPORT = "GRR"
    SAO_PAULO_GUARULHOS_INTERNATIONAL_AIRPORT = "GRU"
    GROZNYY_AIRPORT = "GRV"
    GRACIOSA_ISLAND_AIRPORT = "GRW"
    GRANADA_AIRPORT = "GRX"
    GRAZ_AIRPORT = "GRZ"
    GOTHENBURG_CITY_AIRPORT = "GSE"
    GREAT_FALLS_INTERNATIONAL_AIRPORT = "GTF"
    TOLOTIO_AIRPORT = "GTO"
    A_B_WON_PAT_INTERNATIONAL_AIRPORT = "GUM"
    ATYRAU_AIRPORT = "GUW"
    GENEVE_AIRPORT = "GVA"
    GOVERNADOR_VALADARES_AIRPORT = "GVR"
    HORTA_AIRPORT = "HOR"
    HOVDEN_AIRPORT = "HOV"
    HOMALIN_AIRPORT = "HOX"
    GUAYARAMERIN_AIRPORT = "GYA"
    HEYDAR_ALIYEV_INTERNATIONAL_AIRPORT = "GYD"
    JOSE_JOAQUIN_DE_OLMEDO_AIRPORT = "GYE"
    MAGAN_AIRPORT = "GYG"
    SANTA_GENOVEVA_AIRPORT = "GYN"
    GUANG_YUAN_AIRPORT = "GYS"
    GUYUAN_LIUPANSHAN_AIRPORT = "GYU"
    GAZA_YASER_ARAFAT_INTERNATIONAL_AIRPORT = "GZA"
    GARZE_GESAR_AIRPORT = "GZG"
    KHARKOV_AIRPORT = "HRK"
    VALLEY_INTERNATIONAL_AIRPORT = "HRL"
    GIZO_AIRPORT = "GZO"
    HASVIK_AIRPORT = "HAA"
    HATANGA_AIRPORT = "HTG"
    HOTAN_AIRPORT = "HTN"
    TRI_STATE_MILTON_AIRPORT = "HTS"
    HUATUGOU_AIRPORT = "HTT"
    HANNOVER_AIRPORT = "HAJ"
    HAMBURG_AIRPORT = "HAM"
    NOI_BAI_INTERNATIONAL_AIRPORT = "HAN"
    GRAND_CANYON_BAR_10_AIRPORT = "GCT"
    SAN_FERNANDO_AIRPORT = "RPU"
    BAZHONG_ENYANG_AIRPORT = "BZX"
    CONKLIN_LEISMER_AIRPORT = "CFM"
    AR_HORQIN_AIRPORT = "AEQ"
    HONGYUAN_AIRPORT = "AHJ"
    GASTÃO_MESQUITA_AIRPORT = "GGH"
    BAILING_AIRPORT = "BKV"
    HAIL_AIRPORT = "HAS"
    BOVANENKOVO_AIRPORT = "BVJ"
    HAUGESUND_AIRPORT = "HAU"
    JOSE_MARTI_INTERNATIONAL_AIRPORT = "HAV"
    HOBART_INTERNATIONAL_AIRPORT = "HBA"
    BORG_EL_ARAB_AIRPORT = "HBE"
    HAYWARD_EXECUTIVE_AIRPORT = "HWD"
    KARARA_AIRPORT = "KQR"
    DEQING_MOGANSHAN_AIRPORT = "DEQ"
    PRESIDENT_OBIANG_NGUEMA_INTERNATIONAL_AIRPORT = "GEM"
    GUAÍRA_AIRPORT = "GGJ"
    GRUYERE_MINE_AIRPORT = "GYZ"
    HUBLI_AIRPORT = "HBX"
    HERINGSDORF_AIRPORT = "HDF"
    HANDAN_AIRPORT = "HDG"
    DELINGHA_AIRPORT = "HXD"
    NURSULTAN_NAZARBAYEV_INTERNATIONAL_AIRPORT = "NQZ"
    TANJUNG_API_AIRPORT = "OJU"
    DANFENG_AIRPORT = "DFA"
    BERINGIN_AIRPORT = "GXA"
    QILIAN_AIRPORT = "HBQ"
    KULHUDHUFFUSHI_AIRPORT = "HDK"
    HAMADAN_AIRPORT = "HDM"
    HOEDSPRUIT_AIRPORT = "HDS"
    HOHHOT_BAITA_INTERNATIONAL_AIRPORT = "HET"
    HENGDIAN_AIRPORT = "HEW"
    HAIFA_AIRPORT = "HFA"
    HAGFORS_AIRPORT = "HFS"
    HAMMERFEST_AIRPORT = "HFT"
    HIGUEROTE_AIRPORT = "HGE"
    NOP_GOLIAT_AIRPORT = "DEX"
    ROBERT_BOB_CURTIS_MEMORIAL_AIRPORT = "ORV"
    HORN_ISLAND_AIRPORT = "HID"
    WOODGREEN_AIRPORT = "WOG"
    MELAK_AIRPORT = "GHS"
    DAYRESTAN_AIRPORT = "GSM"
    BERLIN_BRANDENBURG_AIRPORT = "BER"
    BIRMINGHAM_INTERNATIONAL_AIRPORT = "BHX"
    CHERAW_MUNI_LYNCH_BELLINGER_FLD_AIRPORT = "CQW"
    WODGINA_AIRPORT = "GYB"
    MAE_HONG_SON_AIRPORT = "HGN"
    KORHOGO_AIRPORT = "HGO"
    WASH_COUNTY_REGIONAL_AIRPORT = "HGR"
    MOUNT_HAGEN_AIRPORT = "HGU"
    MUSCAT_INTERNATIONAL_AIRPORT = "MCT"
    COOPERSTOWN_WESTVILLE_AIRPORT = "COP"
    CENTRAL_JERSEY_REGIONAL_AIRPORT = "JVI"
    HUA_HIN_AIRPORT = "HHQ"
    HUAIAN_LIANSHUI_AIRPORT = "HIA"
    CHISHOLM_AIRPORT = "HIB"
    HIROSHIMA_AIRPORT = "HIJ"
    SACHEON_AIRPORT = "HIN"
    HONIARA_INTERNATIONAL_AIRPORT = "HIR"
    ZHIJIANG_AIRPORT = "HJJ"
    KHAJURAHO_AIRPORT = "HJR"
    HAKODATE_AIRPORT = "HKD"
    LEHIGH_VALLEY_INTERNATIONAL_AIRPORT = "ABE"
    HONG_KONG_INTERNATIONAL_AIRPORT = "HKG"
    HOSKINS_AIRPORT = "HKN"
    ABILENE_REGIONAL_AIRPORT = "ABI"
    LANSERIA_INTERNATIONAL_AIRPORT = "HLA"
    HULUNBUIR_HAILAR_AIRPORT = "HLD"
    ABERDEEN_MUNICIPAL_AIRPORT = "ABR"
    SOUTHWEST_GEORGIA_REGIONAL_AIRPORT = "ABY"
    NANTUCKET_MEMORIAL_AIRPORT = "ACK"
    ULANHOT_AIRPORT = "HLH"
    OTTAWA_MACDONALD_CARTIER_INTERNATIONAL_AIRPORT = "YOW"
    WACO_MUNICIPAL_AIRPORT = "ACT"
    ARCATA_EUREKA_AIRPORT = "ACV"
    ATLANTIC_CITY_INTERNATIONAL_AIRPORT = "ACY"
    ARDMORE_MUNICIPAL_AIRPORT = "ADM"
    ADDISON_AIRPORT = "ADS"
    ADAREIL_AIRPORT = "AEE"
    HELENA_REGIONAL_AIRPORT = "HLN"
    ALEXANDRIA_INTERNATIONAL_AIRPORT = "AEX"
    SIIRT_AIRPORT = "SXZ"
    FORT_WORTH_ALLIANCE_AIRPORT = "AFW"
    ALLEGHENY_COUNTY_AIRPORT = "AGC"
    AUGUSTA_REGIONAL_AIRPORT = "AGS"
    FUAAMOTU_INTERNATIONAL_AIRPORT = "TBU"
    COLORADO_PLAINS_REGIONAL_AIRPORT = "AKO"
    ALBANY_INTERNATIONAL_AIRPORT = "ALB"
    TRAT_AIRPORT = "TDX"
    HALIM_PERDANAKUSUMA_AIRPORT = "HLP"
    HAMILTON_INTERNATIONAL_AIRPORT = "HLZ"
    KHANTY_MANSIYSK_AIRPORT = "HMA"
    MUBARAK_INTERNATIONAL_AIRPORT = "HMB"
    OUED_IRARA_AIRPORT = "HME"
    HAMI_AIRPORT = "HMI"
    GEN_PESQUEIRA_GARCIA_AIRPORT = "HMO"
    HAMAR_AIRPORT = "HMR"
    HEMAVAN_AIRPORT = "HMV"
    DEVI_AHILYA_BAI_HOLKAR_AIRPORT = "IDR"
    SEOSAN_AIRPORT = "HMY"
    HANAMAKI_AIRPORT = "HNA"
    HANEDA_AIRPORT = "HND"
    HONOLULU_INTERNATIONAL_AIRPORT = "HNL"
    HENGYANG_NANYUE_AIRPORT = "HNY"
    LEA_COUNTY_AIRPORT = "HOB"
    HODEIDAH_AIRPORT = "HOD"
    AL_AHSA_AIRPORT = "HOF"
    FRANK_PAIS_AIRPORT = "HOG"
    SHENNONGJIA_HONGPING_AIRPORT = "HPG"
    CAT_BI_INTERNATIONAL_AIRPORT = "HPH"
    WESTCHESTER_COUNTY_AIRPORT = "HPN"
    BAYTOWN_AIRPORT = "HPY"
    HARARE_INTERNATIONAL_AIRPORT = "HRE"
    HOARAFUSHI_AIRPORT = "HRF"
    HURGHADA_INTERNATIONAL_AIRPORT = "HRG"
    BOONE_COUNTY_AIRPORT = "HRO"
    IZHEVSK_AIRPORT = "IJK"
    HARRISMITH_AIRPORT = "HRS"
    HAZRET_SULTAN_INTERNATIONAL_AIRPORT = "HSA"
    SAGA_AIRPORT = "HSG"
    SHANGJIE_AIRPORT = "HSJ"
    PUTUOSHAN_AIRPORT = "HSN"
    HUNTSVILLE_INTERNATIONAL_AIRPORT = "HSV"
    CHITA_AIRPORT = "HTA"
    HATAY_AIRPORT = "HTY"
    HUMACAO_AIRPORT = "HUC"
    HUMERA_AIRPORT = "HUE"
    HUAHINE_AIRPORT = "HUH"
    PHU_BAI_INTERNATIONAL_AIRPORT = "HUI"
    HOLINGOL_HUOLINHE_AIRPORT = "HUO"
    HUANUCO_AIRPORT = "HUU"
    HUATULCO_AIRPORT = "HUX"
    HUMBERSIDE_AIRPORT = "HUY"
    HUIZHOU_AIRPORT = "HUZ"
    HERVEY_BAY_AIRPORT = "HVB"
    KHOVD_AIRPORT = "HVD"
    VALAN_AIRPORT = "HVG"
    NEW_HAVEN_AIRPORT = "HVN"
    HAVRE_CITY_COUNTY_AIRPORT = "HVR"
    BARNSTABLE_MUNICIPAL_AIRPORT = "HYA"
    RAJIV_GANDHI_INTERNATIONAL_AIRPORT = "HYD"
    LUQIAO_AIRPORT = "HYN"
    HAYS_MUNICIPAL_AIRPORT = "HYS"
    ESTABLECIMIENTO_EL_ARAZA_AIRPORT = "HZA"
    HANZHONG_AIRPORT = "HZG"
    LIPING_AIRPORT = "HZH"
    IGARKA_AIRPORT = "IAA"
    WASHINGTON_DULLES_INTERNATIONAL_AIRPORT = "IAD"
    NIAGARA_FALLS_INTERNATIONAL_AIRPORT = "IAG"
    TUNOSHNA_AIRPORT = "IAR"
    IASI_AIRPORT = "IAS"
    IBADAN_AIRPORT = "IBA"
    IBAGUE_AIRPORT = "IBE"
    HARGEISA_AIRPORT = "HGA"
    IRON_BRIDGE_MINE_AIRPORT = "IBM"
    IBARAKI_AIRPORT = "IBR"
    IBIZA_AIRPORT = "IBZ"
    ANDRÉS_MIGUEL_SALAZAR_MARCANO_AIRPORT = "ICC"
    WICHITA_DWIGHT_D_EISENHOWER_NATIONAL_AIRPORT = "ICT"
    IDAHO_FALLS_REGIONAL_AIRPORT = "IDA"
    DJIBOUTI_AMBOULI_INTERNATIONAL_AIRPORT = "JIB"
    NDIANA_COUNTY_AIRPORT_JIMMY_STEWART_FIELD = "IDI"
    ZIELONA_GORA_BABIMOST_AIRPORT = "IEG"
    KYIV_INTERNATIONAL_AIRPORT = "IEV"
    ISAFJORDUR_AIRPORT = "IFJ"
    ISFAHAN_INTERNATIONAL_AIRPORT = "IFN"
    IVANO_FRANKOVSK_AIRPORT = "IFO"
    NAXOS_AIRPORT = "JNX"
    LAUGHLIN_BULLHEAD_INTERNATIONAL_AIRPORT = "IFP"
    JOINVILLE_LAURO_CARNEIRO_DE_LOYOLA_AIRPORT = "JOI"
    IFURU_AIRPORT = "IFU"
    INAGUA_AIRPORT = "IGA"
    IGIUGIG_AIRPORT = "IGG"
    JI_PARANA_AIRPORT = "JPR"
    JAQUE_AIRPORT = "JQE"
    JOENSUU_AIRPORT = "JOE"
    ADISUTJIPTO_INTERNATIONAL_AIRPORT = "JOG"
    JURUTI_AIRPORT = "JRT"
    YOSHKAR_OLA_AIRPORT = "JOK"
    JOS_AIRPORT = "JOS"
    PRESIDENTE_CASTRO_PINTO_INTERNATIONAL_AIRPORT = "JPA"
    JHARSUGUDA_AIRPORT = "JRG"
    ROWRIAH_AIRPORT = "JRH"
    KILIMANJARO_INTERNATIONAL_AIRPORT = "JRO"
    MAGAS_AIRPORT = "IGT"
    CATARATAS_INTERNATIONAL_AIRPORT = "IGU"
    ASTYPALAIA_AIRPORT = "JTY"
    SYROS_ISLAND_AIRPORT = "JSY"
    SANTORINI_INTERNATIONAL_AIRPORT = "JTR"
    ILAAM_AIRPORT = "IIL"
    CHIZHOU_JIUHUASHAN_AIRPORT = "JUH"
    J_BATISTA_BOS_FILHO_AIRPORT = "IJU"
    EL_CADILLAL_AIRPORT = "JUJ"
    IMAM_KHOMEINI_INTERNATIONAL_AIRPORT = "IKA"
    QUZHOU_AIRPORT = "JUZ"
    TIKSI_AIRPORT = "IKS"
    IRKUTSK_INTERNATIONAL_AIRPORT = "IKT"
    ISSYK_KUL_INTERNATIONAL_AIRPORT = "IKU"
    JESSORE_AIRPORT = "JSR"
    CAMBRIA_COUNTY_AIRPORT = "JST"
    KAMESHLY_AIRPORT = "KAC"
    KADUNA_AIRPORT = "KAD"
    BAURU_AREALVA_AIRPORT = "JTC"
    JUBA_INTERNATIONAL_AIRPORT = "JUB"
    JULIACA_AIRPORT = "JUL"
    JYVASKYLA_AIRPORT = "JYV"
    JIUZHAI_HUANGLONG_AIRPORT = "JZH"
    KASAMA_AIRPORT = "KAA"
    KAJAANI_AIRPORT = "KAJ"
    MALLAM_AMINU_KANO_INTERNATIONAL_AIRPORT = "KAN"
    KUUSAMO_AIRPORT = "KAO"
    LLEIDA_ALGUAIRE_AIRPORT = "ILD"
    KABUL_INTERNATIONAL_AIRPORT = "KBL"
    BORYSPIL_INTERNATIONAL_AIRPORT = "KBP"
    SULTAN_ISMAIL_PETRA_AIRPORT = "KBR"
    KRABI_AIRPORT = "KBV"
    KUCHING_INTERNATIONAL_AIRPORT = "KCH"
    GUSTI_SYAMSIR_ALAM_AIRPORT = "KBU"
    ILIAMNA_AIRPORT = "ILI"
    KUQA_AIRPORT = "KCA"
    WILMINGTON_INTERNATIONAL_AIRPORT = "ILM"
    MANDURRIAO_AIRPORT = "ILO"
    ILE_DES_PINS_AIRPORT = "ILP"
    ILORIN_INTERNATIONAL_AIRPORT = "ILR"
    ILOPANGO_INTERNATIONAL_AIRPORT = "ILS"
    IMPHAL_MUNICIPAL_AIRPORT = "IMF"
    IMPERATRIZ_AIRPORT = "IMP"
    KIRENSK_AIRPORT = "KCK"
    KAHRAMANMARAS_AIRPORT = "KCM"
    CENGIZ_TOPEL_AIRPORT = "KCO"
    KOCHI_RYOMA_AIRPORT = "KCZ"
    WATERLOO_AIRPORT = "ALO"
    KANDAHAR_AIRPORT = "KDH"
    INTA_AIRPORT = "INA"
    KEFLAVIK_INTERNATIONAL_AIRPORT = "KEF"
    SKARDU_AIRPORT = "KDU"
    KEMEROVO_AIRPORT = "KEJ"
    POLGOLLA_RESERVOIR_AIRPORT = "KDZ"
    KEMI_TORNIO_AIRPORT = "KEM"
    KARDLA_AIRPORT = "KDL"
    YINCHUAN_HEDONG_INTERNATIONAL_AIRPORT = "INC"
    INDIANAPOLIS_INTERNATIONAL_AIRPORT = "IND"
    INHAMBANE_AIRPORT = "INH"
    NIS_CONSTANTINE_THE_GREAT_AIRPORT = "INI"
    INNSBRUCK_AIRPORT = "INN"
    SMITH_REYNOLDS_AIRPORT = "INT"
    INVERNESS_AIRPORT = "INV"
    NEPALGANJ_AIRPORT = "KEP"
    KERMAN_AIRPORT = "KER"
    IN_SALAH_AIRPORT = "INZ"
    IOANNINA_AIRPORT = "IOA"
    ISLE_OF_MAN_AIRPORT = "IOM"
    KOGALYM_INTERNATIONAL_AIRPORT = "KGP"
    ILHEUS_BAHIA_JORGE_AMADO_AIRPORT = "IOS"
    MATAVERI_INTERNATIONAL_AIRPORT = "IPC"
    IPOH_AIRPORT = "IPH"
    SAN_LUIS_AIRPORT = "IPI"
    KHERSON_INTERNATIONAL_AIRPORT = "KHE"
    KASHI_AIRPORT = "KHG"
    KASTAMONU_AIRPORT = "KFS"
    KHRABROVO_AIRPORT = "KGD"
    KARAGANDA_AIRPORT = "KGF"
    KALGOORLIE_AIRPORT = "KGI"
    KIGALI_INTERNATIONAL_AIRPORT = "KGL"
    KOS_AIRPORT = "KGS"
    KAOHSIUNG_INTERNATIONAL_AIRPORT = "KHH"
    JINNAH_INTERNATIONAL_AIRPORT = "KHI"
    NANCHANG_CHANGBEI_INTERNATIONAL_AIRPORT = "KHN"
    USIMINAS_AIRPORT = "IPN"
    LYCOMING_COUNTY_AIRPORT = "IPT"
    SAN_ISIDRO_DE_EL_GENERAL_AIRPORT = "IPZ"
    QINGYANG_AIRPORT = "IQN"
    KISUMU_AIRPORT = "KIS"
    DIEGO_ARACENA_INTERNATIONAL_AIRPORT = "IQQ"
    KITHIRA_AIRPORT = "KIT"
    KANSAI_INTERNATIONAL_AIRPORT = "KIX"
    KERTAJATI_INTERNATIONAL_AIRPORT = "KJT"
    C_F_SECADA_VIGNETTA_INTERNATIONAL_AIRPORT = "IQT"
    YEMELYANOVO_AIRPORT = "KJA"
    NDULI_AIRPORT = "IRI"
    KANASI_AIRPORT = "KJI"
    LA_RIOJA_AIRPORT = "IRJ"
    KIRKSVILLE_MUNICIPAL_AIRPORT = "IRK"
    BLANGPIDIE_AIRPORT = "KJX"
    KHASAB_AIRPORT = "KHS"
    KHABAROVSK_AIRPORT = "KHV"
    KRISTIANSTAD_AIRPORT = "KID"
    KISH_INTERNATIONAL_AIRPORT = "KIH"
    NIIGATA_AIRPORT = "KIJ"
    KIMBERLEY_AIRPORT = "KIM"
    KERRY_COUNTY_AIRPORT = "KIR"
    CHISINAU_INTERNATIONAL_AIRPORT = "KIV"
    KAILI_HUANGPING_AIRPORT = "KJH"
    KHON_KAEN_AIRPORT = "KKC"
    KERIKERI_AIRPORT = "KKE"
    KITAKYUSHU_AIRPORT = "KKJ"
    KIRKENES_AIRPORT_HOEYBUKTMOEN = "KKN"
    KASHAN_AIRPORT = "KKS"
    ISLAMABAD_INTERNATIONAL_AIRPORT = "ISB"
    GRABTSEVO_AIRPORT = "KLF"
    KALIBO_INTERNATIONAL_AIRPORT = "KLO"
    KLAGENFURT_AIRPORT = "KLU"
    KARLOVY_VARY_AIRPORT = "KLV"
    KALAMATA_AIRPORT = "KLX"
    KUNMING_CHANGSHUI_INTERNATIONAL_AIRPORT = "KMG"
    MIYAZAKI_AIRPORT = "KMI"
    KALMAR_OLAND_AIRPORT = "KLR"
    KUMAMOTO_AIRPORT = "KMJ"
    KALABO_AIRPORT = "KLB"
    ISPARTA_SULEYMAN_DEMIREL_AIRPORT = "ISE"
    PAINUSHIMA_ISHIGAKI_AIRPORT = "ISG"
    ISCHIA_AIRPORT = "ISH"
    GANDHINAGAR_AIRPORT = "ISK"
    LONG_ISLAND_MACARTHUR_AIRPORT = "ISP"
    ISTANBUL_NEW_AIRPORT = "IST"
    SULAIMANIYAH_INTERNATIONAL_AIRPORT = "ISU"
    KOMATSU_AIRPORT = "KMQ"
    KUMASI_AIRPORT = "KMS"
    KALEMYO_AIRPORT = "KMV"
    KAIMANA_AIRPORT = "KNG"
    KUALA_NAMU_INTERNATIONAL_AIRPORT = "KNO"
    KING_ISLAND_AIRPORT = "KNS"
    KINMEN_AIRPORT = "KNH"
    KANPUR_AIRPORT = "KNU"
    ITHACA_TOMPKINS_REGIONAL_AIRPORT = "ITH"
    ITAMI_AIRPORT = "ITM"
    HANAN_AIRPORT = "IUE"
    INVERCARGILL_AIRPORT = "IVC"
    IVALO_AIRPORT = "IVL"
    IVANOVO_YUZHNY_AIRPORT = "IWA"
    GOGEBIC_COUNTY_AIRPORT = "IWD"
    SIHANOUK_INTERNATIONAL_AIRPORT = "KOS"
    KOKSHETAU_AIRPORT = "KOV"
    POHANG_AIRPORT = "KPO"
    KEPERVEYEM_AIRPORT = "KPW"
    KISHANGARH_AIRPORT = "KQH"
    QURGHONTEPPA_INTERNATIONAL_AIRPORT = "KQT"
    KRAMFORS_AIRPORT = "KRF"
    KIRUNA_AIRPORT = "KRN"
    HAGI_IWAMI_AIRPORT = "IWJ"
    IWAKUNI_KINTAIKYO_AIRPORT = "IWK"
    BELGAUM_AIRPORT = "IXG"
    KUMBHIRGRAM_AIRPORT = "IXS"
    ZONA_DA_MATA_REGIONAL_AIRPORT = "IZA"
    ITZEHOE_HUNGRIGER_WOLF_AIRPORT = "IZE"
    IZUMO_AIRPORT = "IZO"
    JACKSON_HOLE_AIRPORT = "JAC"
    J_PAUL_II_INTERNATIONAL_AIRPORT_KRAKOW_BALICE = "KRK"
    KORLA_AIRPORT = "KRL"
    JAIPUR_AIRPORT = "JAI"
    JACMEL_REGIONAL_AIRPORT = "JAK"
    JACKSON_EVERS_INTERNATIONAL_AIRPORT = "JAN"
    JAUJA_AIRPORT = "JAU"
    KURGAN_AIRPORT = "KRO"
    KRASNODAR_INTERNATIONAL_AIRPORT = "KRR"
    KERMANSHAH_AIRPORT = "KSH"
    NOTOHADINEGORO_AIRPORT = "JBB"
    TURKMANBASHI_AIRPORT = "KRW"
    KARLSTAD_AIRPORT = "KSD"
    KASOS_ISLAND_AIRPORT = "KSJ"
    JONESBORO_AIRPORT = "JBR"
    KASSALA_AIRPORT = "KSL"
    ARISTOTELES_AIRPORT = "KSO"
    KARSHI_AIRPORT = "KSQ"
    KARS_AIRPORT = "KSY"
    NEW_CENTURY_AIRCENTER_AIRPORT = "JCI"
    KETAPANG_AIRPORT = "KTG"
    KARUP_AIRPORT = "KRP"
    KRISTIANSAND_AIRPORT = "KRS"
    KHARTOUM_INTERNATIONAL_AIRPORT = "KRT"
    KOSRAE_AIRPORT = "KSA"
    BARCA_AIRPORT = "KSC"
    KASESE_AIRPORT = "KSE"
    KASSEL_CALDEN_AIRPORT = "KSF"
    KOSTANAY_AIRPORT = "KSN"
    KRISTIANSUND_AIRPORT_KVERNBERGET = "KSU"
    KOTLAS_AIRPORT = "KSZ"
    KARRATHA_AIRPORT = "KTA"
    KERTEH_AIRPORT = "KTE"
    KITALE_AIRPORT = "KTL"
    JODHPUR_AIRPORT = "JDH"
    KAUNAS_AIRPORT = "KUN"
    ORLANDO_BEZERRA_DE_MENEZES_AIRPORT = "JDO"
    KUTAISI_INTERNATIONAL_AIRPORT = "KUT"
    BHUNTAR_AIRPORT = "KUU"
    GUNSAN_AIRPORT = "KUV"
    GYANDZHA_AIRPORT = "KVD"
    KIROVSK_AIRPORT = "KVK"
    JINGDEZHEN_AIRPORT = "JDZ"
    KING_ABDULAZIZ_INTERNATIONAL_AIRPORT = "JED"
    KWAJALEIN_AIRPORT = "KWA"
    KITTILA_AIRPORT = "KTT"
    KATOWICE_INTERNATIONAL_AIRPORT = "KTW"
    SULTAN_HAJI_AHMAD_SHAH_AIRPORT = "KUA"
    KUDAT_AIRPORT = "KUD"
    KURUMOCH_INTERNATIONAL_AIRPORT = "KUF"
    KUSHIRO_AIRPORT = "KUH"
    KUALA_LUMPUR_INTERNATIONAL_AIRPORT = "KUL"
    KUOPIO_AIRPORT = "KUO"
    KULUSUK_AIRPORT = "KUS"
    KAVALA_INTERNATIONAL_AIRPORT = "KVA"
    MORAVA_AIRPORT = "KVO"
    KIROV_AIRPORT = "KVX"
    GUIYANG_LONGDONGBAO_INTERNATIONAL_AIRPORT = "KWE"
    GWANGJU_AIRPORT = "KWJ"
    GUILIN_LIANGJIANG_INTERNATIONAL_AIRPORT = "KWL"
    KHURBA_AIRPORT = "KXK"
    KONYA_AIRPORT = "KYA"
    PHILIPPOS_AIRPORT = "KZI"
    KONDINSKOYE_AIRPORT = "KXD"
    KAZAN_INTERNATIONAL_AIRPORT = "KZN"
    KZYL_ORDA_AIRPORT = "KZO"
    KUWAIT_INTERNATIONAL_AIRPORT = "KWI"
    AASIAAT_AIRPORT = "JEG"
    JEKI_AIRPORT = "JEK"
    PAAMIUT_AIRPORT = "JFR"
    KYZYL_AIRPORT = "KYZ"
    JIAYUGUAN_AIRPORT = "JGN"
    JIAN_JING_GANG_SHAN_AIRPORT = "JGS"
    SENAI_AIRPORT = "JHB"
    XISHUANGBANNA_GASA_AIRPORT = "JHG"
    KAPALUA_AIRPORT = "JHM"
    SISIMIUT_AIRPORT = "JHS"
    JINCHUAN_AIRPORT = "JIC"
    KASTELLORIZO_AIRPORT = "KZS"
    QUATRO_DE_FEVEREIRO_AIRPORT = "LAD"
    SERVEL_AIRPORT = "LAI"
    CORREIA_PINTO_AIRPORT = "LAJ"
    JIGIGA_AIRPORT = "JIJ"
    LEON_AIRPORT = "LAP"
    LA_BRAQ_AIRPORT = "LAQ"
    KOMODO_AIRPORT = "LBJ"
    IKARIA_AIRPORT = "JIK"
    JIMMA_AIRPORT = "JIM"
    LEEDS_BRADFORD_INTERNATIONAL_AIRPORT = "LBA"
    CAPITAL_REGION_INTERNATIONAL_AIRPORT = "LAN"
    LAOAG_AIRPORT = "LAO"
    QIANJIANG_WULINGSHAN_AIRPORT = "JIQ"
    LIBERAL_MUNICIPAL_AIRPORT = "LBL"
    LAWTON_FORT_SILL_REGIONAL_AIRPORT = "LAW"
    LOS_ANGELES_INTERNATIONAL_AIRPORT = "LAX"
    KHUJAND_AIRPORT = "LBD"
    JAGUARUNA_REGIONAL_AIRPORT = "JJG"
    MULIKA_LODGE_AIRPORT = "JJM"
    LARNACA_INTERNATIONAL_AIRPORT = "LCA"
    GOLOSON_INTERNATIONAL_AIRPORT = "LCE"
    A_CORUNA_AIRPORT = "LCG"
    LODZ_LUBLINEK_AIRPORT = "LCJ"
    LONDRINA_AIRPORT = "LDB"
    TARBES_OSSUN_LOURDES_AIRPORT = "LDE"
    JOPLIN_AIRPORT = "JLN"
    JABALPUR_AIRPORT = "JLR"
    LANCANG_JINGMAI_AIRPORT = "JMJ"
    MIKONOS_AIRPORT = "JMK"
    LEBANON_REGIONAL_AIRPORT = "LEB"
    CORONEL_HORACIO_DE_MATTOS_AIRPORT = "LEC"
    ALMERIA_AIRPORT = "LEI"
    GEN_A_V_COBO_AIRPORT = "LET"
    BLUE_GRASS_AIRPORT = "LEX"
    LANPING_FENG_HUA_AIRPORT = "LFH"
    LAMERD_AIRPORT = "LFM"
    LINFEN_QIAOLI_AIRPORT = "LFQ"
    LA_FRIA_AIRPORT = "LFR"
    PULKOVO_AIRPORT = "LED"
    O_R_TAMBO_INTERNATIONAL_AIRPORT = "JNB"
    JINING_AIRPORT = "JNG"
    LAGO_AGRIO_AIRPORT = "LGQ"
    MILANO_LINATE_AIRPORT = "LIN"
    ALAMOSA_MUNICIPAL_AIRPORT = "ALS"
    LIFOU_AIRPORT = "LIF"
    BELLEGARDE_AIRPORT = "LIG"
    BILL_AND_HILLARY_CLINTON_NATIONAL_AIRPORT = "LIT"
    LEGASPI_AIRPORT = "LGP"
    LONDON_GATWICK_AIRPORT = "LGW"
    ALLAMA_IQBAL_INTERNATIONAL_AIRPORT = "LHE"
    LONDON_HEATHROW_AIRPORT = "LHR"
    LIHUE_AIRPORT = "LIH"
    LILLE_AIRPORT = "LIL"
    JORGE_CHAVEZ_INTERNATIONAL_AIRPORT = "LIM"
    LIMON_INTERNATIONAL_AIRPORT = "LIO"
    LIBERIA_AIRPORT = "LIR"
    LISBON_PORTELA_AIRPORT = "LIS"
    LOIKAW_AIRPORT = "LIW"
    GEWAYENTA_AIRPORT = "LKA"
    LANKARAN_INTERNATIONAL_AIRPORT = "LLK"
    LAKE_MANYARA_AIRPORT = "LKY"
    LIBO_COUNTY_LIBO_CITY_AIRPORT = "LLB"
    LIJIANG_AIRPORT = "LJG"
    LALIBELA_AIRPORT = "LLI"
    LJUBLJANA_JOZE_PUCNIK_AIRPORT = "LJU"
    BANAK_AIRPORT = "LKL"
    LÜLIANG_AIRPORT = "LLV"
    LEKNES_AIRPORT = "LKN"
    CHAUDHARY_CHARAN_SINGH_INTERNATIONAL_AIRPORT = "LKO"
    LULEA_AIRPORT = "LLA"
    CAGAYAN_NORTH_INTERNATIONAL_AIRPORT = "LLC"
    LINGLING_AIRPORT = "LLF"
    WALLA_WALLA_AIRPORT = "ALW"
    LIMBANG_AIRPORT = "LMN"
    ROBERT_ATTY_BESSING_AIRPORT = "LNU"
    LINCANG_AIRPORT = "LNJ"
    LONGNAN_CHENGZHOU_AIRPORT = "LNL"
    LANCASTER_AIRPORT = "LNS"
    LANAI_AIRPORT = "LNY"
    LAMPEDUSA_AIRPORT = "LMP"
    CRATER_LAKE_KLAMATH_REGIONAL_AIRPORT = "LMT"
    LINZ_AIRPORT = "LNZ"
    LOEI_AIRPORT = "LOE"
    CIUDAD_DE_CATAMAYO_AIRPORT = "LOH"
    LMEKRAREG_AIRPORT = "LOO"
    LOMBOK_INTERNATIONAL_AIRPORT = "LOP"
    MURTALA_MUHAMMED_INTERNATIONAL_AIRPORT = "LOS"
    BOWMAN_FIELD_AIRPORT = "LOU"
    LOS_TABLONES_AIRPORT = "LOX"
    LALEU_AIRPORT = "LRH"
    LA_ROMANA_AIRPORT = "LRM"
    LEROS_AIRPORT = "LRS"
    LONDON_LUTON_AIRPORT = "LTN"
    LORETO_AIRPORT = "LTO"
    COTAPAXI_INTERNATIONAL_AIRPORT = "LTX"
    LUDERITZ_AIRPORT = "LUD"
    LUGANO_AIRPORT = "LUG"
    LUDHIANA_SAHNEWAL_AIRPORT = "LUH"
    CINCINNATI_MUNICIPAL_LUNKEN_AIRPORT = "LUK"
    LUXEMBOURG_AIRPORT = "LUX"
    GREENBRIER_VALLEY_AIRPORT = "LWB"
    LENINAKAN_AIRPORT = "LWN"
    LVIV_INTERNATIONAL_AIRPORT = "LWO"
    LEWISTON_NEZ_PERCE_COUNTY_REGIONAL_AIRPORT = "LWS"
    LAWAS_AIRPORT = "LWY"
    LHASA_GONGGAR_AIRPORT = "LXA"
    MENORCA_AIRPORT = "MAH"
    AMATA_KABUA_INTERNATIONAL_AIRPORT = "MAJ"
    MANCHESTER_AIRPORT = "MAN"
    MAE_SOT_AIRPORT = "MAQ"
    LA_CHINITA_AIRPORT = "MAR"
    MOMOTE_AIRPORT = "MAS"
    ADOLFO_SUAREZ_MADRID_BARAJAS_AIRPORT = "MAD"
    MONBETSU_AIRPORT = "MBE"
    EUGENIO_M_DE_HOSTOS_AIRPORT = "MAZ"
    MMABATHO_INTERNATIONAL_AIRPORT = "MBD"
    CENTENNIAL_AIRPORT = "APA"
    HARTSFIELD_JACKSON_ATLANTA_INTERNATIONAL_AIRPORT = "ATL"
    MOBILE_DOWNTOWN_AIRPORT = "BFM"
    BERLIN_MUNICIPAL_AIRPORT = "BML"
    COLUMBIA_METROPOLITAN_AIRPORT = "CAE"
    CHIPPEWA_COUNTY_AIRPORT = "CIU"
    CHARLOTTE_DOUGLAS_INTERNATIONAL_AIRPORT = "CLT"
    CORPUS_CHRISTI_INTERNATIONAL_AIRPORT = "CRP"
    COLUMBUS_AIRPORT = "CSG"
    RONALD_REAGAN_NATIONAL_AIRPORT = "DCA"
    MARA_LODGES_AIRPORT = "MRE"
    KICHWA_TEMBO_AIRPORT = "KTJ"
    FLYING_CLOUD_AIRPORT = "FCM"
    FORT_LAUDERDALE_HOLLYWOOD_INTERNATIONAL_AIRPORT = "FLL"
    FRIDAY_HARBOR_AIRPORT = "FRD"
    GRAYLING_AIRPORT = "KGX"
    WILLIAM_P_HOBBY_AIRPORT = "HOU"
    GEORGE_BUSH_INTERCONTINENTAL_AIRPORT = "IAH"
    IMPERIAL_COUNTY_AIRPORT = "IPL"
    SLOULIN_FIELD_INTERNATIONAL_AIRPORT = "ISN"
    MCCARRAN_INTERNATIONAL_AIRPORT = "LAS"
    LUBBOCK_PRESTON_SMITH_INTERNATIONAL_AIRPORT = "LBB"
    LOMPOC_AIRPORT = "LPC"
    MIDLAND_INTERNATIONAL_AIRPORT = "MAF"
    MERCED_MUNICIPAL_AIRPORT = "MCE"
    MONTGOMERY_REGIONAL_AIRPORT = "MGM"
    MATHER_AIRPORT = "MHR"
    MARTHAS_VINEYARD_AIRPORT = "MVY"
    WILL_ROGERS_WORLD_AIRPORT = "OKC"
    ORCAS_ISLAND_AIRPORT = "ESD"
    GREATER_ROCHESTER_INTERNATIONAL_AIRPORT = "ROC"
    SEVILLE_AIRPORT = "SVQ"
    RUIDOSO_SIERRA_BLANCA_REGIONAL_AIRPORT = "RUI"
    TONOPAH_AIRPORT = "TPH"
    JEREZ_AIRPORT = "XRY"
    MALAGA_AIRPORT = "AGP"
    ALICANTE_ELCHE_AIRPORT = "ALC"
    ANGERS_MARCE_AIRPORT = "ANE"
    EUROAIRPORT_SWISS = "BSL"
    CHARLES_DE_GAULLE_AIRPORT = "CDG"
    STRASBOURG_AIRPORT = "SXB"
    HYERES_AIRPORT = "TLN"
    KARPATHOS_AIRPORT = "AOK"
    PICO_ISLAND_AIRPORT = "PIX"
    CORVO_ISLAND_AZORES_AIRPORT = "CVU"
    PARDUBICE_AIRPORT = "PED"
    EILAT_AIRPORT = "ETH"
    RAMON_AIRPORT = "ETM"
    FARO_AIRPORT = "FAO"
    SANTA_CRUZ_AIRPORT = "FLW"
    W_A_MOZART_SALZBURG_AIRPORT = "SZG"
    LUBLIN_AIRPORT = "LUZ"
    ZAFER_AIRPORT = "KZR"
    SINOP_AIRPORT_TURKEY = "NOP"
    IZMIR_ADNAN_MENDERES_AIRPORT = "ADB"
    SANLIURFA_GAP_AIRPORT = "GNY"
    ISTANBUL_ATATURK_AIRPORT = "ISL"
    BRATISLAVA_AIRPORT = "BTS"
    NORMAN_MANLEY_INTERNATIONAL_AIRPORT = "KIN"
    CIUDAD_CONSTITUCIÓN_AIRPORT = "CUA"
    LOS_CANOS_AIRPORT = "GAO"
    RAFAEL_CABRERA_AIRPORT = "GER"
    GOLFITO_AIRPORT = "GLF"
    LYNDEN_PINDLING_INTERNATIONAL_AIRPORT = "NAS"
    MAYAGUANA_AIRPORT = "MYG"
    BIMINI_INTERNATIONAL_AIRPORT = "BIM"
    CROOKED_ISLAND_AIRPORT = "CRI"
    CHARLES_KIRKCONNEL_INTERNATIONAL_AIRPORT = "CYB"
    NORTH_ELEUTHERA_INTERNATIONAL_AIRPORT = "ELH"
    GOVERNORS_HARBOUR_AIRPORT = "GHB"
    KANDAVU_AIRPORT = "KDV"
    LABASA_AIRPORT = "LBS"
    LAKEBA_AIRPORT = "LKB"
    AITUTAKI_AIRPORT = "AIT"
    PHILIP_S_W_GOLDSON_INTERNATIONAL_AIRPORT = "BZE"
    NADI_INTERNATIONAL_AIRPORT = "NAN"
    SAVUSAVU_AIRPORT = "SVU"
    FAKARAVA_AIRPORT = "FAV"
    TIKEHAU_ATOLL_AIRPORT = "TIH"
    KAUKURA_ATOLL_AIRPORT = "KKR"
    KAUEHI_AIRPORT = "KHZ"
    ARUTUA_AIRPORT = "AXR"
    HIVA_OA_AIRPORT = "AUQ"
    MOTU_MUTE_AIRPORT = "BOB"
    NUKU_HIVA_AIRPORT = "NHV"
    FUTUNA_AIRPORT = "FTA"
    RANGIROA_AIRPORT = "RGI"
    BAUERFIELD_AIRPORT = "VLI"
    MOUNT_COOK_AIRPORT = "MON"
    HOKITIKA_AIRPORT = "HKK"
    ABHA_REGIONAL_AIRPORT = "AHB"
    BUSHEHR_AIRPORT = "BUZ"
    SIR_BANI_YAS_ISLAND_AIRPORT = "XSB"
    SHARJAH_INTERNATIONAL_AIRPORT = "SHJ"
    SALALAH_INTERNATIONAL_AIRPORT = "SLL"
    AL_AIN_AIRPORT = "AAN"
    MARKA_INTERNATIONAL_AIRPORT = "ADJ"
    ABU_DHABI_INTERNATIONAL_AIRPORT = "AUH"
    BHAGATANWALA_AIRPORT = "BHW"
    DERA_GHAZI_KHAN_AIRPORT = "DEA"
    AL_DHAFRA_MILITARY_AIRPORT = "DHF"
    DUQM_INTERNATIONAL_AIRPORT = "DQM"
    DUBAI_WORLD_CENTRAL_AL_MAKTOUM_INTERNATIONAL_AIRPORT = "DWC"
    DUBAI_AIRPORT = "DXB"
    WILEY_POST_WILL_ROGERS_MEMORIAL_AIRPORT = "BRW"
    BARTER_ISLAND_AIRPORT = "BTI"
    COLD_BAY_AIRPORT = "CDB"
    MUDHOLE_SMITH_AIRPORT = "CDV"
    KODIAK_BENNY_BENSON_STATE_AIRPORT = "ADQ"
    BETHEL_AIRPORT = "BET"
    BUCKLAND_AIRPORT = "BKC"
    KONGIGANAK_AIRPORT = "KKH"
    MARSHALL_DON_HUNTER_SR_AIRPORT = "MLL"
    DILLINGHAM_AIRPORT = "DLG"
    DEERING_AIRPORT = "DRG"
    EMMONAK_AIRPORT = "EMK"
    UNALASKA_AIRPORT = "DUT"
    JUNEAU_INTERNATIONAL_AIRPORT = "JNU"
    MCGRATH_AIRPORT = "MCG"
    MOUNTAIN_VILLAGE_AIRPORT = "MOU"
    KWIGILLINGOK_AIRPORT = "KWK"
    KLAWOCK_AIRPORT = "KLW"
    WALES_AIRPORT = "WAA"
    AMBLER_AIRPORT = "ABL"
    EGEGIK_AIRPORT = "EGX"
    FAIRBANKS_INTERNATIONAL_AIRPORT = "FAI"
    EDWARD_G_PITKA_SR_AIRPORT = "GAL"
    HAINES_MUNICIPAL_AIRPORT = "HNS"
    KALSKAG_MUNICIPAL_AIRPORT = "KLG"
    HUGHES_MUNICIPAL_AIRPORT = "HUS"
    HOONAH_AIRPORT = "HNH"
    NULATO_AIRPORT = "NUL"
    KOBUK_WIEN_AIRPORT = "OBU"
    UNALAKLEET_AIRPORT = "UNK"
    PETERSBURG_MUNICIPAL_AIRPORT = "PSG"
    KWINHAGAK_AIRPORT = "KWN"
    SHISHMAREF_AIRPORT = "SHH"
    SAINT_PAUL_ISLAND_AIRPORT = "SNP"
    TED_STEVENS_ANCHORAGE_INTERNATIONAL_AIRPORT = "ANC"
    ANIAK_AIRPORT = "ANI"
    ANVIK_AIRPORT = "ANV"
    ATQASUK_EDWARD_BURNELL_SR_MEMORIAL_AIRPORT = "ATK"
    ALAKANUK_AIRPORT = "AUK"
    SITKA_AIRPORT = "SIT"
    TELLER_AIRPORT = "TLA"
    SELAWIK_AIRPORT = "WLK"
    KIVALINA_AIRPORT = "KVL"
    KASIGLUK_AIRPORT = "KUK"
    KOTLIK_AIRPORT = "KOT"
    BREVIG_MISSION_AIRPORT = "KTS"
    KOYUKUK_AIRPORT = "KYU"
    KOKHANOK_AIRPORT = "KNK"
    KWETHLUK_AIRPORT = "KWT"
    AWABA_AIRPORT = "AWB"
    SHAKTOOLIK_AIRPORT = "SKK"
    CHEVAK_AIRPORT = "VAK"
    ELIM_AIRPORT = "ELI"
    WRANGELL_AIRPORT = "WRG"
    YAKUTAT_AIRPORT = "YAK"
    KONA_INTERNATIONAL_AIRPORT_AT_KEAHOLE = "KOA"
    DEW_STATION_AIRPORT = "PIZ"
    MATSU_NANGAN_AIRPORT = "LZN"
    MAGONG_AIRPORT = "MZG"
    HUALIEN_AIRPORT = "HUN"
    YAKUSHIMA_AIRPORT = "KUM"
    NAGASAKI_AIRPORT = "NGS"
    AOMORI_AIRPORT = "AOJ"
    AMAMI_AIRPORT = "ASJ"
    HACHIJO_JIMA_AIRPORT = "HAC"
    MIYAKO_AIRPORT = "MMY"
    YEOSU_AIRPORT = "RSU"
    KING_MSWATI_III_INTERNATIONAL_AIRPORT = "SHO"
    JEJU_INTERNATIONAL_AIRPORT = "CJU"
    INCHEON_INTERNATIONAL_AIRPORT = "ICN"
    BUSUANGA_AIRPORT = "USU"
    EL_CALAFATE_AIRPORT = "FTE"
    CATARATAS_DEL_IGUAZU_INTERNATIONAL_AIRPORT = "IGR"
    MALVINAS_ARGENTINAS_INTERNATIONAL_AIRPORT = "USH"
    MAR_DEL_PLATA_AIRPORT = "MDQ"
    RIO_GALLEGOS_INTERNACIONAL_AIRPORT = "RGL"
    ALTA_FLORESTA_AIRPORT = "AFL"
    CARAJAS_AIRPORT = "CKS"
    EDUARDO_GOMES_INTERNATIONAL_AIRPORT = "MAO"
    CORUMBA_INTERNACIONAL_AIRPORT = "CMG"
    MARABA_AIRPORT = "MAB"
    PALMAS_AIRPORT = "PMW"
    CHACALLUTA_AIRPORT = "ARI"
    TENIENTE_VIDAL_AIRPORT = "BBA"
    VILHENA_AIRPORT = "BVH"
    PAMPA_GUANACO_AIRPORT = "DPB"
    MOCOPULLI_AIRPORT = "MHC"
    COPOSA_AIRPORT = "CPP"
    PRES_IBANEZ_AIRPORT = "PUQ"
    ARTURO_MERINO_BENITEZ_AIRPORT = "SCL"
    TEMUCO_MAQUEHUE_AIRPORT = "PZS"
    PUERTO_ASIS_AIRPORT = "PUU"
    GUAPI_AIRPORT = "GPI"
    PUERTO_CARRENO_AIRPORT = "PCR"
    SHUMBA_AIRPORT = "JAE"
    CANARANA_AIRPORT = "CQA"
    FAZENDA_TUCUNARE_AIRPORT = "AZL"
    GRANTLEY_ADAMS_INTERNATIONAL_AIRPORT = "BGI"
    CANEFIELD_AIRPORT = "DCF"
    MELVILLE_HALL_AIRPORT = "DOM"
    TULUKSAK_AIRPORT = "TLT"
    REINA_BEATRIX_INTERNATIONAL_AIRPORT = "AUA"
    CLAYTON_J_LLOYD_INTERNATIONAL_AIRPORT = "AXA"
    TERRANCE_B_LETTSOME_INTERNATIONAL_AIRPORT = "EIS"
    L_F_WADE_INTERNATIONAL_AIRPORT = "BDA"
    MARKOVO_AIRPORT = "KVM"
    ENTERPRISE_MUNI_AIRPORT = "EDN"
    ANAPA_AIRPORT = "AAQ"
    KOGGALA_AIRPORT = "KCT"
    MATTALA_RAJAPAKSA_INTERNATIONAL_AIRPORT = "HRI"
    MACAU_INTERNATIONAL_AIRPORT = "MFM"
    TRIBHUVAN_INTERNATIONAL_AIRPORT = "KTM"
    BHARATPUR_AIRPORT = "BHR"
    BAJURA_AIRPORT = "BJU"
    TUMLING_TAR_AIRPORT = "TMI"
    SUVARNABHUMI_AIRPORT = "BKK"
    KOODDOO_AIRPORT = "GKK"
    NYAUNG_U_AIRPORT = "NYU"
    HEHO_AIRPORT = "HEH"
    PHUKET_INTERNATIONAL_AIRPORT = "HKT"
    KENG_TUNG_AIRPORT = "KET"
    KYAUKPYU_AIRPORT = "KYP"
    KAWTHAUNG_AIRPORT = "KAW"
    CIVIL_AIRPORT = "AKY"
    MANDALAY_INTERNATIONAL_AIRPORT = "MDL"
    MOPAH_AIRPORT = "MKQ"
    KALIMARAU_AIRPORT = "BEJ"
    LANGGUR_AIRPORT = "LUV"
    DOBO_AIRPORT = "DOB"
    HALUOLEO_AIRPORT = "KDI"
    MUKAH_AIRPORT = "MKM"
    LAHAD_DATU_AIRPORT = "LDU"
    LABUAN_AIRPORT = "LBU"
    BARIO_AIRPORT = "BBN"
    BAUBAU_AIRPORT = "BUW"
    MARUDI_AIRPORT = "MUR"
    MULU_AIRPORT = "MZV"
    STEBBINS_AIRPORT = "WBB"
    HANG_NADIM_INTERNATIONAL_AIRPORT = "BTH"
    LETUNG_AIRPORT = "LMU"
    GUNUNGSITOLI_AIRPORT = "GNS"
    SULTAN_SYARIF_KASIM_II_INTERNATIONAL_AIRPORT = "PKU"
    PANGKOR_AIRPORT = "PKG"
    HALIWEN_AIRPORT = "ABU"
    ARRABURY_AIRPORT = "AAB"
    BLACKALL_AIRPORT = "BKQ"
    ALICE_SPRINGS_AIRPORT = "ASP"
    CHARLEVILLE_AIRPORT = "CTL"
    AUSTRAL_DOWNS_AIRPORT = "AWP"
    CONNELLAN_AIRPORT = "AYQ"
    BARCALDINE_AIRPORT = "BCI"
    BROOME_AIRPORT = "BME"
    WHITSUNDAY_COAST_AIRPORT = "PPP"
    NIFTY_AIRPORT = "NIF"
    BARIMUNYA_AIRPORT = "BYP"
    CEDUNA_AIRPORT = "CED"
    CLONCURRY_AIRPORT = "CNJ"
    COOBER_PEDY_AIRPORT = "CPD"
    COONDEWANNA_AIRPORT = "CJF"
    DOOMADGEE_AIRPORT = "DMD"
    DEVONPORT_AIRPORT = "DPO"
    FORREST_RIVER_AIRPORT = "FVR"
    GINBATA_AIRPORT = "GBW"
    GLADSTONE_AIRPORT = "GLT"
    ALYANGULA_AIRPORT = "GTE"
    GEORGETOWN_AIRPORT = "GTT"
    BALLERA_AIRPORT = "BBL"
    KARUMBA_AIRPORT = "KRB"
    KINGSCOTE_AIRPORT = "KGC"
    MORNINGTON_AIRPORT = "ONG"
    MANINGRIDA_AIRPORT = "MNG"
    MCARTHUR_RIVER_AIRPORT = "MCV"
    NORTHERN_PENINSULA_AIRPORT = "ABM"
    KUNUNURRA_AIRPORT = "KNX"
    NHULUNBUY_AIRPORT = "GOV"
    LEARMONTH_AIRPORT = "LEA"
    NORMANTON_AIRPORT = "NTN"
    OLYMPIC_DAM_AIRPORT = "OLP"
    PARABURDOO_AIRPORT = "PBO"
    PORT_MACQUARIE_AIRPORT = "PQQ"
    PORT_HEDLAND_INTERNATIONAL_AIRPORT = "PHE"
    TREPELL_AIRPORT = "TQP"
    ROMA_AIRPORT = "RMA"
    SYDNEY_KINGSFORD_SMITH_AIRPORT = "SYD"
    THE_MONUMENT_AIRPORT = "PHQ"
    TELFER_AIRPORT = "TEF"
    BEIJING_CAPITAL_INTERNATIONAL_AIRPORT = "PEK"
    BEIHAI_FUCHENG_AIRPORT = "BHY"
    SHIJIAZHUANG_DAGUOCUN_AIRPORT = "SJW"
    QINHUANGDAO_BEIDAIHE_AIRPORT = "BPE"
    GUANGZHOU_BAIYUN_INTERNATIONAL_AIRPORT = "CAN"
    TIANJIN_BINHAI_INTERNATIONAL_AIRPORT = "TSN"
    DELMA_ISLAND_AIRPORT = "ZDY"
    CHIFENG_AIRPORT = "CIF"
    CHANGSHA_HUANGHUA_AIRPORT = "CSX"
    ZHANGJIAJIE_HEHUA_AIRPORT = "DYG"
    LUOYANG_BEIJIAO_AIRPORT = "LYA"
    NANNING_AIRPORT = "NNG"
    SANYA_PHOENIX_INTERNATIONAL_AIRPORT = "SYX"
    ZHONGWEI_AIRPORT = "ZHY"
    NANYANG_AIRPORT = "NNY"
    ZHENGZHOU_XINZHENG_AIRPORT = "CGO"
    XIAN_XIGUAN_AIRPORT = "SIA"
    DUNHUANG_AIRPORT = "DNH"
    HAIKOU_AIRPORT = "HAK"
    JIEYANG_CHAOSHAN_AIRPORT = "SWA"
    WUHAN_TIANHE_INTERNATIONAL_AIRPORT = "WUH"
    LANZHOU_ZHONGCHUAN_INTERNATIONAL_AIRPORT = "LHW"
    DEHONG_MANGSHI_AIRPORT = "LUM"
    QINGDAO_LIUTING_INTERNATIONAL_AIRPORT = "TAO"
    CHINGGIS_KHAAN_INTERNATIONAL_AIRPORT = "ULN"
    CHANGLE_INTERNATIONAL_AIRPORT = "FOC"
    HEFEI_XINQIAO_AIRPORT = "HFE"
    HANGZHOU_XIAOSHAN_INTERNATIONAL_AIRPORT = "HGH"
    URUMQI_DIWOPU_INTERNATIONAL_AIRPORT = "URC"
    QIEMO_AIRPORT = "IQM"
    KANGDING_AIRPORT = "KGT"
    KARAMAY_AIRPORT = "KRY"
    YUSHU_BATANG_AIRPORT = "YUS"
    YANJI_CHAOYANGCHUAN_AIRPORT = "YNJ"
    KANSAS_CITY_INTERNATIONAL_AIRPORT = "MCI"
    ORLANDO_INTERNATIONAL_AIRPORT = "MCO"
    JIANSANJIANG_SHIDI_AIRPORT = "JSJ"
    YICHUN_SHI_AIRPORT = "LDS"
    LIAONING_PROVINCE_AIRPORT = "JNZ"
    JIXI_AIRPORT = "JXA"
    DALIAN_ZHOUSHUIZI_INTERNATIONAL_AIRPORT = "DLC"
    FUYUAN_DONGJI_AIRPORT = "FYJ"
    HEIHE_AIRPORT = "HEK"
    HARBIN_TAIPING_INTERNATIONAL_AIRPORT = "HRB"
    JIAMUSI_AIRPORT = "JMU"
    MC_COOK_AIRPORT = "MCK"
    MASON_CITY_AIRPORT = "MCW"
    AUGUSTO_C_SANDINO_INTERNATIONAL_AIRPORT = "MGA"
    MOUNT_GAMBIER_AIRPORT = "MGB"
    MICHIGAN_CITY_AIRPORT = "MGC"
    MARGATE_AIRPORT = "MGH"
    MORGANTOWN_AIRPORT = "MGW"
    DAYTON_WRIGHT_BROTHERS_AIRPORT = "MGY"
    MILDENHALL_AIRPORT = "MHZ"
    MALEO_AIRPORT = "MOH"
    MIANYANG_NANJIAO_AIRPORT = "MIG"
    DR_GASTAO_VIDIGAL_AIRPORT = "MII"
    MYTILENE_INTERNATIONAL_AIRPORT = "MJT"
    TAMPA_PADANG_AIRPORT = "MJU"
    MURCIA_SAN_JAVIER_AIRPORT = "MJV"
    MIRNYJ_AIRPORT = "MJZ"
    CHARLES_B_WHEELER_DOWNTOWN_AIRPORT = "MKC"
    GENERAL_MITCHELL_INTERNATIONAL_AIRPORT = "MKE"
    MUSKEGON_AIRPORT = "MKG"
    MOLOKAI_AIRPORT = "MKK"
    MALTA_INTERNATIONAL_AIRPORT = "MLA"
    ORLANDO_MELBOURNE_INTERNATIONAL_AIRPORT = "MLB"
    MALATYA_AIRPORT = "MLX"
    MALMÖ_BULLTOFTA_AIRPORT = "MMA"
    MEMANBETSU_AIRPORT = "MMB"
    MATSUMOTO_AIRPORT = "MMJ"
    WAI_OTI_AIRPORT = "MOF"
    MANASSAS_REGIONAL_AIRPORT_HARRY_P_DAVIS_FIELD = "MNZ"
    MODESTO_MUNICIPAL_AIRPORT = "MOD"
    TEMAE_AIRPORT = "MOZ"
    MIQUELON_AIRPORT = "MQC"
    MAGNITOGORSK_AIRPORT = "MQF"
    MILDURA_AIRPORT = "MQL"
    MARDIN_AIRPORT = "MQM"
    MO_I_RANA_AIRPORT = "MQN"
    KRUGER_MPUMALANGA_INTERNATIONAL_AIRPORT = "MQP"
    MARSEILLE_PROVENCE_AIRPORT = "MRS"
    SIR_SEEWOOSAGUR_RAMGOOLAM_INTERNATIONAL_AIRPORT = "MRU"
    MINERALNYE_VODY_AIRPORT = "MRV"
    MONTEREY_REGIONAL_AIRPORT = "MRY"
    MOREE_AIRPORT = "MRZ"
    NORTHWEST_ALABAMA_REGIONAL_AIRPORT = "MSL"
    DANE_COUNTY_REGIONAL_AIRPORT = "MSN"
    MAHSHAHR_AIRPORT = "MRX"
    MINATITLAN_AIRPORT = "MTT"
    GEN_MARIANO_ESCOBEDO_AIRPORT = "MTY"
    FRANZ_JOSEF_STRAUSS_AIRPORT = "MUC"
    MORA_AIRPORT = "MXX"
    MEI_XIAN_AIRPORT = "MXZ"
    MARY_AIRPORT = "MYP"
    MYITKYINA_AIRPORT = "MYT"
    MAYOR_PNP_NANCY_FLORE_AIRPORT = "MZA"
    NALCHIK_AIRPORT = "NAL"
    NANCHONG_AIRPORT = "NAO"
    QIQIHAR_AIRPORT = "NDG"
    NINGBO_AIRPORT = "NGB"
    CHUBU_CENTRAIR_INTERNATIONAL_AIRPORT = "NGO"
    NAMANGAN_AIRPORT = "NMA"
    SIMON_MWANSA_KAPWEPWE_INTERNATIONAL_AIRPORT = "NLA"
    NOUAKCHOTT_INTERNATIONAL_AIRPORT = "NKC"
    NORDEN_NORDDEICH_AIRPORT = "NOD"
    NARYAN_MAR_AIRPORT = "NNM"
    NUNUKAN_AIRPORT = "NNX"
    NOJABRXSK_AIRPORT = "NOJ"
    NOVOKUZNETSK_AIRPORT = "NOZ"
    HAWKES_BAY_AIRPORT = "NPE"
    PRESIDENTE_PERON_INTERNATIONAL_AIRPORT = "NQN"
    NORILSK_AIRPORT = "NSK"
    NUREMBERG_AIRPORT = "NUE"
    NEOM_AIRPORT = "NUM"
    NOVY_URENGOY_AIRPORT = "NUX"
    BENITO_SALAS_AIRPORT = "NVA"
    NAVOI_AIRPORT = "NVI"
    MARIA_REICHE_NEUMAN_AIRPORT = "NZC"
    MANZHOULI_AIRPORT = "NZH"
    ZHALANTUN_CHENGJISIHAN_AIRPORT = "NZL"
    ORANGE_AIRPORT = "OAG"
    ALBERT_J_ELLIS_AIRPORT = "OAJ"
    METROPOLITAN_OAKLAND_INTERNATIONAL_AIRPORT = "OAK"
    CACOAL_AIRPORT = "OAL"
    GARRETT_COUNTY_AIRPORT = "ODM"
    LONG_SERIDAN_AIRPORT = "ODN"
    BODAYBO_AIRPORT = "ODO"
    ODESSA_INTERNATIONAL_AIRPORT = "ODS"
    OUDOMXAY_AIRPORT = "ODY"
    ORNSKOLDSVIK_AIRPORT = "OER"
    OKUSHIRI_AIRPORT = "OIR"
    OLIVE_BRANCH_AIRPORT = "OLV"
    OLKIOMBO_AIRPORT = "OLX"
    OLOKMINSK_AIRPORT = "OLZ"
    OREBRO_BOFORS_AIRPORT = "ORB"
    OHARE_INTERNATIONAL_AIRPORT = "ORD"
    NORFOLK_INTERNATIONAL_AIRPORT = "ORF"
    WORCESTER_REGIONAL_AIRPORT = "ORH"
    CORK_AIRPORT = "ORK"
    PARIS_ORLY_AIRPORT = "ORY"
    NAMSOS_AIRPORT = "OSY"
    SOUTHWEST_OREGON_REGIONAL_AIRPORT = "OTH"
    BUCHAREST_HENRI_COANDA_INTERNATIONAL_AIRPORT = "OTP"
    CENTRAL_MAINE_AIRPORT_OF_NORRIDGEWOCK = "OWK"
    OSVALDO_VIEIRA_AIRPORT = "OXB"
    PLATTSBURGH_INTERNATIONAL_AIRPORT = "PBG"
    EL_TAJIN_NATIONAL_AIRPORT = "PAZ"
    HUEJOTSINGO_AIRPORT = "PBC"
    PARO_AIRPORT = "PBH"
    DEKALB_PEACHTREE_AIRPORT = "PDK"
    PUERTO_MALDONADO_AIRPORT = "PEM"
    PEDASÍ_AIRPORT = "PDM"
    CAPITAN_DE_CORBETA_CARLOS_A_CURBELO_INTERNATIONAL_AIRPORT = "PDP"
    PIEDRAS_NEGRAS_INTERNATIONAL_AIRPORT = "PDS"
    PLOVDIV_AIRPORT = "PDV"
    PERM_INTERNATIONAL_AIRPORT = "PEE"
    SANT_EGIDIO_AIRPORT = "PEG"
    CHARLOTTE_COUNTY_AIRPORT = "PGD"
    LLABANERE_AIRPORT = "PGF"
    GLASGOW_PRESTWICK_AIRPORT = "PIK"
    PITTSBURGH_INTERNATIONAL_AIRPORT = "PIT"
    CAPITAN_FAP_RENAN_ELIAS_OLIVERA_AIRPORT = "PIO"
    POITIERS_BIARD_AIRPORT = "PIS"
    CAP_FAP_GUILLERMO_CONCHA_IBERICO_INTERNATIONAL_AIRPORT = "PIU"
    PAJALA_AIRPORT = "PJA"
    ISKANDAR_AIRPORT = "PKN"
    POKHARA_AIRPORT = "PKR"
    PSKOV_AIRPORT = "PKV"
    BEIJING_DAXING_INTERNATIONAL_AIRPORT = "PKX"
    TJILIK_RIWUT_AIRPORT = "PKY"
    PALANGA_INTERNATIONAL_AIRPORT = "PLQ"
    SEMIPALATINSK_AIRPORT = "PLX"
    PARMA_AIRPORT = "PMF"
    PALM_ISLAND_AIRPORT = "PMK"
    FALCONE_BORSELLINO_AIRPORT = "PMO"
    PALMERSTON_NORTH_AIRPORT = "PMR"
    SANTIAGO_MARINO_INTERNATIONAL_AIRPORT = "PMV"
    PAMPLONA_AIRPORT = "PNA"
    PEMBA_AIRPORT = "POL"
    PAGO_PAGO_INTERNATIONAL_AIRPORT = "PPG"
    LA_UNION_AIRPORT = "POP"
    A_DE_BARROS_AIRPORT = "PPB"
    GENERAL_JUSTO_JOSE_DE_URQUIZA_AIRPORT = "PRA"
    PRESCOTT_AIRPORT = "PRC"
    VACLAV_HAVEL_AIRPORT_PRAGUE = "PRG"
    PRASLIN_ISLAND_AIRPORT = "PRI"
    PORTIMAO_AIRPORT = "PRM"
    PRISTINA_INTERNATIONAL_AIRPORT = "PRN"
    PHRAE_AIRPORT = "PRH"
    DINWIDDIE_COUNTY_AIRPORT = "PTB"
    POLOKWANE_AIRPORT = "PTG"
    MOSCOW_REGIONAL_AIRPORT = "PUW"
    PROVINCETOWN_AIRPORT = "PVC"
    GUSTAVO_DIAZ_ORDAZ_INTERNATIONAL_AIRPORT = "PVR"
    POLYARNYJ_AIRPORT = "PYJ"
    SAM_MBAKWE_INTERNATIONAL_AIRPORT = "QOW"
    LUBLIN_RADAWIEC_AIRPORT = "QLU"
    LEIRIA_GANDARA_AIRPORT = "QLR"
    QUERETARO_INTERCONTINENTAL_AIRPORT = "QRO"
    SETIF_AIRPORT = "QSF"
    RAFHA_AIRPORT = "RAH"
    DR_LEITE_LOPES_STATE_AIRPORT = "RAO"
    PRES_MEDICI_AIRPORT = "RBR"
    TITO_MENNITI_AIRPORT = "REG"
    TRELEW_AIRPORT = "REL"
    ORENBURG_AIRPORT = "REN"
    SIEM_REAP_INTERNATIONAL_AIRPORT = "REP"
    RESISTENCIA_AIRPORT = "RES"
    STOLPORT_AIRPORT = "RET"
    REUS_AIRPORT = "REU"
    GEN_LUCIO_BLANCO_INTERNATIONAL_AIRPORT = "REX"
    RICHMOND_INTERNATIONAL_AIRPORT_BYRD_FIELD = "RIC"
    RICHMOND_MUNICIPALCIPAL_AIRPORT = "RID"
    SCARLETT_MARTÍNEZ_INTERNATIONAL_AIRPORT = "RIH"
    RISHIRI_AIRPORT = "RIS"
    RIVERTON_AIRPORT = "RIW"
    RIGA_INTERNATIONAL_AIRPORT = "RIX"
    MARSA_ALAM_INTERNATIONAL_AIRPORT = "RMF"
    NEW_RICHMOND_MUNICIPAL_AIRPORT = "RNH"
    YORON_AIRPORT = "RNJ"
    ROANOKE_BLACKSBURG_REGIONAL_AIRPORT = "ROA"
    RONDONOPOLIS_AIRPORT = "ROO"
    MERRILL_MUNICIPAL_AIRPORT = "RRL"
    FISHERTON_AIRPORT = "ROS"
    ROTORUA_INTERNATIONAL_AIRPORT = "ROT"
    SANTA_ROSA_AIRPORT = "RSA"
    ROSEAU_MUNICIPAL_AIRPORT = "ROX"
    SOUTHWEST_FLORIDA_INTERNATIONAL_AIRPORT = "RSW"
    ROATAN_AIRPORT = "RTB"
    ROTTERDAM_THE_HAGUE_AIRPORT = "RTM"
    ROXAS_CITY_AIRPORT = "RXS"
    RAHIM_YAR_KHAN_AIRPORT = "RYK"
    MOSS_AIRPORT = "RYG"
    ROYAL_AIRPORT = "RYL"
    CLR_AIRPORT = "RZP"
    ST_BARTHELEMY_AIRPORT = "SBH"
    SAN_LUIS_COUNTY_REGIONAL_AIRPORT = "SBP"
    SIBU_AIRPORT = "SBW"
    WICOMICO_REGIONAL_AIRPORT = "SBY"
    SIBIU_AIRPORT = "SBZ"
    LUBANGO_AIRPORT = "SDD"
    SANTIAGO_DEL_ESTERO_AIRPORT = "SDE"
    SANANDAJ_AIRPORT = "SDG"
    SENDAI_AIRPORT = "SDJ"
    LOUISVILLE_INTERNATIONAL_AIRPORT = "SDF"
    SANDANE_AIRPORT = "SDN"
    SAND_POINT_MUNICIPAL_AIRPORT = "SDP"
    KANGERLUSSUAQ_AIRPORT = "SFJ"
    SANTA_FE_AIRPORT = "SFN"
    SAN_FRANCISCO_INTERNATIONAL_AIRPORT = "SFO"
    SKELLEFTEA_AIRPORT = "SFT"
    SHENANDOAH_VALLEY_AIRPORT = "SHD"
    SHENYANG_TAOXIAN_INTERNATIONAL_AIRPORT = "SHE"
    SIMFEROPOL_INTERNATIONAL_AIRPORT = "SIP"
    SHILLONG_AIRPORT = "SHL"
    NORMAN_Y_MINETA_SAN_JOSE_INTERNATIONAL_AIRPORT = "SJC"
    SARAJEVO_INTERNATIONAL_AIRPORT = "SJJ"
    JUAN_SANTAMARIA_INTERNATIONAL_AIRPORT = "SJO"
    LOS_CABOS_INTERNATIONAL_AIRPORT = "SJD"
    SAN_ANGELO_REGIONAL_AIRPORT = "SJT"
    SUKKUR_AIRPORT = "SKZ"
    STORM_LAKE_MUNICIPAL_AIRPORT = "SLB"
    SALT_LAKE_CITY_INTERNATIONAL_AIRPORT = "SLC"
    ADIRONDACK_AIRPORT = "SLK"
    MATACAN_AIRPORT = "SLM"
    SALINA_REGIONAL_AIRPORT = "SLN"
    MARTIN_MIGUEL_DE_GUEMES_INTERNATIONAL_AIRPORT = "SLA"
    SANTA_MARIA_PUBLIC_AIRPORT = "SMX"
    JOHN_WAYNE_AIRPORT = "SNA"
    GENERAL_ULPIANO_PAEZ_AIRPORT = "SNC"
    SHANNON_AIRPORT = "SNN"
    SOUTHAMPTON_AIRPORT = "SOU"
    SHOW_LOW_AIRPORT = "SOW"
    LA_PALMA_AIRPORT = "SPC"
    JUANA_AZURDUY_DE_PADILLA_INTERNATIONAL_AIRPORT = "SRE"
    SAMSUN_SAMAIR_AIRPORT = "SSX"
    STAUNING_VESTJYLLANDS_AIRPORT = "STA"
    ST_GEORGE_ISLAND_AIRPORT = "STG"
    CIBAO_INTERNATIONAL_AIRPORT = "STI"
    SAKKYRYR_AIRPORT = "SUK"
    SUMTER_MUNICIPAL_AIRPORT = "SUM"
    SPIRIT_OF_ST_LOUIS_AIRPORT = "SUS"
    STEWART_INTERNATIONAL_AIRPORT = "SWF"
    ARGYLE_INTERNATIONAL_AIRPORT = "SVD"
    SWANSEA_AIRPORT = "SWS"
    SULTAN_MUHAMMAD_KAHARUDDIN_III_AIRPORT = "SWQ"
    SEVERO_EVENSK_AIRPORT = "SWV"
    STREZHEVOY_AIRPORT = "SWT"
    PRINCESS_JULIANA_INTERNATIONAL_AIRPORT = "SXM"
    STORNOWAY_AIRPORT = "SYY"
    SHIRAZ_INTERNATIONAL_AIRPORT = "SYZ"
    SOYO_AIRPORT = "SZA"
    SULTAN_ABDUL_AZIZ_SHAH_AIRPORT = "SZB"
    SEMERA_AIRPORT = "SZE"
    SHONAI_AIRPORT = "SYO"
    PARCHIM_AIRPORT = "SZW"
    OLSZTYN_MAZURY_AIRPORT = "SZY"
    HANCOCK_INTERNATIONAL_AIRPORT = "SYR"
    D_Z_ROMUALDEZ_AIRPORT = "TAC"
    TAPACHULA_INTERNATIONAL_AIRPORT = "TAP"
    POPRAD_TATRY_AIRPORT = "TAT"
    TAU_ISLAND_AIRPORT = "TAV"
    TUY_HOA_AIRPORT = "TBB"
    TABORA_AIRPORT = "TBO"
    CAPITAN_FAP_PEDRO_CANGA_RODRIGUEZ_AIRPORT = "TBP"
    TABATINGA_INTERNATIONAL_AIRPORT = "TBT"
    TARTU_AIRPORT = "TAY"
    TAMBOV_DONSKOYE_AIRPORT = "TBW"
    TAMBELAN_AIRPORT = "TBX"
    TREASURE_CAY_AIRPORT = "TCB"
    TINBOLI_AIRPORT = "TCK"
    TACNA_AIRPORT = "TCQ"
    TUTICORIN_AIRPORT = "TCR"
    TENGCHONG_TUOFENG_AIRPORT = "TCZ"
    TENIENTE_JORGE_HENRICH_ARAUZ_AIRPORT = "TDD"
    CHEIKH_LARBI_TEBESSI_AIRPORT = "TEE"
    MATUNDO_AIRPORT = "TET"
    TERUEL_AIRPORT = "TEV"
    TEZPUR_AIRPORT = "TEZ"
    TENERIFE_NORTH_AIRPORT = "TFN"
    TENERIFE_SOUTH_AIRPORT = "TFS"
    MUHAMMAD_TAUFIQ_KIEMAS_AIRPORT = "TFY"
    TANJUNG_MANIS_AIRPORT = "TGC"
    PODGORICA_AIRPORT = "TGD"
    SULTAN_MAHMUD_AIRPORT = "TGG"
    TEFE_AIRPORT = "TFF"
    CHENGDU_TIANFU_INTERNATIONAL_AIRPORT = "TFU"
    TOUGGOURT_AIRPORT = "TGR"
    ANGEL_ALBINO_CORZO_INTERNATIONAL_AIRPORT = "TGZ"
    BAI_THUONG_AIRPORT = "THD"
    TROLLHATTAN_AIRPORT = "THN"
    YORK_AIRPORT = "THV"
    TURUKHANSK_AIRPORT = "THX"
    TIRANA_INTERNATIONAL_AIRPORT = "TIA"
    TAIF_AIRPORT = "TIF"
    TIJUANA_AIRPORT = "TIJ"
    TINDOUF_AIRPORT = "TIN"
    CAPITAN_ORIEL_LEA_PLAZA_AIRPORT = "TJA"
    TRÊS_LAGOAS_AIRPORT = "TJL"
    BULUTUMBANG_AIRPORT = "TJQ"
    KULYAB_AIRPORT = "TJU"
    TALLINN_AIRPORT = "TLL"
    TOULOUSE_BLAGNAC_AIRPORT = "TLS"
    TOLUCA_INTERNATIONAL_AIRPORT = "TLC"
    RADIN_INTEN_II_AIRPORT = "TKG"
    CHUUK_INTERNATIONAL_AIRPORT = "TKK"
    TAMBOLAKA_AIRPORT = "TMC"
    KIGOMA_AIRPORT = "TKQ"
    GABRIEL_VARGAS_SANTOS_AIRPORT = "TME"
    TOKUSHIMA_AWAODORI_AIRPORT = "TKS"
    TURKU_AIRPORT = "TKU"
    TALLAHASSEE_INTERNATIONAL_AIRPORT = "TLH"
    ZENATA_AIRPORT = "TLM"
    TURPAN_JIAOHE_AIRPORT = "TLQ"
    BEN_GURION_INTERNATIONAL_AIRPORT = "TLV"
    PLASTUN_AIRPORT = "TLY"
    THIMARAFUSHI_AIRPORT = "TMF"
    TERMEZ_AIRPORT = "TMJ"
    TAMALE_AIRPORT = "TML"
    TAMPERE_PIRKKALA_AIRPORT = "TMP"
    AGUENAR_HADJ_BEY_AKHAMOK_AIRPORT = "TMR"
    SAO_TOME_ISLAND_AIRPORT = "TMS"
    TAMBOR_AIRPORT = "TMU"
    TIMIMOUN_AIRPORT = "TMX"
    TORRANCE_AIRPORT = "TOA"
    TOZEUR_AIRPORT = "TOE"
    TONGHUA_SANYUANPU_AIRPORT = "TNH"
    KIDJANG_AIRPORT = "TNJ"
    ANTANANARIVO_AIRPORT = "TNR"
    NEWTON_MUNICIPAL_AIRPORT = "TNU"
    TOMSK_AIRPORT = "TOF"
    TROY_MUNICIPAL_AIRPORT = "TOI"
    TORRINGTON_MUNICIPAL_AIRPORT = "TOR"
    CAD_FAP_GUILLERMO_DEL_CASTILLO_PAREDES_AIRPORT = "TPP"
    TEPIC_AIRPORT = "TPQ"
    TOLEDO_EXPRESS_AIRPORT = "TOL"
    TROMSO_LANGNES_AIRPORT = "TOS"
    TOYAMA_AIRPORT = "TOY"
    TAMPA_INTERNATIONAL_AIRPORT = "TPA"
    TAIWAN_TAOYUAN_INTERNATIONAL_AIRPORT = "TPE"
    TRAPANI_BIRGI_AIRPORT = "TPS"
    TIREE_AIRPORT = "TRE"
    TORP_SANDEFJORD_AIRPORT = "TRF"
    TAURANGA_CITY_AIRPORT = "TRG"
    JUWATA_INTERNATIONAL_AIRPORT = "TRK"
    TRUJILLO_AIRPORT = "TRU"
    BONRIKI_AIRPORT = "TRW"
    TAN_TAN_AIRPORT = "TTA"
    TOTTORI_AIRPORT = "TTJ"
    VAL_DE_LOIRE_AIRPORT = "TUF"
    TABUK_REGIONAL_AIRPORT = "TUU"
    MATEI_AIRPORT = "TVU"
    TRENTON_MERCER_AIRPORT = "TTN"
    BRITTON_MUNICIPAL_AIRPORT = "TTO"
    BABULLAH_AIRPORT = "TTE"
    TURBAT_AIRPORT = "TUK"
    DAWE_AIRPORT = "TVY"
    TUMXUK_TANGWANGCHENG_AIRPORT = "TWC"
    MAGIC_VALLEY_REGIONAL_AIRPORT = "TWF"
    TAWAU_AIRPORT = "TWU"
    TEIXEIRA_DE_FREITAS_AIRPORT = "TXF"
    TEXARKANA_MUNICIPAL_AIRPORT = "TXK"
    REMBELE_AIRPORT = "TXE"
    TEGEL_AIRPORT = "TXL"
    CAPTAIN_FAP_VICTOR_MONTES_ARIAS_AIRPORT = "TYL"
    HUANGSHAN_TUNXI_INTERNATIONAL_AIRPORT = "TXN"
    TUZLA_INTERNATIONAL_AIRPORT = "TZL"
    NARSARSUAQ_AIRPORT = "UAK"
    TYNDA_AIRPORT = "TYD"
    SAN_JUAN_AIRPORT = "UAQ"
    UBERABA_AIRPORT = "UBA"
    YAMAGUCHI_UBE_AIRPORT = "UBJ"
    NEW_ULAANBAATAR_INTERNATIONAL_AIRPORT = "UBN"
    UBON_RATCHATHANI_INTERNATIONAL_AIRPORT = "UBP"
    UKHTA_AIRPORT = "UCT"
    UBERLANDIA_TEN_CEL_AV_CESAR_BOMBONATO_AIRPORT = "UDI"
    QUELIMANE_AIRPORT = "UEL"
    KUME_JIMA_AIRPORT = "UEO"
    PHU_CAT_AIRPORT = "UIH"
    ULANQAB_JINING_AIRPORT = "UCB"
    QUINCY_MUNICIPAL_AIRPORT = "UIN"
    MARISCAL_SUCRE_INTERNATIONAL_AIRPORT = "UIO"
    PLUGUFFAN_AIRPORT = "UIP"
    UKUNDA_AIRPORT = "UKA"
    PRINCE_ABDUL_MAJEED_BIN_ABDULAZIZ_AIRPORT = "ULH"
    ULYANOVSK_VOSTOCHNY_AIRPORT = "ULY"
    KOBE_AIRPORT = "UKB"
    WAUKON_MUNICIPAL_AIRPORT = "UKN"
    MENA_INTERMOUNTAIN_MUNICIPAL_AIRPORT = "UMZ"
    RANONG_AIRPORT = "UNN"
    LICENCIADO_Y_GENERAL_IGNACIO_LOPEZ_RAYON_AIRPORT = "UPN"
    RUBEN_BERTA_AIRPORT = "URG"
    URALSK_AIRPORT = "URA"
    SULTAN_HASANUDDIN_INTERNATIONAL_AIRPORT = "UPG"
    KURESSAARE_AIRPORT = "URE"
    KURSK_VOSTOCHNY_AIRPORT = "URS"
    YUZHNO_SAKHALINSK_AIRPORT = "UUS"
    UNION_COUNTY_AIRPORT = "USC"
    CONCORD_PADGETT_REGIONAL_AIRPORT = "USA"
    USINSK_AIRPORT = "USK"
    UNIÃO_DA_VITÓRIA_AIRPORT = "UVI"
    KOH_SAMUI_AIRPORT = "USM"
    YULIN_YUYANG_AIRPORT = "UYN"
    ST_AUGUSTINE_AIRPORT = "UST"
    ULSAN_AIRPORT = "USN"
    UST_NERA_AIRPORT = "USR"
    TUNICA_MUNICIPALCIPAL_AIRPORT = "UTM"
    UTAPAO_AIRPORT = "UTP"
    UMTATA_AIRPORT = "UTT"
    UDON_THANI_INTERNATIONAL_AIRPORT = "UTH"
    UPINGTON_AIRPORT = "UTN"
    BUGULMA_AIRPORT = "UUA"
    ULAN_UDE_AIRPORT = "UUD"
    CHU_LAI_INTERNATIONAL_AIRPORT = "VCL"
    URZHAR_AIRPORT = "UZR"
    MAJOR_BRIGADEIRO_TROMPOWSKY_AIRPORT = "VAG"
    VAASA_AIRPORT = "VAA"
    VARDOE_AIRPORT = "VAW"
    CAN_THO_AIRPORT = "VCA"
    VALCHETA_AIRPORT = "VCF"
    VIDALIA_MUNICIPAL_AIRPORT = "VDI"
    GOBERNADOR_EDGARDO_CASTELLO_AIRPORT = "VDM"
    VALDEZ_MUNICIPAL_AIRPORT = "VDZ"
    VERNAL_REGIONAL_AIRPORT = "VEL"
    VERACRUZ_INTERNATIONAL_AIRPORT = "VER"
    TIOGA_MUNICIPAL_AIRPORT = "VEX"
    VICTORIA_FALLS_AIRPORT = "VFA"
    RACH_GIA_AIRPORT = "VKG"
    EURICO_DE_AGUIAR_SALLES_AIRPORT = "VIX"
    CHIMOIO_AIRPORT = "VPY"
    ANTONIO_RIVERA_RODRIGUEZ_AIRPORT = "VQS"
    JUAN_GUALBERTO_GOMEZ_AIRPORT = "VRA"
    VILA_REAL_AIRPORT = "VRL"
    VISEU_AIRPORT = "VSE"
    WADI_AD_DAWASIR_AIRPORT = "WAE"
    WANGANUI_AIRPORT = "WAG"
    FREDERIC_CHOPIN_AIRPORT = "WAW"
    SHIYAN_WUDANGSHAN_AIRPORT = "WDS"
    WEASUA_AIRPORT = "WES"
    WEIFANG_AIRPORT = "WEF"
    WAJIR_AIRPORT = "WJR"
    HOKKAIDO_AIRPORT = "WKJ"
    WONJU_AIRPORT = "WJU"
    WAIKOLOA_AIRPORT = "WKL"
    MILES_AIRPORT = "WLE"
    NAGA_AIRPORT = "WNP"
    WENZHOU_LONGWAN_INTERNATIONAL_AIRPORT = "WNZ"
    WHANGAREI_AIRPORT = "WRE"
    WINDARLING_AIRPORT = "WRN"
    WESTPORT_AIRPORT = "WSZ"
    ROOIKOP_AIRPORT = "WVB"
    TOOWOOMBA_WELLCAMP_AIRPORT = "WTB"
    WUYISHAN_AIRPORT = "WUS"
    CHAPECO_AIRPORT = "XAP"
    CORON_AIRPORT = "XCN"
    CHALONS_VATRY_AIRPORT = "XCR"
    YELLOWSTONE_AIRPORT = "WYS"
    XINYANG_MINGGANG_AIRPORT = "XAI"
    LAKE_GENEVA_AIRE_ESTATES_AIRPORT = "XES"
    HAMBURG_FINKENWERDER_AIRPORT = "XFW"
    XIANGYANG_AIRPORT = "XFN"
    XICHANG_AIRPORT = "XIC"
    MANGLA_AIRPORT = "XJM"
    XIENG_KHOUANG_AIRPORT = "XKH"
    NASIRIYAH_AIRPORT = "XNH"
    QUEPOS_AIRPORT = "XQP"
    XINBARAG_YOUQI_BAOGEDE_AIRPORT = "XRQ"
    XUZHOU_GUANYIN_AIRPORT = "XUZ"
    WILLISTON_BASIN_INTERNATIONAL_AIRPORT = "XWA"
    YENISEHIR_AIRPORT = "YEI"
    FORT_FRANCES_MUNICIPAL_AIRPORT = "YAG"
    YAOUNDE_AIRPORT = "YAO"
    YAP_INTERNATIONAL_AIRPORT = "YAP"
    YIBIN_CAIBA_AIRPORT = "YBP"
    BRANDON_MUNICIPAL_AIRPORT = "YBR"
    BAIE_COMEAU_AIRPORT = "YBC"
    CASTLEGAR_AIRPORT = "YCG"
    YUNCHENG_AIRPORT = "YCU"
    CHILLIWACK_MUNICIPALCIPAL_AIRPORT = "YCW"
    INDUSTRIAL_AIRPORT = "YDC"
    EDMONTON_INTERNATIONAL_AIRPORT = "YEG"
    YINCHUAN_HELANSHAN_AIRPORT = "YEH"
    FREDERICTON_INTERNATIONAL_AIRPORT = "YFC"
    MIHO_AIRPORT = "YGJ"
    MICHEL_POULIOT_GASPE_AIRPORT = "YGP"
    HALIFAX_STANFIELD_INTERNATIONAL_AIRPORT = "YHZ"
    YOGYAKARTA_INTERNATIONAL_AIRPORT = "YIA"
    YICHUN_MINGYUESHAN_AIRPORT = "YIC"
    YICHANG_SANXIA_AIRPORT = "YIH"
    YINING_AIRPORT = "YIN"
    WILLOW_RUN_AIRPORT = "YIP"
    YIWU_AIRPORT = "YIW"
    HAMILTON_AIRPORT = "YHM"
    JASPER_AIRPORT = "YJA"
    ARXAN_YIERSHI_AIRPORT = "YIE"
    KAMLOOPS_AIRPORT = "YKA"
    REGION_OF_WATERLOO_INTERNATIONAL_AIRPORT = "YKF"
    YINGKOU_LANQI_AIRPORT = "YKH"
    HAKKARI_YÜKSEKOVA_AIRPORT = "YKO"
    YAKUTSK_AIRPORT = "YKS"
    YEVLAKH_AIRPORT = "YLV"
    KELOWNA_INTERNATIONAL_AIRPORT = "YLW"
    FORT_MCMURRAY_INTERNATIONAL_AIRPORT = "YMM"
    MOOSE_JAW_AIR_VICE_MARSHAL_C_M_MCEWEN_AIRPORT = "YMJ"
    YANBU_AIRPORT = "YNB"
    CHIBOUGAMAU_AIRPORT = "YMT"
    YANCHENG_NANYANG_INTERNATIONAL_AIRPORT = "YNZ"
    MIRABEL_INTERNATIONAL_AIRPORT = "YMX"
    NEMISCAU_AIRPORT = "YNS"
    YANTAI_LAISHAN_INTERNATIONAL_AIRPORT = "YNT"
    YANGYANG_AIRPORT = "YNY"
    YONGPHULLA_AIRPORT = "YON"
    WAWA_AIRPORT = "YXZ"
    QUEBEC_CITY_JEAN_LESAGE_INTERNATIONAL_AIRPORT = "YQB"
    RED_DEER_REGIONAL_AIRPORT = "YQF"
    KENORA_AIRPORT = "YQK"
    LETHBRIDGE_AIRPORT = "YQL"
    WINDSOR_INTERNATIONAL_AIRPORT = "YQG"
    GREATER_MONCTON_INTERNATIONAL_AIRPORT = "YQM"
    SYDNEY_AIRPORT = "YQY"
    COMOX_AIRPORT = "YQQ"
    REGINA_INTERNATIONAL_AIRPORT = "YQR"
    GRANDE_PRAIRIE_AIRPORT = "YQU"
    GANDER_INTERNATIONAL_AIRPORT = "YQX"
    QUESNEL_AIRPORT = "YQZ"
    FORT_SMITH_AIRPORT = "YSM"
    SUDBURY_AIRPORT = "YSB"
    SAINT_JOHN_AIRPORT = "YSJ"
    TIMMINS_VICTOR_M_POWER_AIRPORT = "YTS"
    YANGZHOU_TAIZHOU_AIRPORT = "YTY"
    MONTREAL_PIERRE_ELLIOTT_TRUDEAU_INTERNATIONAL_AIRPORT = "YUL"
    YUMA_INTERNATIONAL_AIRPORT = "YUM"
    ROUYN_NORANDA_AIRPORT = "YUY"
    VERNON_REGIONAL_AIRPORT = "YVE"
    VAL_DOR_AIRPORT = "YVO"
    VANCOUVER_INTERNATIONAL_AIRPORT = "YVR"
    TORONTO_CITY_CENTRE_AIRPORT = "YTZ"
    WIARTON_KEPPEL_AIRPORT = "YVV"
    WINNIPEG_JAMES_ARMSTRONG_RICHARDSON_INTERNATIONAL_AIRPORT = "YWG"
    CANADIAN_ROCKIES_INTERNATIONAL_AIRPORT = "YXC"
    SASKATOON_INTERNATIONAL_AIRPORT = "YXE"
    MEDICINE_HAT_REGIONAL_AIRPORT = "YXH"
    SIOUX_LOOKOUT_AIRPORT = "YXL"
    EDMONTON_CITY_CENTRE_BLATCHFORD_FIELD_AIRPORT = "YXD"
    PANGNIRTUNG_AIRPORT = "YXP"
    PRINCE_GEORGE_AIRPORT = "YXS"
    LONDON_INTERNATIONAL_AIRPORT = "YXU"
    ABBOTSFORD_AIRPORT = "YXX"
    VICTORIA_INNER_HARBOUR_AIRPORT = "YWH"
    JACK_GARLAND_AIRPORT = "YYB"
    CALGARY_INTERNATIONAL_AIRPORT = "YYC"
    GOOSE_BAY_AIRPORT = "YYR"
    SMITHERS_AIRPORT = "YYD"
    PEARSON_INTERNATIONAL_AIRPORT = "YYZ"
    TRAIL_REGIONAL_AIRPORT = "YZZ"
    ZAHEDAN_AIRPORT = "ZAH"
    PICHOY_AIRPORT = "ZAL"
    ST_JOHNS_INTERNATIONAL_AIRPORT = "YYT"
    BATHURST_AIRPORT = "ZBF"
    MONT_JOLI_AIRPORT = "YYY"
    CHAH_BAHAR_AIRPORT = "ZBR"
    YELLOWKNIFE_AIRPORT = "YZF"
    SARNIA_AIRPORT = "YZR"
    CORAL_HARBOUR_AIRPORT = "YZS"
    SEPT_ILES_AIRPORT = "YZV"
    ZHAOTONG_AIRPORT = "ZAT"
    ZARAGOZA_AIRPORT = "ZAZ"
    LA_CALERA_AIRPORT = "ZCL"
    TEMUCO_AIRPORT = "ZCO"
    IXTAPA_ZIHUATANEJO_INTERNACIONAL_AIRPORT = "ZIH"
    ZHIGANSK_AIRPORT = "ZIX"
    ZYRYANKA_AIRPORT = "ZKP"
    ZHANJIANG_AIRPORT = "ZHA"
    ZHUKOVSKY_INTERNATIONAL_AIRPORT = "ZIA"
    MANZANILLO_AIRPORT = "ZLO"
    SOUTH_CARIBOO_REGIONAL_AIRPORT = "ZMH"
    ZALINGEI_AIRPORT = "ZLX"
    NEWMAN_AIRPORT = "ZNE"
    ZANZIBAR_INTERNATIONAL_AIRPORT = "ZNZ"
    CANAL_BAJO_AIRPORT = "ZOS"
    MASSET_AIRPORT = "ZMT"
    ROUND_LAKE_AIRPORT = "ZRJ"
    ZAKINTHOS_AIRPORT = "ZTH"
    ZHITOMIR_AIRPORT = "ZTR"
    ZURICH_AIRPORT = "ZRH"
    SAN_SALVADOR_AIRPORT = "ZSA"
    SHAMATTAWA_AIRPORT = "ZTM"
    ZHUHAI_JINWAN_AIRPORT = "ZUH"
    ZUNYI_XINZHOU_AIRPORT = "ZYI"
    TASHKURGAN_AIRPORT = "HQL"
    ALAER_TALIMU_AIRPORT = "ACF"
    BUSSELLTON_REGIONAL_AIRPORT = "BQB"
    ZANGILAN_INTERNATIONAL_AIRPORT = "ZZE"
    YALA_BETONG_INTERNATIONAL_AIRPORT = "BTZ"
    SHIGATSE_TINGRI_AIRPORT = "DDR"
    SÃO_RAIMUNDO_NONATO_AIRPORT = "NSR"
    SALINÓPOLIS_AIRPORT = "OPP"
    RIZE_ARTVIN_AIRPORT = "RZV"
    MUYNAK_AIRPORT = "MOK"
    LANGZHONG_AIRPORT = "LZG"
    DEOGHAR_INTERNATIONAL_AIRPORT = "DGH"
    GARANHUNS_AIRPORT = "QGP"
    LAVRAS_AIRPORT = "VRZ"
    DR_FRANCISCO_TOMÉ_DA_FROTA_AIRPORT = "QIG"
    MOPA_AIRPORT = "GOX"
    OTOG_FRONT_BANNER_OLJOQ_AIRPORT = "OTQ"
